local _, namespace = ... 	--localization
local L = namespace.L 				--localization

local _, addon = ...
addon.duraMean = 0

local _, gdbprivate = ...

local ipairs = ipairs
local DCS_CharacterShirtSlot = CharacterShirtSlot
local getItemQualityColor = GetItemQualityColor

-- ---------------------------
-- -- DCS Durability Frames --
-- ---------------------------

local DCSITEM_SLOT_FRAMES = {
	CharacterHeadSlot,CharacterNeckSlot,CharacterShoulderSlot,CharacterBackSlot,CharacterChestSlot,CharacterWristSlot,
	CharacterHandsSlot,CharacterWaistSlot,CharacterLegsSlot,CharacterFeetSlot,
	CharacterFinger0Slot,CharacterFinger1Slot,CharacterTrinket0Slot,CharacterTrinket1Slot,
	CharacterMainHandSlot,CharacterSecondaryHandSlot,CharacterRangedSlot,
}

local DCSITEM_SLOT_FRAMES_RIGHT = {
	[CharacterHeadSlot]={},[CharacterShoulderSlot]={},[CharacterChestSlot]={},[CharacterWristSlot]={},
}

local DCSITEM_SLOT_NECK_BACK_SHIRT = {
	[CharacterNeckSlot]={},[CharacterBackSlot]={},[DCS_CharacterShirtSlot]={},
}

local DCSITEM_TWO_HANDED_WEAPONS = {
	"Bows","Crossbows","Guns","Fishing Poles","Polearms","Staves","Two-Handed Axes","Two-Handed Maces","Two-Handed Swords",
}
	
--local duraMean
local duraTotal
local duraMaxTotal
local duraFinite = 0

--------------------
-- Create Objects --
--------------------
local duraMeanFS = DCS_CharacterShirtSlot:CreateFontString("FontString","OVERLAY","GameTooltipText") --text for average durability on shirt
	duraMeanFS:SetPoint("CENTER",DCS_CharacterShirtSlot,"CENTER",1,-2) --poisiton will be influenced by DCS_Set_Dura_Item_Positions()
	duraMeanFS:SetFont("Fonts\\FRIZQT__.TTF", 15, "THINOUTLINE")
	duraMeanFS:SetFormattedText("")

local duraMeanTexture = DCS_CharacterShirtSlot:CreateTexture(nil,"ARTWORK") --bar for average durability on shirt 

local duraDurabilityFrameFS = DurabilityFrame:CreateFontString("FontString","OVERLAY","GameTooltipText")
	duraDurabilityFrameFS:SetPoint("CENTER",DurabilityFrame,"CENTER",0,0)
	duraDurabilityFrameFS:SetFont("Fonts\\FRIZQT__.TTF", 16, "THINOUTLINE")
	duraDurabilityFrameFS:SetFormattedText("")
	
for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
	v.duratexture = v:CreateTexture(nil,"ARTWORK")

    v.durability = v:CreateFontString("FontString","OVERLAY","GameTooltipText")
    v.durability:SetFormattedText("")

    v.itemrepair = v:CreateFontString("FontString","OVERLAY","GameTooltipText")
    v.itemrepair:SetFormattedText("")
	
    v.ilevel = v:CreateFontString("FontString","OVERLAY","GameTooltipText")
    v.ilevel:SetFormattedText("")

    v.enchant = v:CreateFontString("FontString","OVERLAY","GameTooltipText")
	v.enchant:SetFormattedText("")
	
	v.itemcolor = v:CreateTexture(nil,"ARTWORK")
	v.itemcolor:SetAllPoints(v)

	v.ItemFrameOutlineTexture = v:CreateTexture(nil,"OVERLAY",nil)
	v.ItemFrameOutlineTexture:SetPoint("TOPLEFT", v, "TOPLEFT", -2, 2);
	v.ItemFrameOutlineTexture:SetPoint("BOTTOMRIGHT", v, "BOTTOMRIGHT", 2, -2);
	v.ItemFrameOutlineTexture:SetTexture("Interface\\Addons\\DejaClassicStats\\DCSArt\\WhiteIconFrame.blp")

	v.ItemFramehighlightTexture = v:CreateTexture(nil, "HIGHLIGHT",nil)
	v.ItemFramehighlightTexture:SetPoint("TOPLEFT", v, "TOPLEFT", -2, 2);
	v.ItemFramehighlightTexture:SetPoint("BOTTOMRIGHT", v, "BOTTOMRIGHT", 2, -2);
	v.ItemFramehighlightTexture:SetTexture("Interface\\COMMON\\WhiteIconFrame.blp")
end

local function DCS_Set_Item_Quality_Color_Outlines()
	for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
		v.ItemFrameOutlineTexture:SetVertexColor(0, 0, 0, 0);
		v.ItemFramehighlightTexture:SetVertexColor(0, 0, 0, 0);
		local itemLink = GetInventoryItemLink("player", v:GetID())
		if (itemLink==nil) then
			local iLikeCake = true
		else
			local qualityBordersChecked = gdbprivate.gdb.gdbdefaults.DejaClassicStatsItemQualityBorders.ItemQualityBordersChecked
			local qualityBordersAlpha
			if qualityBordersChecked then 
				qualityBordersAlpha = gdbprivate.gdb.gdbdefaults.QCOA_SetSliderValue.QCOA_SliderValue
			else
				qualityBordersAlpha = 0
			end
			local item = Item:CreateFromEquipmentSlot(v:GetID())
			local itemName, itemLink = GetItemInfo(itemLink)
			local r, g, b, hex = getItemQualityColor(C_Item.GetItemQualityByID(itemLink))
			v.ItemFrameOutlineTexture:SetVertexColor(r, g, b, qualityBordersAlpha);
			v.ItemFramehighlightTexture:SetVertexColor(r, g, b, qualityBordersAlpha);
		end
	end
end

	
gdbprivate.gdbdefaults.gdbdefaults.QCOA_SetSliderValue = {
	QCOA_SliderValue = 0.75,
}

-- Quality Color Outlines Alpha Slider:
local QCOA_Slider = CreateFrame("Slider", "QCOA_Slider", DejaClassicStatsPanel, "OptionsSliderTemplate")
	QCOA_Slider:RegisterEvent("PLAYER_LOGIN")
	QCOA_Slider:SetPoint("TOPLEFT", DejaClassicStatsPanel, "TOP", -25, -265)
	QCOA_Slider:SetWidth(200)
	QCOA_Slider:SetHeight(10)
	QCOA_Slider:SetOrientation('HORIZONTAL')
	QCOA_Slider:SetMinMaxValues(0.25, 1.0)
	QCOA_Slider.minValue, QCOA_Slider.maxValue = QCOA_Slider:GetMinMaxValues() 
	QCOA_Slider:SetValueStep(0.05)
	QCOA_Slider:SetObeyStepOnDrag(true)

	QCOA_Slider.tooltipText = "Set the intensity (alpha) of your equipped items' quality colored border glow in increments or decrements of 5. Default is 75." --Creates a tooltip on mouseover.

	getglobal(QCOA_Slider:GetName() .. 'Low'):SetText(QCOA_Slider.minValue); --Sets the left-side slider text (default is "Low").
	getglobal(QCOA_Slider:GetName() .. 'High'):SetText(QCOA_Slider.maxValue); --Sets the right-side slider text (default is "High").

	QCOA_Slider:Show()
			
	QCOA_Slider:SetScript("OnEvent", function(self, event, arg1)
		if event == "PLAYER_LOGIN" then
		local slideValue = gdbprivate.gdb.gdbdefaults.QCOA_SetSliderValue.QCOA_SliderValue
			self:SetValue(slideValue)
			getglobal(QCOA_Slider:GetName() .. 'Text'):SetFormattedText(L["Item Quality Glow"].." = (%.2f)", (slideValue)); --Sets the "title" text (top-centre of slider).
		end
	end)

	QCOA_Slider:SetScript("OnValueChanged", function(self, value) 
	local slideValue = QCOA_Slider:GetValue()			
		getglobal(QCOA_Slider:GetName() .. 'Text'):SetFormattedText(L["Item Quality Glow"].." = (%.2f)", (slideValue)); --Sets the "title" text (top-centre of slider).
		gdbprivate.gdb.gdbdefaults.QCOA_SetSliderValue.QCOA_SliderValue = slideValue
		if PaperDollFrame:IsVisible() then
			DCS_Set_Item_Quality_Color_Outlines() --Here to update on the events when PaperDoll is open.
		end
	end)

--TODO - setting of their values and checkbox states in frame meant for this purpose

local showavgdur --display of average durability on shirt
local showtextures --display of durability textures
local showdura --display of durability percentage on items
local showrepair --display of item repair cost
local showitemlevel --display of item's item level
local showenchant --display of item's enchant
local simpleitemcolor -- blacking out of item textures for easier seeing of info
local darkeritemcolor -- darkening but not blacking out of item textures for easier seeing of info
local otherinfoplacement --alternate display position of item repair cost, durability, and ilvl

local function puttop(fontstring,slot,size)
	if otherinfoplacement then
		if DCSITEM_SLOT_FRAMES_RIGHT[slot] or DCSITEM_SLOT_NECK_BACK_SHIRT[slot] then
			fontstring:SetPoint("LEFT",slot,"RIGHT",6,0)
		else
			fontstring:SetPoint("TOPRIGHT",slot,"TOPLEFT",-6,-2)
		end
		if (slot == CharacterMainHandSlot) then
			fontstring:ClearAllPoints()
			fontstring:SetPoint("RIGHT",slot,"LEFT",-2,-2)
		end
		if (slot == CharacterSecondaryHandSlot) then
			fontstring:ClearAllPoints()
			fontstring:SetPoint("BOTTOMLEFT",slot,"TOPLEFT",-6,15)
		end
		if (slot == CharacterRangedSlot) then
			fontstring:ClearAllPoints()
			fontstring:SetPoint("BOTTOMLEFT",slot,"TOPRIGHT",4,-8)
		end
	else
		fontstring:SetPoint("TOP",slot,"TOP",3,-2)
	end
	fontstring:SetFont("Fonts\\FRIZQT__.TTF", size, "THINOUTLINE")
end

local function putcenter(fontstring,slot,size)
	if otherinfoplacement then
		if DCSITEM_SLOT_FRAMES_RIGHT[slot] or DCSITEM_SLOT_NECK_BACK_SHIRT[slot] then
			fontstring:SetPoint("LEFT",slot,"RIGHT",10,-2)
		else
			fontstring:SetPoint("RIGHT",slot,"LEFT",-10,-2)
		end
		if (slot == CharacterMainHandSlot) then
			fontstring:ClearAllPoints()
			fontstring:SetPoint("RIGHT",slot,"LEFT",-2,-6)
		end
		if (slot == CharacterSecondaryHandSlot) then
			fontstring:ClearAllPoints()
			fontstring:SetPoint("CENTER",slot,"CENTER",1,-2)
		end
		if (slot == CharacterRangedSlot) then
			fontstring:ClearAllPoints()
			fontstring:SetPoint("TOPLEFT",slot,"BOTTOMRIGHT",8,0)
		end
	else
		fontstring:SetPoint("CENTER",slot,"CENTER",1,-2)
	end
	fontstring:SetFont("Fonts\\FRIZQT__.TTF", size, "THINOUTLINE")
end

local function putbottom(fontstring,slot,size)
	if otherinfoplacement then
		if DCSITEM_SLOT_FRAMES_RIGHT[slot] or DCSITEM_SLOT_NECK_BACK_SHIRT[slot] then
			fontstring:SetPoint("BOTTOMLEFT",slot,"BOTTOMRIGHT",6,2)
		else
			fontstring:SetPoint("RIGHT",slot,"LEFT",-6,0)
		end
		if (slot == CharacterMainHandSlot) then
			fontstring:ClearAllPoints()
			fontstring:SetPoint("BOTTOMRIGHT",slot,"BOTTOMLEFT",-2,0)
		end
		if (slot == CharacterRangedSlot) then
			fontstring:ClearAllPoints()
			fontstring:SetPoint("BOTTOMLEFT",slot,"BOTTOMRIGHT",4,-2)
		end
		if (slot == CharacterSecondaryHandSlot) then
			fontstring:ClearAllPoints()
			fontstring:SetPoint("BOTTOMRIGHT",slot,"TOPRIGHT",20,15)
		end
	else
		fontstring:SetPoint("BOTTOM",slot,"BOTTOM",1,0)
	end
	fontstring:SetFont("Fonts\\FRIZQT__.TTF", size, "THINOUTLINE")
end

local function putothercenter(fontstring,slot,size)
	if otherinfoplacement then
		if DCSITEM_SLOT_FRAMES_RIGHT[slot] or DCSITEM_SLOT_NECK_BACK_SHIRT[slot] then
			fontstring:SetPoint("LEFT",slot,"RIGHT",6,-4)
		else
			fontstring:SetPoint("TOPRIGHT",slot,"TOPLEFT",-6,-9)
		end
		if (slot == CharacterMainHandSlot) then
			fontstring:ClearAllPoints()
			fontstring:SetPoint("TOPRIGHT",slot,"TOPRIGHT",8,16)
		end
		if (slot == CharacterSecondaryHandSlot) then
			fontstring:ClearAllPoints()
			fontstring:SetPoint("TOPRIGHT",slot,"TOPRIGHT",8,16)
		end
		if (slot == CharacterRangedSlot) then
			fontstring:ClearAllPoints()
			fontstring:SetPoint("TOPRIGHT",slot,"TOPRIGHT",8,16)
		end
	else
		fontstring:SetPoint("TOP",slot,"TOP",3,-2)
	end
	fontstring:SetFont("Fonts\\FRIZQT__.TTF", size, "THINOUTLINE")
end

function putenchant(fontstring,slot,size)
	if showenchant then
		ShowDefaultStats = gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowDefaultStats.ShowDefaultStatsChecked
		if DCSITEM_SLOT_FRAMES_RIGHT[slot] or DCSITEM_SLOT_NECK_BACK_SHIRT[slot] then
			fontstring:SetPoint("TOPLEFT",slot,"TOPRIGHT",6,-2)
		else
			fontstring:SetPoint("BOTTOMRIGHT",slot,"BOTTOMLEFT",-6,2)
		end
		if (slot == CharacterMainHandSlot) then
			fontstring:ClearAllPoints()
			fontstring:SetPoint("TOPRIGHT",slot,"BOTTOMRIGHT",4,4)
		end
		if (slot == CharacterRangedSlot) then
			fontstring:ClearAllPoints()
			fontstring:SetPoint("TOPLEFT",slot,"BOTTOMLEFT",-4,4)
		end
		if ShowDefaultStats then
			if (slot == CharacterSecondaryHandSlot) then
				fontstring:ClearAllPoints()
				fontstring:SetPoint("BOTTOMLEFT",slot,"TOPLEFT",-6,2)
			end
			if (slot == CharacterWristSlot) then
				fontstring:SetPoint("TOPLEFT",slot,"TOPRIGHT",6,-10)
			end
		else
			if (slot == CharacterSecondaryHandSlot) then
				fontstring:ClearAllPoints()
				fontstring:SetPoint("BOTTOMLEFT",slot,"TOPLEFT",-6,6)
			end
		end
	end
	fontstring:SetFont("Fonts\\FRIZQT__.TTF", size, "THINOUTLINE")
end

local function putilevel(fontstring,slot,size)
	fontstring:SetPoint("CENTER",slot,"CENTER",1,-2)
	fontstring:SetFont("Fonts\\FRIZQT__.TTF", size, "THINOUTLINE")
end

local function DCS_Set_Dura_Item_Positions()
	--It encompasses item repair, durability and, indirectly, durability bars.
	--making it work with local to DCSDuraRepair.lua variable
	local showdura = gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowDuraChecked.ShowDuraSetChecked
	local showrepair = gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowItemRepairChecked.ShowItemRepairSetChecked
	local showenchant = gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowEnchantChecked.ShowEnchantSetChecked
	local abbrevEnchants = gdbprivate.gdb.gdbdefaults.DejaClassicStatsAbbrevEnchantsChecked.AbbrevEnchantsSetChecked
	local otherinfoplacement = gdbprivate.gdb.gdbdefaults.DejaClassicStatsAlternateInfoPlacement.AlternateInfoPlacementChecked
	--print("called DCS_Set_Dura_Item_Positions") --debug for later
	duraMeanFS:ClearAllPoints()

	putcenter(duraMeanFS,DCS_CharacterShirtSlot,15)
	for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
		v.durability:ClearAllPoints()
		v.itemrepair:ClearAllPoints()
		v.ilevel:ClearAllPoints()
		v.enchant:ClearAllPoints()
		if showitemlevel then
			if showdura then 
				if showrepair then
					puttop(v.durability,v,11)
					putbottom(v.itemrepair,v,11)
				else --not showrepair
					if otherinfoplacement then
						putothercenter(v.durability,v,15)
					else
						puttop(v.durability,v,11)
					end
				end
			else --not showdura
				if showrepair then
					if otherinfoplacement then
						putothercenter(v.itemrepair,v,15)
					else
						putbottom(v.itemrepair,v,11)
					end
				end
			end
			if otherinfoplacement then
				putilevel(v.ilevel,v,16)
			else
				if not (showdura or showrepair) then
					putilevel(v.ilevel,v,16)
				else
					putilevel(v.ilevel,v,14)
				end
			end
		else
			if showdura then 
				if showrepair then
					puttop(v.durability,v,11)
					putbottom(v.itemrepair,v,11)
				else --not showrepair
					if otherinfoplacement then
						putothercenter(v.durability,v,15)
					else
						putcenter(v.durability,v,15)
					end
				end
			else --not showdura
				if showrepair then
					if otherinfoplacement then
						putothercenter(v.itemrepair,v,15)
					else
						putcenter(v.itemrepair,v,15)
					end
				end
			end
		end
		if showenchant then
			putenchant(v.enchant,v,11)
		end
	end
end

---------------------------------
-- Durability Mean Calculation --
---------------------------------
function DCS_Mean_DurabilityCalc()
	addon.duraMean = 0
	duraTotal = 0
	duraMaxTotal = 0
	for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
		local slotId = v:GetID()
		local durCur, durMax = GetInventoryItemDurability(slotId)
		-- --------------------------
		-- -- Mean Durability Calc --
		-- --------------------------
		if durCur == nil then durCur = 0 end
		if durMax == nil then durMax = 0 end
		
		duraTotal = duraTotal + durCur
		duraMaxTotal = duraMaxTotal + durMax
	end
	if duraMaxTotal == 0 then 
		duraMaxTotal = 1
		duraTotal = 1 --if nothing to break then durability should be 100%
	end --puting outside of for loop
	addon.duraMean = ((duraTotal/duraMaxTotal)*100)
end		

-----------------------------------
-- Durability Frame Mean Display --
-----------------------------------
local function DCS_Durability_Frame_Mean_Display()
	--DCS_Mean_DurabilityCalc() -- DCS_Mean_DurabilityCalc called already before
	duraDurabilityFrameFS:SetFormattedText("%.0f%%", addon.duraMean)
	duraDurabilityFrameFS:Show()
--	print(addon.duraMean)
	if addon.duraMean == 100 then --If mean is 100 hide text % display
		duraDurabilityFrameFS:Hide()
	elseif addon.duraMean >= 80 then --If mean is 80% or greater color the text off-white.
		duraDurabilityFrameFS:SetTextColor(0.753, 0.753, 0.753)
	elseif addon.duraMean > 66 then --If mean is 66% or greater then color the text green.
		duraDurabilityFrameFS:SetTextColor(0, 1, 0)
	elseif addon.duraMean > 33 then --If mean is 33% or greater then color the text yellow.
		duraDurabilityFrameFS:SetTextColor(1, 1, 0)
	elseif addon.duraMean >= 0 then --If mean is 0% or greater then color the text red. Is this check needed?
		duraDurabilityFrameFS:SetTextColor(1, 0, 0)
	end
end

-----------------------------------
-- Mean Durability Shirt Display --
-----------------------------------
local function DCS_Mean_Durability()
	DCS_Mean_DurabilityCalc()
    if addon.duraMean < 10 then
		duraMeanFS:SetTextColor(1, 0, 0)
	elseif addon.duraMean < 33 then
		duraMeanFS:SetTextColor(1, 0, 0)
	elseif addon.duraMean < 66 then
	    duraMeanFS:SetTextColor(1, 1, 0)
	elseif addon.duraMean < 80 then
		duraMeanFS:SetTextColor(0, 1, 0)
	elseif addon.duraMean < 100 then
		duraMeanFS:SetTextColor(0.753, 0.753, 0.753)
	end
	if DurabilityFrame:IsVisible() then
		DCS_Durability_Frame_Mean_Display()
	end
end

----------------------------
-- Item Durability Colors --
----------------------------
local function DCS_Item_DurabilityTop()
	for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
		local slotId = v:GetID()
		local durCur, durMax = GetInventoryItemDurability(slotId)
		--if durCur == nil or durMax == nil then
		--	v.duratexture:SetColorTexture(0, 0, 0, 0)
		--	v.durability:SetFormattedText("")
		--elseif ( durCur == durMax ) then
		if ( durCur == durMax ) then
			--v.duratexture:SetColorTexture(0, 0, 0, 0) --moving texture stuff to textures
			v.durability:SetFormattedText("")
		else --if ( durCur ~= durMax ) then -- no need to check, can remain as comment for easier understanding
			duraFinite = ((durCur/durMax)*100)
			--print(duraFinite)
		    v.durability:SetFormattedText("%.0f%%", duraFinite)
			--if duraFinite == 100 then --this should be covered by durCur == durMax
			--	v.duratexture:SetColorTexture(0,  0, 0, 0)
			--	v.durability:SetTextColor(0, 0, 0, 0)
			--	print ("what is this")
			--elseif duraFinite > 66 then
			if duraFinite > 66 then
				--v.duratexture:SetColorTexture(0, 1, 0)
				v.durability:SetTextColor(0, 1, 0)
			elseif duraFinite > 33 then
				--v.duratexture:SetColorTexture(1, 1, 0)
				v.durability:SetTextColor(1, 1, 0)
			elseif duraFinite > 10 then
				--v.duratexture:SetColorTexture(1, 0, 0)
				v.durability:SetTextColor(1, 0, 0)
			else --if duraFinite <= 10 then -- no need to check, can remain as comment for easier understanding
				--v.duratexture:SetAllPoints(v) -Removed so green boxes do not appear when durability is at zero.
				--v.duratexture:SetColorTexture(1, 0, 0, 0.10)
				v.durability:SetTextColor(1, 0, 0)
			end
		end
		--DCS_Mean_DurabilityCalc() -- moving outside for loop
	end
	--DCS_Mean_DurabilityCalc() -- seems like it gets called even before this
end

gdbprivate.gdbdefaults.gdbdefaults.DejaClassicStatsShowDuraChecked = {
	ShowDuraSetChecked = true,
}	

local DCS_ShowDuraCheck = CreateFrame("CheckButton", "DCS_ShowDuraCheck", DejaClassicStatsPanel, "InterfaceOptionsCheckButtonTemplate")
	DCS_ShowDuraCheck:RegisterEvent("PLAYER_LOGIN")
    DCS_ShowDuraCheck:RegisterEvent("UPDATE_INVENTORY_DURABILITY")
	DCS_ShowDuraCheck:RegisterEvent("PLAYER_EQUIPMENT_CHANGED") --seems like UPDATE_INVENTORY_DURABILITY doesn't get triggered by equipping an item with the same name
	DCS_ShowDuraCheck:ClearAllPoints()
	DCS_ShowDuraCheck:SetPoint("TOPLEFT", "dcsItemsPanelCategoryFS", 7, -75)
	DCS_ShowDuraCheck:SetScale(1)
	DCS_ShowDuraCheck.tooltipText = L["Displays each equipped item's durability."] --Creates a tooltip on mouseover.
	_G[DCS_ShowDuraCheck:GetName() .. "Text"]:SetText(L["Item Durability"])

local event	--TODO: delete second variable event that might appear after merging
DCS_ShowDuraCheck:SetScript("OnEvent", function(self, event, ...)
	if event == "PLAYER_LOGIN" then
		showdura = gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowDuraChecked.ShowDuraSetChecked
		self:SetChecked(showdura)
		DCS_Set_Dura_Item_Positions()
	end
	if PaperDollFrame:IsVisible() then
		if showdura then
			DCS_Item_DurabilityTop()
		else
			for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
				v.durability:SetFormattedText("")
			end
		end
		local checked = gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowDuraChecked.ShowDuraSetChecked
		self:SetChecked(checked)
		DCS_Set_Dura_Item_Positions()
		if checked then
			DCS_Item_DurabilityTop()
		else
			for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
				v.durability:SetFormattedText("")
			end
		end
	end
end)

DCS_ShowDuraCheck:SetScript("OnClick", function(self)
	showdura = not showdura
	gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowDuraChecked.ShowDuraSetChecked = showdura
	DCS_Set_Dura_Item_Positions() --same line irrespectfully of the condtition
	if showdura then
		DCS_Item_DurabilityTop()
	else
		for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
			v.durability:SetFormattedText("")
		end
	end
	local checked = self:GetChecked()
	gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowDuraChecked.ShowDuraSetChecked = checked
	DCS_Set_Dura_Item_Positions() --same line irrespectfully of the condtition
	if checked then
		DCS_Item_DurabilityTop()
	else
		for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
			v.durability:SetFormattedText("")
		end
	end
end)

--------------------------------------
-- Durability Bar Textures Creation --
--------------------------------------
local function DCS_Durability_Bar_Textures()
	-- I see really similar loop in DCS_Item_DurabilityTop(), can't they be merged (of course, need to check whether they get called within the same condition)
	duraTotal = 0 --calculation of average for shirt bar is also here
	duraMaxTotal = 0
	for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
		local slotId = v:GetID()
		local durCur, durMax = GetInventoryItemDurability(slotId)
		if durCur == nil then durCur = 0 end
		if durMax == nil then durMax = 0 end
		duraTotal = duraTotal + durCur
		duraMaxTotal = duraMaxTotal + durMax
		if ( durCur == durMax ) then
			v.duratexture:SetColorTexture(0, 0, 0, 0)
		else --if ( durCur ~= durMax ) then -- no need to check, can remain as comment for easier understanding
			duraFinite = durCur/durMax
            if duraFinite > 0.66 then
	            v.duratexture:SetColorTexture(0, 1, 0)
		    elseif duraFinite > 0.33 then
				v.duratexture:SetColorTexture(1, 1, 0)
			elseif duraFinite > 0.10 then
				v.duratexture:SetColorTexture(1, 0, 0)
			else --if duraFinite <= 0.10 then -- no need to check, can remain as comment for easier understanding
				v.duratexture:SetColorTexture(1, 0, 0, 0.10)
			end
		    if DCSITEM_SLOT_FRAMES_RIGHT[v] then
		        v.duratexture:SetPoint("BOTTOMLEFT",v,"BOTTOMRIGHT",1,3)
			    v.duratexture:SetSize(4, (31*duraFinite))
			else
                v.duratexture:SetPoint("BOTTOMRIGHT",v,"BOTTOMLEFT",-2,3)
				v.duratexture:SetSize(3, (31*duraFinite))
			end
		    v.duratexture:Show()
		end
	end
	if duraMaxTotal == 0 then 
		duraMaxTotal = 1
		duraTotal = 1 --if nothing to break then durability should be 100%
	end
	local duraMean = duraTotal/duraMaxTotal
	duraMeanTexture:SetSize(4, 31*duraMean)
	if duraMean == 1 then 
		duraMeanTexture:SetColorTexture(0, 0, 0, 0)
	elseif duraMean < 0.10 then
		--duraMeanTexture:SetColorTexture(1, 0, 0)
		duraMeanTexture:SetColorTexture(1, 0, 0, 0.15)
	elseif duraMean < 0.33 then
		duraMeanTexture:SetColorTexture(1, 0, 0)
	elseif duraMean < 0.66 then
		duraMeanTexture:SetColorTexture(1, 1, 0)
	elseif duraMean < 0.80 then
		duraMeanTexture:SetColorTexture(0, 1, 0)
	else --if duraMean < 1 then -- no need to check, can remain as comment for easier understanding
		duraMeanTexture:SetColorTexture(0.753, 0.753, 0.753)
	end
	duraMeanTexture:ClearAllPoints()
	if duraMean > 0.10 then 
		duraMeanTexture:SetPoint("BOTTOMLEFT",DCS_CharacterShirtSlot,"BOTTOMRIGHT",1,3)
	else --if duraMean <= 0.10 then -- no need to check, can remain as comment for easier understanding
		duraMeanTexture:SetAllPoints(DCS_CharacterShirtSlot)
	end
end

gdbprivate.gdbdefaults.gdbdefaults.DejaClassicStatsShowDuraTextureChecked = {
	ShowDuraTextureSetChecked = true,
}	

local DCS_ShowDuraTextureCheck = CreateFrame("CheckButton", "DCS_ShowDuraTextureCheck", DejaClassicStatsPanel, "InterfaceOptionsCheckButtonTemplate")
	DCS_ShowDuraTextureCheck:RegisterEvent("PLAYER_LOGIN")
    DCS_ShowDuraTextureCheck:RegisterEvent("UPDATE_INVENTORY_DURABILITY")
	DCS_ShowDuraTextureCheck:RegisterEvent("PLAYER_EQUIPMENT_CHANGED") --seems like UPDATE_INVENTORY_DURABILITY doesn't get triggered by equipping an item with the same name
	DCS_ShowDuraTextureCheck:ClearAllPoints()
	DCS_ShowDuraTextureCheck:SetPoint("TOPLEFT", "dcsItemsPanelCategoryFS", 7, -35)
	DCS_ShowDuraTextureCheck:SetScale(1) 
	DCS_ShowDuraTextureCheck.tooltipText = L["Displays a durability bar next to each item."] --Creates a tooltip on mouseover.
	_G[DCS_ShowDuraTextureCheck:GetName() .. "Text"]:SetText(L["Durability Bars"])
	
DCS_ShowDuraTextureCheck:SetScript("OnEvent", function(self, event, ...)
	if event == "PLAYER_LOGIN" then
		showtextures = gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowDuraTextureChecked.ShowDuraTextureSetChecked
		self:SetChecked(showtextures)
	end
	--print("DCS_ShowDuraTextureCheck:SetScript(OnEvent)")
	if PaperDollFrame:IsVisible() then
		--print("PaperDollFrame:IsVisible()")
		if showtextures then
			--print("showtextures")
			DCS_Durability_Bar_Textures()
			--DCS_Mean_Durability() --average durability for bar near shirt should be in DCS_Durability_Bar_Textures()
			--DCS_Item_DurabilityTop() --all single item durability stuff should be in DCS_Durability_Bar_Textures()
			duraMeanTexture:Show()
		else
			for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
				v.duratexture:Hide()
			end
			duraMeanTexture:Hide()
		end
		local checked = gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowDuraTextureChecked.ShowDuraTextureSetChecked
		self:SetChecked(checked)
		if checked then
			DCS_Durability_Bar_Textures()
			DCS_Mean_Durability()
			DCS_Item_DurabilityTop()
			duraMeanTexture:Show()
		else
			for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
				v.duratexture:Hide()
			end
			duraMeanTexture:Hide()
		end
	end
end)

DCS_ShowDuraTextureCheck:SetScript("OnClick", function(self)
	showtextures = not showtextures
	gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowDuraTextureChecked.ShowDuraTextureSetChecked = showtextures
	if showtextures then
		DCS_Durability_Bar_Textures()
		--DCS_Mean_Durability() --average durability for bar near shirt should be in DCS_Durability_Bar_Textures()
		--DCS_Item_DurabilityTop() --all single item durability stuff should be in DCS_Durability_Bar_Textures()
		duraMeanTexture:Show()
	else
		for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
			v.duratexture:Hide()
		end
		duraMeanTexture:Hide()
	end
	local checked = self:GetChecked()
	gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowDuraTextureChecked.ShowDuraTextureSetChecked = checked
	if checked then
		DCS_Durability_Bar_Textures()
		DCS_Mean_Durability()
		DCS_Item_DurabilityTop()
		duraMeanTexture:Show()
	else
		for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
			v.duratexture:Hide()
		end
		duraMeanTexture:Hide()
	end
end)

------------------------
-- Average Durability --
------------------------

gdbprivate.gdbdefaults.gdbdefaults.DejaClassicStatsShowAverageRepairChecked = {
	ShowAverageRepairSetChecked = true,
}	

local DCS_ShowAverageDuraCheck = CreateFrame("CheckButton", "DCS_ShowAverageDuraCheck", DejaClassicStatsPanel, "InterfaceOptionsCheckButtonTemplate")
	DCS_ShowAverageDuraCheck:RegisterEvent("PLAYER_LOGIN")
    DCS_ShowAverageDuraCheck:RegisterEvent("UPDATE_INVENTORY_DURABILITY")
	DCS_ShowAverageDuraCheck:RegisterEvent("PLAYER_EQUIPMENT_CHANGED") --seems like UPDATE_INVENTORY_DURABILITY doesn't get triggered by equipping an item with the same name
	DCS_ShowAverageDuraCheck:ClearAllPoints()
	DCS_ShowAverageDuraCheck:SetPoint("TOPLEFT", "dcsItemsPanelCategoryFS", 7, -55)
	DCS_ShowAverageDuraCheck:SetScale(1)
	DCS_ShowAverageDuraCheck.tooltipText = L["Displays average item durability on the character shirt slot and durability frames."] --Creates a tooltip on mouseover.
	_G[DCS_ShowAverageDuraCheck:GetName() .. "Text"]:SetText(L["Average Durability"])
	
	DCS_ShowAverageDuraCheck:SetScript("OnEvent", function(self, event, ...)
		if event == "PLAYER_LOGIN" then
			showavgdur = gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowAverageRepairChecked.ShowAverageRepairSetChecked
			self:SetChecked(showavgdur)
		end
		--print(..., DurabilityFrame:IsVisible(),DurabilityFrame:IsShown())
		if showavgdur and (DurabilityFrame:IsVisible() or PaperDollFrame:IsVisible()) then
			DCS_Mean_Durability()
			if addon.duraMean == 100 then --check after calculation
				duraMeanFS:SetFormattedText("")
			else
				duraMeanFS:SetFormattedText("%.0f%%", addon.duraMean)
			end
		else
			duraMeanFS:SetFormattedText("")
			duraDurabilityFrameFS:Hide()
		end
	end)

	DCS_ShowAverageDuraCheck:SetScript("OnClick", function(self)
		showavgdur = not showavgdur
		gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowAverageRepairChecked.ShowAverageRepairSetChecked = showavgdur
		if showavgdur then
			DCS_Mean_Durability()
			if addon.duraMean == 100 then --check after calculation
				duraMeanFS:SetFormattedText("")
			else
				duraMeanFS:SetFormattedText("%.0f%%", addon.duraMean)
			end
		else
			duraMeanFS:SetFormattedText("")
			duraDurabilityFrameFS:Hide()
		end
	end)
	
----------------------
-- Item Repair Cost --
----------------------
local function DCS_Item_RepairCostBottom()
	for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
		local slotId = v:GetID()
		local scanTool = CreateFrame("GameTooltip")
			scanTool:ClearLines()
		local repairitemCost = select(3, scanTool:SetInventoryItem("player", slotId))
		if (repairitemCost<=0) then
			v.itemrepair:SetFormattedText("")
		elseif (repairitemCost>999999) then -- 99G 99s 99c
			v.itemrepair:SetTextColor(1, 0.843, 0)
			v.itemrepair:SetFormattedText("%.0fg", (repairitemCost/10000))
		elseif (repairitemCost>9999) then -- 99s 99c
			v.itemrepair:SetTextColor(1, 0.843, 0)
			v.itemrepair:SetFormattedText("%.2fg", (repairitemCost/10000))
		elseif (repairitemCost>99) then -- 99c
			v.itemrepair:SetTextColor(0.753, 0.753, 0.753)
			v.itemrepair:SetFormattedText("%.2fs", (repairitemCost/100))
		else
			v.itemrepair:SetTextColor(0.722, 0.451, 0.200)
			v.itemrepair:SetFormattedText("%.0fc", repairitemCost)
		end
	end
end


gdbprivate.gdbdefaults.gdbdefaults.DejaClassicStatsShowItemRepairChecked = {
	ShowItemRepairSetChecked = true,
}	

local DCS_ShowItemRepairCheck = CreateFrame("CheckButton", "DCS_ShowItemRepairCheck", DejaClassicStatsPanel, "InterfaceOptionsCheckButtonTemplate")
	DCS_ShowItemRepairCheck:RegisterEvent("PLAYER_LOGIN")
	DCS_ShowItemRepairCheck:RegisterEvent("UPDATE_INVENTORY_DURABILITY")
	DCS_ShowItemRepairCheck:RegisterEvent("PLAYER_EQUIPMENT_CHANGED") --seems like UPDATE_INVENTORY_DURABILITY doesn't get triggered by equipping an item with the same name
	DCS_ShowItemRepairCheck:RegisterEvent("MERCHANT_SHOW")
	DCS_ShowItemRepairCheck:RegisterEvent("MERCHANT_CLOSED") --without this event repair cost should remain unchanged from the last vendor
	DCS_ShowItemRepairCheck:ClearAllPoints()
	DCS_ShowItemRepairCheck:SetPoint("TOPLEFT", "dcsItemsPanelCategoryFS", 7, -95)
	DCS_ShowItemRepairCheck:SetScale(1)
	DCS_ShowItemRepairCheck.tooltipText = L["Displays each equipped item's repair cost."] --Creates a tooltip on mouseover.
	_G[DCS_ShowItemRepairCheck:GetName() .. "Text"]:SetText(L["Item Repair Cost"])
	
DCS_ShowItemRepairCheck:SetScript("OnEvent", function(self, event, ...)
	if event == "PLAYER_LOGIN" then
		-- print(self:GetChecked())
		showrepair = gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowItemRepairChecked.ShowItemRepairSetChecked
		self:SetChecked(showrepair)
		DCS_Set_Dura_Item_Positions()
	end
	--print("want to recalculate repairs")
	if PaperDollFrame:IsVisible() then
		--print("recalculating repairs")
		if showrepair then
			DCS_Item_RepairCostBottom()
		else
			for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
				v.itemrepair:SetFormattedText("")
			end
		end
		local checked = gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowItemRepairChecked.ShowItemRepairSetChecked
		self:SetChecked(checked)
		DCS_Set_Dura_Item_Positions()
		if checked then
			DCS_Item_RepairCostBottom()
		else
			for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
				v.itemrepair:SetFormattedText("")
			end
		end
	end
end)

DCS_ShowItemRepairCheck:SetScript("OnClick", function(self)
	showrepair = not showrepair
	gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowItemRepairChecked.ShowItemRepairSetChecked = showrepair
	DCS_Set_Dura_Item_Positions()
	if showrepair then
		DCS_Item_RepairCostBottom()
	else
		for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
			v.itemrepair:SetFormattedText("")
		end
	end
	local checked = self:GetChecked()
	gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowItemRepairChecked.ShowItemRepairSetChecked = checked
	DCS_Set_Dura_Item_Positions()
	if checked then
		DCS_Item_RepairCostBottom()
	else
		for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
			v.itemrepair:SetFormattedText("")
		end
	end
end)

local function attempt_ilvl(v,attempts)
	if attempts > 0 then
		local item = Item:CreateFromEquipmentSlot(v:GetID())
		local value = item:GetCurrentItemLevel()
		if value then --ilvl of nil probably indicates that there's no tem in that slot
			if value > 0 then --ilvl of 0 probably indicates that item is not fully loaded
				v.ilevel:SetTextColor(getItemQualityColor(item:GetItemQuality())) --upvalue call
				v.ilevel:SetText(value)
			else
				C_Timer.After(0.2, function() attempt_ilvl(v,attempts-1) end)
			end
		else
			v.ilevel:SetText("")
		end
	end
end

local function DCS_Item_Level_Center()
	for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
		attempt_ilvl(v,20)
	end
end

gdbprivate.gdbdefaults.gdbdefaults.DejaClassicStatsShowItemLevelChecked = {
	ShowItemLevelSetChecked = true,
}

local DCS_ShowItemLevelCheck = CreateFrame("CheckButton", "DCS_ShowItemLevelCheck", DejaClassicStatsPanel, "InterfaceOptionsCheckButtonTemplate")
	DCS_ShowItemLevelCheck:RegisterEvent("PLAYER_LOGIN")
	DCS_ShowItemLevelCheck:ClearAllPoints()
	DCS_ShowItemLevelCheck:SetPoint("TOPLEFT", "dcsItemsPanelCategoryFS", 7, -15)
	DCS_ShowItemLevelCheck:SetScale(1)
	DCS_ShowItemLevelCheck.tooltipText = L["Displays the item level of each equipped item. Caveat; Item level is relatively meaningless in Classic."] --Creates a tooltip on mouseover.
	_G[DCS_ShowItemLevelCheck:GetName() .. "Text"]:SetText(L["Item Level"])
	
DCS_ShowItemLevelCheck:SetScript("OnEvent", function(self, event, ...)
	showitemlevel = gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowItemLevelChecked.ShowItemLevelSetChecked
	self:SetChecked(showitemlevel)
	DCS_Set_Dura_Item_Positions()
	DCS_Item_Level_Center() --why it is called
end)

DCS_ShowItemLevelCheck:SetScript("OnClick", function(self)
	showitemlevel = not showitemlevel
	gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowItemLevelChecked.ShowItemLevelSetChecked = showitemlevel
	DCS_Set_Dura_Item_Positions() --is this call needed? (Yes, it is -Deja)
	if showitemlevel then --TODO: rewrite of DCS_Item_Level_Center because in 3 places the same code
		DCS_Item_Level_Center()
	else
		for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
			v.ilevel:SetFormattedText("")
		end
	end
end)

local DCS_ShowItemLevelChange = CreateFrame("Frame", "DCS_ShowItemLevelChange", UIParent)
	DCS_ShowItemLevelChange:RegisterEvent("PLAYER_EQUIPMENT_CHANGED")
	
DCS_ShowItemLevelChange:SetScript("OnEvent", function(self, event, ...)
	if PaperDollFrame:IsVisible() then
		--print("PaperDollFrame:IsVisible")
		if showitemlevel then
		--print("showitemlevel")
			C_Timer.After(0.25, DCS_Item_Level_Center) --Event fires before Artifact changes so we have to wait a fraction of a second.
		else
			for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
				v.ilevel:SetFormattedText("")
			end
		end
	end
end)

gdbprivate.gdbdefaults.gdbdefaults.DejaClassicStatsSimpleItemColorChecked = {
	SimpleItemColorChecked = false,
	DarkerItemColorChecked = false,
}

local function paintblack()
	for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
		if simpleitemcolor then
			v.itemcolor:SetColorTexture(0, 0, 0, 1)
			v.itemcolor:Show()
		elseif darkeritemcolor then
			v.itemcolor:SetColorTexture(0, 0, 0, 0.6)
			v.itemcolor:Show()
		else
			v.itemcolor:Hide()
		end
	end
end

local DCS_SimpleItemColorCheck = CreateFrame("CheckButton", "DCS_SimpleItemColorCheck", DejaClassicStatsPanel, "InterfaceOptionsCheckButtonTemplate")
	DCS_SimpleItemColorCheck:RegisterEvent("PLAYER_LOGIN")
	DCS_SimpleItemColorCheck:ClearAllPoints()
	DCS_SimpleItemColorCheck:SetPoint("TOPLEFT", "dcsItemsPanelCategoryFS", 7, -135)
	DCS_SimpleItemColorCheck:SetScale(1)
	DCS_SimpleItemColorCheck.tooltipText = L["Black item icons to make text more visible."] --Creates a tooltip on mouseover.
	_G[DCS_SimpleItemColorCheck:GetName() .. "Text"]:SetText(L["Black Item Icons"])

local DCS_DarkerItemColorCheck = CreateFrame("CheckButton", "DCS_DarkerItemColorCheck", DejaClassicStatsPanel, "InterfaceOptionsCheckButtonTemplate")
	DCS_DarkerItemColorCheck:ClearAllPoints()
	DCS_DarkerItemColorCheck:SetPoint("TOPLEFT", "dcsItemsPanelCategoryFS", 7, -115)
	DCS_DarkerItemColorCheck:SetScale(1)
	DCS_DarkerItemColorCheck.tooltipText = L["Darken item icons to make text more visible."] --Creates a tooltip on mouseover.
	_G[DCS_DarkerItemColorCheck:GetName() .. "Text"]:SetText(L["Darken Item Icons"])

DCS_SimpleItemColorCheck:SetScript("OnEvent", function(self, event, ...)
	simpleitemcolor = gdbprivate.gdb.gdbdefaults.DejaClassicStatsSimpleItemColorChecked.SimpleItemColorChecked
	darkeritemcolor = gdbprivate.gdb.gdbdefaults.DejaClassicStatsSimpleItemColorChecked.DarkerItemColorChecked
	self:SetChecked(simpleitemcolor)
	DCS_DarkerItemColorCheck:SetChecked(darkeritemcolor)
	paintblack()
end)

DCS_SimpleItemColorCheck:SetScript("OnClick", function(self)
	simpleitemcolor = not simpleitemcolor
	gdbprivate.gdb.gdbdefaults.DejaClassicStatsSimpleItemColorChecked.SimpleItemColorChecked = simpleitemcolor
	if simpleitemcolor then
		DCS_DarkerItemColorCheck:SetChecked(false)
		gdbprivate.gdb.gdbdefaults.DejaClassicStatsSimpleItemColorChecked.DarkerItemColorChecked = false
		darkeritemcolor = false
	end
	paintblack()
end)

DCS_DarkerItemColorCheck:SetScript("OnClick", function(self)
	darkeritemcolor = not darkeritemcolor
	gdbprivate.gdb.gdbdefaults.DejaClassicStatsSimpleItemColorChecked.DarkerItemColorChecked = darkeritemcolor
	if darkeritemcolor then
		DCS_SimpleItemColorCheck:SetChecked(false)
		gdbprivate.gdb.gdbdefaults.DejaClassicStatsSimpleItemColorChecked.SimpleItemColorChecked = false
		simpleitemcolor = false
	end
	paintblack()
end)

-- local DCS_SimpleItemColor = CreateFrame("Frame", "DCS_SimpleItemColor", UIParent) --Needed? Doesn't seem so.
-- 	DCS_SimpleItemColor:RegisterEvent("PLAYER_EQUIPMENT_CHANGED")
	
-- 	DCS_SimpleItemColor:SetScript("OnEvent", function(self, event, ...)
-- 		if PaperDollFrame:IsVisible() then
-- 			paintblack()
-- 		end
-- 	end)

local DCS_ENCHANT_IDS = {
	[1] = "Rockbiter 3",
	[2] = "Frostbrand 1",
	[3] = "Flametongue 3",
	[4] = "Flametongue 2",
	[5] = "Flametongue 1",
	[6] = "Rockbiter 2",
	[7] = "Deadly Poison",
	[8] = "Deadly Poison II",
	[9] = "Poison (15 Dmg)",
	[10] = "Poison (20 Dmg)",
	[11] = "Poison (25 Dmg)",
	[12] = "Frostbrand 2",
	[13] = "Sharpened (+3 Damage)",
	[14] = "Sharpened (+4 Damage)",
	[15] = "Reinforced (+8 Armor)",
	[16] = "Reinforced (+16 Armor)",
	[17] = "Reinforced (+24 Armor)",
	[18] = "Reinforced (+32 Armor)",
	[19] = "Weighted (+2 Damage)",
	[20] = "Weighted (+3 Damage)",
	[21] = "Weighted (+4 Damage)",
	[22] = "Crippling Poison",
	[23] = "Mind-numbing Poison II",
	[24] = "+5 Mana",
	[25] = "Shadow Oil",
	[26] = "Frost Oil",
	[27] = "Sundered",
	[28] = "+4 All Resistances",
	[29] = "Rockbiter 1",
	[30] = "Scope (+1 Damage)",
	[31] = "+4 Beastslaying",
	[32] = "Scope (+2 Damage)",
	[33] = "Scope (+3 Damage)",
	[34] = "Counterweight (+20 Haste Rating)",
	[35] = "Mind Numbing Poison",
	[36] = "Enchant: Fiery Blaze",
	[37] = "Steel Weapon Chain",
	[38] = "+5 Defense Rating",
	[39] = "Sharpened (+1 Damage)",
	[40] = "Sharpened (+2 Damage)",
	[41] = "+5 Health",
	[42] = "Poison (Instant 20)",
	[43] = "Iron Spike (8-12)",
	[44] = "Absorption (10)",
	[63] = "Absorption (25)",
	[64] = "+3 Spirit",
	[65] = "+1 All Resistances",
	[66] = "+1 Stamina",
	[67] = "+1 Damage",
	[68] = "+1 Strength",
	[69] = "+2 Strength",
	[70] = "+3 Strength",
	[71] = "+1 Stamina",
	[72] = "+2 Stamina",
	[73] = "+3 Stamina",
	[74] = "+1 Agility",
	[75] = "+2 Agility",
	[76] = "+3 Agility",
	[77] = "+2 Damage",
	[78] = "+3 Damage",
	[79] = "+1 Intellect",
	[80] = "+2 Intellect",
	[81] = "+3 Intellect",
	[82] = "+1 Spirit",
	[83] = "+2 Spirit",
	[84] = "+3 Spirit",
	[85] = "+3 Armor",
	[86] = "+8 Armor",
	[87] = "+12 Armor",
	[89] = "+16 Armor",
	[90] = "+4 Agility",
	[91] = "+5 Agility",
	[92] = "+6 Agility",
	[93] = "+7 Agility",
	[94] = "+4 Intellect",
	[95] = "+5 Intellect",
	[96] = "+6 Intellect",
	[97] = "+7 Intellect",
	[98] = "+4 Spirit",
	[99] = "+5 Spirit",
	[100] = "+6 Spirit",
	[101] = "+7 Spirit",
	[102] = "+4 Stamina",
	[103] = "+5 Stamina",
	[104] = "+6 Stamina",
	[105] = "+7 Stamina",
	[106] = "+4 Strength",
	[107] = "+5 Strength",
	[108] = "+6 Strength",
	[109] = "+7 Strength",
	[110] = "+1 Defense Rating",
	[111] = "+2 Defense Rating",
	[112] = "+3 Defense Rating",
	[113] = "+4 Defense Rating",
	[114] = "+5 Defense Rating",
	[115] = "+6 Defense Rating",
	[116] = "+7 Defense Rating",
	[117] = "+4 Damage",
	[118] = "+5 Damage",
	[119] = "+6 Damage",
	[120] = "+7 Damage",
	[121] = "+20 Armor",
	[122] = "+24 Armor",
	[123] = "+28 Armor",
	[124] = "Flametongue Totem 1",
	[125] = "+1 Sword Skill",
	[126] = "+2 Sword Skill",
	[127] = "+3 Sword Skill",
	[128] = "+4 Sword Skill",
	[129] = "+5 Sword Skill",
	[130] = "+6 Sword Skill",
	[131] = "+7 Sword Skill",
	[132] = "+1 Two-Handed Sword Skill",
	[133] = "+2 Two-Handed Sword Skill",
	[134] = "+3 Two-Handed Sword Skill",
	[135] = "+4 Two-Handed Sword Skill",
	[136] = "+5 Two-Handed Sword Skill",
	[137] = "+6 Two-Handed Sword Skill",
	[138] = "+7 Two-Handed Sword Skill",
	[139] = "+1 Mace Skill",
	[140] = "+2 Mace Skill",
	[141] = "+3 Mace Skill",
	[142] = "+4 Mace Skill",
	[143] = "+5 Mace Skill",
	[144] = "+6 Mace Skill",
	[145] = "+7 Mace Skill",
	[146] = "+1 Two-Handed Mace Skill",
	[147] = "+2 Two-Handed Mace Skill",
	[148] = "+3 Two-Handed Mace Skill",
	[149] = "+4 Two-Handed Mace Skill",
	[150] = "+5 Two-Handed Mace Skill",
	[151] = "+6 Two-Handed Mace Skill",
	[152] = "+7 Two-Handed Mace Skill",
	[153] = "+1 Axe Skill",
	[154] = "+2 Axe Skill",
	[155] = "+3 Axe Skill",
	[156] = "+4 Axe Skill",
	[157] = "+5 Axe Skill",
	[158] = "+6 Ase Skill",
	[159] = "+7 Axe Skill",
	[160] = "+1 Two-Handed Axe Skill",
	[161] = "+2 Two-Handed Axe Skill",
	[162] = "+3 Two-Handed Axe Skill",
	[163] = "+4 Two-Handed Axe Skill",
	[164] = "+5 Two-Handed Axe Skill",
	[165] = "+6 Two-Handed Axe Skill",
	[166] = "+7 Two-Handed Axe Skill",
	[167] = "+1 Dagger Skill",
	[168] = "+2 Dagger Skill",
	[169] = "+3 Dagger Skill",
	[170] = "+4 Dagger Skill",
	[171] = "+5 Dagger Skill",
	[172] = "+6 Dagger Skill",
	[173] = "+7 Dagger Skill",
	[174] = "+1 Gun Skill",
	[175] = "+2 Gun Skill",
	[176] = "+3 Gun Skill",
	[177] = "+4 Gun Skill",
	[178] = "+5 Gun Skill",
	[179] = "+6 Gun Skill",
	[180] = "+7 Gun Skill",
	[181] = "+1 Bow Skill",
	[182] = "+2 Bow Skill",
	[183] = "+3 Bow Skill",
	[184] = "+4 Bow Skill",
	[185] = "+5 Bow Skill",
	[186] = "+6 Bow Skill",
	[187] = "+7 Bow Skill",
	[188] = "+2 Beast Slaying",
	[189] = "+4 Beast Slaying",
	[190] = "+6 Beast Slaying",
	[191] = "+8 Beast Slaying",
	[192] = "+10 Beast Slaying",
	[193] = "+12 Beast Slaying",
	[194] = "+14 Beast Slaying",
	[195] = "+14 Critical Strike Rating",
	[196] = "+28 Critical Strike Rating",
	[197] = "+42 Critical Strike Rating",
	[198] = "+56 Critical Strike Rating",
	[199] = "10% On Get Hit: Shadow Bolt (10 Damage)",
	[200] = "10% On Get Hit: Shadow Bolt (20 Damage)",
	[201] = "10% On Get Hit: Shadow Bolt (30 Damage)",
	[202] = "10% On Get Hit: Shadow Bolt (40 Damage)",
	[203] = "10% On Get Hit: Shadow Bolt (50 Damage)",
	[204] = "10% On Get Hit: Shadow Bolt (60 Damage)",
	[205] = "10% On Get Hit: Shadow Bolt (70 Damage)",
	[206] = "+1 Spell Power",
	[207] = "+2 Spell Power",
	[208] = "+4 Spell Power",
	[209] = "+5 Spell Power",
	[210] = "+6 Spell Power",
	[211] = "+7 Spell Power",
	[212] = "+8 Spell Power",
	[213] = "+1 Fire Spell Damage",
	[214] = "+3 Fire Spell Damage",
	[215] = "+4 Fire Spell Damage",
	[216] = "+6 Fire Spell Damage",
	[217] = "+7 Fire Spell Damage",
	[218] = "+9 Fire Spell Damage",
	[219] = "+10 Fire Spell Damage",
	[220] = "+1 Nature Spell Damage",
	[221] = "+3 Nature Spell Damage",
	[222] = "+4 Nature Spell Damage",
	[223] = "+6 Nature Spell Damage",
	[224] = "+7 Nature Spell Damage",
	[225] = "+9 Nature Spell Damage",
	[226] = "+10 Nature Spell Damage",
	[227] = "+1 Frost Spell Damage",
	[228] = "+3 Frost Spell Damage",
	[229] = "+4 Frost Spell Damage",
	[230] = "+6 Frost Spell Damage",
	[231] = "+7 Frost Spell Damage",
	[232] = "+9 Frost Spell Damage",
	[233] = "+10 Frost Spell Damage",
	[234] = "+1 Shadow Spell Damage",
	[235] = "+3 Shadow Spell Damage",
	[236] = "+4 Shadow Spell Damage",
	[237] = "+6 Shadow Spell Damage",
	[238] = "+7 Shadow Spell Damage",
	[239] = "+9 Shadow Spell Damage",
	[240] = "+10 Shadow Spell Damage",
	[241] = "+2 Weapon Damage",
	[242] = "+15 Health",
	[243] = "+1 Spirit",
	[244] = "+4 Intellect",
	[245] = "+5 Armor",
	[246] = "+20 Mana",
	[247] = "+1 Agility",
	[248] = "+1 Strength",
	[249] = "+2 Beastslaying",
	[250] = "+1 Weapon Damage",
	[251] = "+1 Intellect",
	[252] = "+6 Spirit",
	[253] = "Absorption (50)",
	[254] = "+25 Health",
	[255] = "+3 Spirit",
	[256] = "+5 Fire Resistance",
	[257] = "+10 Armor",
	[263] = "Fishing Lure (+25 Fishing Skill)",
	[264] = "Fishing Lure (+50 Fishing Skill)",
	[265] = "Fishing Lure (+75 Fishing Skill)",
	[266] = "Fishing Lure (+100 Fishing Skill)",
	[283] = "Windfury 1",
	[284] = "Windfury 2",
	[285] = "Flametongue Totem 2",
	[286] = "+2 Weapon Fire Damage",
	[287] = "+4 Weapon Fire Damage",
	[288] = "+6 Weapon Fire Damage",
	[289] = "+8 Weapon Fire Damage",
	[290] = "+10 Weapon Fire Damage",
	[291] = "+12 Weapon Fire Damage",
	[292] = "+14 Weapon Fire Damage",
	[303] = "Orb of Fire",
	[323] = "Instant Poison",
	[324] = "Instant Poison II",
	[325] = "Instant Poison III",
	[343] = "+8 Agility",
	[344] = "+32 Armor",
	[345] = "+40 Armor",
	[346] = "+36 Armor",
	[347] = "+44 Armor",
	[348] = "+48 Armor",
	[349] = "+9 Agility",
	[350] = "+8 Intellect",
	[351] = "+8 Spirit",
	[352] = "+8 Strength",
	[353] = "+8 Stamina",
	[354] = "+9 Intellect",
	[355] = "+9 Spirit",
	[356] = "+9 Stamina",
	[357] = "+9 Strength",
	[358] = "+10 Agility",
	[359] = "+10 Intellect",
	[360] = "+10 Spirit",
	[361] = "+10 Stamina",
	[362] = "+10 Strength",
	[363] = "+11 Agility",
	[364] = "+11 Intellect",
	[365] = "+11 Spirit",
	[366] = "+11 Stamina",
	[367] = "+11 Strength",
	[368] = "+12 Agility",
	[369] = "+12 Intellect",
	[370] = "+12 Spirit",
	[371] = "+12 Stamina",
	[372] = "+12 Strength",
	[383] = "+52 Armor",
	[384] = "+56 Armor",
	[385] = "+60 Armor",
	[386] = "+16 Armor",
	[387] = "+17 Armor",
	[388] = "+18 Armor",
	[389] = "+19 Armor",
	[403] = "+13 Agility",
	[404] = "+14 Agility",
	[405] = "+13 Intellect",
	[406] = "+14 Intellect",
	[407] = "+13 Spirit",
	[408] = "+14 Spirit",
	[409] = "+13 Stamina",
	[410] = "+13 Strength",
	[411] = "+14 Stamina",
	[412] = "+14 Strength",
	[423] = "+1 Spell Power",
	[424] = "+2 Spell Power",
	[425] = "Black Temple Dummy",
	[426] = "+5 Spell Power",
	[427] = "+6 Spell Power",
	[428] = "+7 Spell Power",
	[429] = "+8 Spell Power",
	[430] = "+9 Spell Power",
	[431] = "+11 Spell Power",
	[432] = "+12 Spell Power",
	[433] = "+11 Fire Spell Damage",
	[434] = "+13 Fire Spell Damage",
	[435] = "+14 Fire Spell Damage",
	[436] = "+70 Critical Strike Rating",
	[437] = "+11 Frost Spell Damage",
	[438] = "+13 Frost Spell Damage",
	[439] = "+14 Frost Spell Damage",
	[440] = "+9 Spell Power",
	[441] = "+11 Spell Power",
	[442] = "+12 Spell Power",
	[443] = "+11 Nature Spell Damage",
	[444] = "+13 Nature Spell Damage",
	[445] = "+14 Nature Spell Damage",
	[446] = "+11 Shadow Spell Damage",
	[447] = "+13 Shadow Spell Damage",
	[448] = "+14 Shadow Spell Damage",
	[463] = "Mithril Spike (16-20)",
	[464] = "+4% Mount Speed",
	[483] = "Sharpened (+6 Damage)",
	[484] = "Weighted (+6 Damage)",
	[503] = "Rockbiter 4",
	[504] = "+80 Rockbiter",
	[523] = "Flametongue 4",
	[524] = "Frostbrand 3",
	[525] = "Windfury 3",
	[543] = "Flametongue Totem 3",
	[563] = "Windfury Totem 2",
	[564] = "Windfury Totem 3",
	[583] = "+1 Agility / +1 Spirit",
	[584] = "+1 Agility / +1 Intellect",
	[585] = "+1 Agility / +1 Stamina",
	[586] = "+1 Agility / +1 Strength",
	[587] = "+1 Intellect / +1 Spirit",
	[588] = "+1 Intellect / +1 Stamina",
	[589] = "+1 Intellect / +1 Strength",
	[590] = "+1 Spirit / +1 Stamina",
	[591] = "+1 Spirit / +1 Strength",
	[592] = "+1 Stamina / +1 Strength",
	[603] = "Crippling Poison II",
	[623] = "Instant Poison IV",
	[624] = "Instant Poison V",
	[625] = "Instant Poison VI",
	[626] = "Deadly Poison III",
	[627] = "Deadly Poison IV",
	[643] = "Mind-Numbing Poison III",
	[663] = "Scope (+5 Damage)",
	[664] = "Scope (+7 Damage)",
	[683] = "Rockbiter 6",
	[684] = "+15 Strength",
	[703] = "Wound Poison",
	[704] = "Wound Poison II",
	[705] = "Wound Poison III",
	[706] = "Wound Poison IV",
	[723] = "+3 Intellect",
	[724] = "+3 Stamina",
	[743] = "+2 Stealth",
	[744] = "+20 Armor",
	[763] = "+5 Shield Block Rating",
	[783] = "+10 Armor",
	[803] = "Fiery Weapon",
	[804] = "+10 Shadow Resistance",
	[805] = "+4 Weapon Damage",
	[823] = "+3 Strength",
	[843] = "+30 Mana",
	[844] = "+2 Mining",
	[845] = "+2 Herbalism",
	[846] = "+2 Fishing",
	[847] = "+1 All Stats",
	[848] = "+30 Armor",
	[849] = "+3 Agility",
	[850] = "+35 Health",
	[851] = "+5 Spirit",
	[852] = "+5 Stamina",
	[853] = "+6 Beastslaying",
	[854] = "+6 Elemental Slayer",
	[855] = "+5 Fire Resistance",
	[856] = "+5 Strength",
	[857] = "+50 Mana",
	[863] = "+10 Shield Block Rating",
	[864] = "+4 Weapon Damage",
	[865] = "+5 Skinning",
	[866] = "+2 All Stats",
	[883] = "+15 Agility",
	[884] = "+50 Armor",
	[903] = "+3 All Resistances",
	[904] = "+5 Agility",
	[905] = "+5 Intellect",
	[906] = "+5 Mining",
	[907] = "+7 Spirit",
	[908] = "+50 Health",
	[909] = "+5 Herbalism",
	[910] = "Increased Stealth",
	[911] = "Minor Speed Increase",
	[912] = "Demonslaying",
	[913] = "+65 Mana",
	[923] = "+5 Defense Rating",
	[924] = "+2 Defense Rating",
	[925] = "+3 Defense Rating",
	[926] = "+8 Frost Resistance",
	[927] = "+7 Strength",
	[928] = "+3 All Stats",
	[929] = "+7 Stamina",
	[930] = "+2% Mount Speed",
	[931] = "+10 Haste Rating",
	[943] = "+3 Weapon Damage",
	[963] = "+7 Weapon Damage",
	[983] = "+16 Agility",
	[1003] = "Venomhide Poison",
	[1023] = "Feedback 1",
	[1043] = "+16 Strength",
	[1044] = "+17 Strength",
	[1045] = "+18 Strength",
	[1046] = "+19 Strength",
	[1047] = "+20 Strength",
	[1048] = "+21 Strength",
	[1049] = "+22 Strength",
	[1050] = "+23 Strength",
	[1051] = "+24 Strength",
	[1052] = "+25 Strength",
	[1053] = "+26 Strength",
	[1054] = "+27 Strength",
	[1055] = "+28 Strength",
	[1056] = "+29 Strength",
	[1057] = "+30 Strength",
	[1058] = "+31 Strength",
	[1059] = "+32 Strength",
	[1060] = "+33 Strength",
	[1061] = "+34 Strength",
	[1062] = "+35 Strength",
	[1063] = "+36 Strength",
	[1064] = "+37 Strength",
	[1065] = "+38 Strength",
	[1066] = "+39 Strength",
	[1067] = "+40 Strength",
	[1068] = "+15 Stamina",
	[1069] = "+16 Stamina",
	[1070] = "+17 Stamina",
	[1071] = "+18 Stamina",
	[1072] = "+19 Stamina",
	[1073] = "+20 Stamina",
	[1074] = "+21 Stamina",
	[1075] = "+22 Stamina",
	[1076] = "+23 Stamina",
	[1077] = "+24 Stamina",
	[1078] = "+25 Stamina",
	[1079] = "+26 Stamina",
	[1080] = "+27 Stamina",
	[1081] = "+28 Stamina",
	[1082] = "+29 Stamina",
	[1083] = "+30 Stamina",
	[1084] = "+31 Stamina",
	[1085] = "+32 Stamina",
	[1086] = "+33 Stamina",
	[1087] = "+34 Stamina",
	[1088] = "+35 Stamina",
	[1089] = "+36 Stamina",
	[1090] = "+37 Stamina",
	[1091] = "+38 Stamina",
	[1092] = "+39 Stamina",
	[1093] = "+40 Stamina",
	[1094] = "+17 Agility",
	[1095] = "+18 Agility",
	[1096] = "+19 Agility",
	[1097] = "+20 Agility",
	[1098] = "+21 Agility",
	[1099] = "+22 Agility",
	[1100] = "+23 Agility",
	[1101] = "+24 Agility",
	[1102] = "+25 Agility",
	[1103] = "+26 Agility",
	[1104] = "+27 Agility",
	[1105] = "+28 Agility",
	[1106] = "+29 Agility",
	[1107] = "+30 Agility",
	[1108] = "+31 Agility",
	[1109] = "+32 Agility",
	[1110] = "+33 Agility",
	[1111] = "+34 Agility",
	[1112] = "+35 Agility",
	[1113] = "+36 Agility",
	[1114] = "+37 Agility",
	[1115] = "+38 Agility",
	[1116] = "+39 Agility",
	[1117] = "+40 Agility",
	[1118] = "+15 Intellect",
	[1119] = "+16 Intellect",
	[1120] = "+17 Intellect",
	[1121] = "+18 Intellect",
	[1122] = "+19 Intellect",
	[1123] = "+20 Intellect",
	[1124] = "+21 Intellect",
	[1125] = "+22 Intellect",
	[1126] = "+23 Intellect",
	[1127] = "+24 Intellect",
	[1128] = "+25 Intellect",
	[1129] = "+26 Intellect",
	[1130] = "+27 Intellect",
	[1131] = "+28 Intellect",
	[1132] = "+29 Intellect",
	[1133] = "+30 Intellect",
	[1134] = "+31 Intellect",
	[1135] = "+32 Intellect",
	[1136] = "+33 Intellect",
	[1137] = "+34 Intellect",
	[1138] = "+35 Intellect",
	[1139] = "+36 Intellect",
	[1140] = "+37 Intellect",
	[1141] = "+38 Intellect",
	[1142] = "+39 Intellect",
	[1143] = "+40 Intellect",
	[1144] = "+15 Spirit",
	[1145] = "+16 Spirit",
	[1146] = "+17 Spirit",
	[1147] = "+18 Spirit",
	[1148] = "+19 Spirit",
	[1149] = "+20 Spirit",
	[1150] = "+21 Spirit",
	[1151] = "+22 Spirit",
	[1152] = "+23 Spirit",
	[1153] = "+24 Spirit",
	[1154] = "+25 Spirit",
	[1155] = "+26 Spirit",
	[1156] = "+27 Spirit",
	[1157] = "+28 Spirit",
	[1158] = "+29 Spirit",
	[1159] = "+30 Spirit",
	[1160] = "+31 Spirit",
	[1161] = "+32 Spirit",
	[1162] = "+33 Spirit",
	[1163] = "+34 Spirit",
	[1164] = "+36 Spirit",
	[1165] = "+37 Spirit",
	[1166] = "+38 Spirit",
	[1167] = "+39 Spirit",
	[1168] = "+40 Spirit",
	[1183] = "+35 Spirit",
	[1203] = "+41 Strength",
	[1204] = "+42 Strength",
	[1205] = "+43 Strength",
	[1206] = "+44 Strength",
	[1207] = "+45 Strength",
	[1208] = "+46 Strength",
	[1209] = "+41 Stamina",
	[1210] = "+42 Stamina",
	[1211] = "+43 Stamina",
	[1212] = "+44 Stamina",
	[1213] = "+45 Stamina",
	[1214] = "+46 Stamina",
	[1215] = "+41 Agility",
	[1216] = "+42 Agility",
	[1217] = "+43 Agility",
	[1218] = "+44 Agility",
	[1219] = "+45 Agility",
	[1220] = "+46 Agility",
	[1221] = "+41 Intellect",
	[1222] = "+42 Intellect",
	[1223] = "+43 Intellect",
	[1224] = "+44 Intellect",
	[1225] = "+45 Intellect",
	[1226] = "+46 Intellect",
	[1227] = "+41 Spirit",
	[1228] = "+42 Spirit",
	[1229] = "+43 Spirit",
	[1230] = "+44 Spirit",
	[1231] = "+45 Spirit",
	[1232] = "+46 Spirit",
	[1243] = "+1 Arcane Resistance",
	[1244] = "+2 Arcane Resistance",
	[1245] = "+3 Arcane Resistance",
	[1246] = "+4 Arcane Resistance",
	[1247] = "+5 Arcane Resistance",
	[1248] = "+6 Arcane Resistance",
	[1249] = "+7 Arcane Resistance",
	[1250] = "+8 Arcane Resistance",
	[1251] = "+9 Arcane Resistance",
	[1252] = "+10 Arcane Resistance",
	[1253] = "+11 Arcane Resistance",
	[1254] = "+12 Arcane Resistance",
	[1255] = "+13 Arcane Resistance",
	[1256] = "+14 Arcane Resistance",
	[1257] = "+15 Arcane Resistance",
	[1258] = "+16 Arcane Resistance",
	[1259] = "+17 Arcane Resistance",
	[1260] = "+18 Arcane Resistance",
	[1261] = "+19 Arcane Resistance",
	[1262] = "+20 Arcane Resistance",
	[1263] = "+21 Arcane Resistance",
	[1264] = "+22 Arcane Resistance",
	[1265] = "+23 Arcane Resistance",
	[1266] = "+24 Arcane Resistance",
	[1267] = "+25 Arcane Resistance",
	[1268] = "+26 Arcane Resistance",
	[1269] = "+27 Arcane Resistance",
	[1270] = "+28 Arcane Resistance",
	[1271] = "+29 Arcane Resistance",
	[1272] = "+30 Arcane Resistance",
	[1273] = "+31 Arcane Resistance",
	[1274] = "+32 Arcane Resistance",
	[1275] = "+33 Arcane Resistance",
	[1276] = "+34 Arcane Resistance",
	[1277] = "+35 Arcane Resistance",
	[1278] = "+36 Arcane Resistance",
	[1279] = "+37 Arcane Resistance",
	[1280] = "+38 Arcane Resistance",
	[1281] = "+39 Arcane Resistance",
	[1282] = "+40 Arcane Resistance",
	[1283] = "+41 Arcane Resistance",
	[1284] = "+42 Arcane Resistance",
	[1285] = "+43 Arcane Resistance",
	[1286] = "+44 Arcane Resistance",
	[1287] = "+45 Arcane Resistance",
	[1288] = "+46 Arcane Resistance",
	[1289] = "+1 Frost Resistance",
	[1290] = "+2 Frost Resistance",
	[1291] = "+3 Frost Resistance",
	[1292] = "+4 Frost Resistance",
	[1293] = "+5 Frost Resistance",
	[1294] = "+6 Frost Resistance",
	[1295] = "+7 Frost Resistance",
	[1296] = "+8 Frost Resistance",
	[1297] = "+9 Frost Resistance",
	[1298] = "+10 Frost Resistance",
	[1299] = "+11 Frost Resistance",
	[1300] = "+12 Frost Resistance",
	[1301] = "+13 Frost Resistance",
	[1302] = "+14 Frost Resistance",
	[1303] = "+15 Frost Resistance",
	[1304] = "+16 Frost Resistance",
	[1305] = "+17 Frost Resistance",
	[1306] = "+18 Frost Resistance",
	[1307] = "+19 Frost Resistance",
	[1308] = "+20 Frost Resistance",
	[1309] = "+21 Frost Resistance",
	[1310] = "+22 Frost Resistance",
	[1311] = "+23 Frost Resistance",
	[1312] = "+24 Frost Resistance",
	[1313] = "+25 Frost Resistance",
	[1314] = "+26 Frost Resistance",
	[1315] = "+27 Frost Resistance",
	[1316] = "+28 Frost Resistance",
	[1317] = "+29 Frost Resistance",
	[1318] = "+30 Frost Resistance",
	[1319] = "+31 Frost Resistance",
	[1320] = "+32 Frost Resistance",
	[1321] = "+33 Frost Resistance",
	[1322] = "+34 Frost Resistance",
	[1323] = "+35 Frost Resistance",
	[1324] = "+36 Frost Resistance",
	[1325] = "+37 Frost Resistance",
	[1326] = "+38 Frost Resistance",
	[1327] = "+39 Frost Resistance",
	[1328] = "+40 Frost Resistance",
	[1329] = "+41 Frost Resistance",
	[1330] = "+42 Frost Resistance",
	[1331] = "+43 Frost Resistance",
	[1332] = "+44 Frost Resistance",
	[1333] = "+45 Frost Resistance",
	[1334] = "+46 Frost Resistance",
	[1335] = "+1 Fire Resistance",
	[1336] = "+2 Fire Resistance",
	[1337] = "+3 Fire Resistance",
	[1338] = "+4 Fire Resistance",
	[1339] = "+5 Fire Resistance",
	[1340] = "+6 Fire Resistance",
	[1341] = "+7 Fire Resistance",
	[1342] = "+8 Fire Resistance",
	[1343] = "+9 Fire Resistance",
	[1344] = "+10 Fire Resistance",
	[1345] = "+11 Fire Resistance",
	[1346] = "+12 Fire Resistance",
	[1347] = "+13 Fire Resistance",
	[1348] = "+14 Fire Resistance",
	[1349] = "+15 Fire Resistance",
	[1350] = "+16 Fire Resistance",
	[1351] = "+17 Fire Resistance",
	[1352] = "+18 Fire Resistance",
	[1353] = "+19 Fire Resistance",
	[1354] = "+20 Fire Resistance",
	[1355] = "+21 Fire Resistance",
	[1356] = "+22 Fire Resistance",
	[1357] = "+23 Fire Resistance",
	[1358] = "+24 Fire Resistance",
	[1359] = "+25 Fire Resistance",
	[1360] = "+26 Fire Resistance",
	[1361] = "+27 Fire Resistance",
	[1362] = "+28 Fire Resistance",
	[1363] = "+29 Fire Resistance",
	[1364] = "+30 Fire Resistance",
	[1365] = "+31 Fire Resistance",
	[1366] = "+32 Fire Resistance",
	[1367] = "+33 Fire Resistance",
	[1368] = "+34 Fire Resistance",
	[1369] = "+35 Fire Resistance",
	[1370] = "+36 Fire Resistance",
	[1371] = "+37 Fire Resistance",
	[1372] = "+38 Fire Resistance",
	[1373] = "+39 Fire Resistance",
	[1374] = "+40 Fire Resistance",
	[1375] = "+41 Fire Resistance",
	[1376] = "+42 Fire Resistance",
	[1377] = "+43 Fire Resistance",
	[1378] = "+44 Fire Resistance",
	[1379] = "+45 Fire Resistance",
	[1380] = "+46 Fire Resistance",
	[1381] = "+1 Nature Resistance",
	[1382] = "+2 Nature Resistance",
	[1383] = "+3 Nature Resistance",
	[1384] = "+4 Nature Resistance",
	[1385] = "+5 Nature Resistance",
	[1386] = "+6 Nature Resistance",
	[1387] = "+7 Nature Resistance",
	[1388] = "+8 Nature Resistance",
	[1389] = "+9 Nature Resistance",
	[1390] = "+10 Nature Resistance",
	[1391] = "+11 Nature Resistance",
	[1392] = "+12 Nature Resistance",
	[1393] = "+13 Nature Resistance",
	[1394] = "+14 Nature Resistance",
	[1395] = "+15 Nature Resistance",
	[1396] = "+16 Nature Resistance",
	[1397] = "+17 Nature Resistance",
	[1398] = "+18 Nature Resistance",
	[1399] = "+19 Nature Resistance",
	[1400] = "+20 Nature Resistance",
	[1401] = "+21 Nature Resistance",
	[1402] = "+22 Nature Resistance",
	[1403] = "+23 Nature Resistance",
	[1404] = "+24 Nature Resistance",
	[1405] = "+25 Nature Resistance",
	[1406] = "+26 Nature Resistance",
	[1407] = "+27 Nature Resistance",
	[1408] = "+28 Nature Resistance",
	[1409] = "+29 Nature Resistance",
	[1410] = "+30 Nature Resistance",
	[1411] = "+31 Nature Resistance",
	[1412] = "+32 Nature Resistance",
	[1413] = "+33 Nature Resistance",
	[1414] = "+34 Nature Resistance",
	[1415] = "+35 Nature Resistance",
	[1416] = "+36 Nature Resistance",
	[1417] = "+37 Nature Resistance",
	[1418] = "+38 Nature Resistance",
	[1419] = "+39 Nature Resistance",
	[1420] = "+40 Nature Resistance",
	[1421] = "+41 Nature Resistance",
	[1422] = "+42 Nature Resistance",
	[1423] = "+43 Nature Resistance",
	[1424] = "+44 Nature Resistance",
	[1425] = "+45 Nature Resistance",
	[1426] = "+46 Nature Resistance",
	[1427] = "+1 Shadow Resistance",
	[1428] = "+2 Shadow Resistance",
	[1429] = "+3 Shadow Resistance",
	[1430] = "+4 Shadow Resistance",
	[1431] = "+5 Shadow Resistance",
	[1432] = "+6 Shadow Resistance",
	[1433] = "+7 Shadow Resistance",
	[1434] = "+8 Shadow Resistance",
	[1435] = "+9 Shadow Resistance",
	[1436] = "+10 Shadow Resistance",
	[1437] = "+11 Shadow Resistance",
	[1438] = "+12 Shadow Resistance",
	[1439] = "+13 Shadow Resistance",
	[1440] = "+14 Shadow Resistance",
	[1441] = "+15 Shadow Resistance",
	[1442] = "+16 Shadow Resistance",
	[1443] = "+17 Shadow Resistance",
	[1444] = "+18 Shadow Resistance",
	[1445] = "+19 Shadow Resistance",
	[1446] = "+20 Shadow Resistance",
	[1447] = "+21 Shadow Resistance",
	[1448] = "+22 Shadow Resistance",
	[1449] = "+23 Shadow Resistance",
	[1450] = "+24 Shadow Resistance",
	[1451] = "+25 Shadow Resistance",
	[1452] = "+26 Resist Shadow",
	[1453] = "+27 Shadow Resistance",
	[1454] = "+28 Shadow Resistance",
	[1455] = "+29 Shadow Resistance",
	[1456] = "+30 Shadow Resistance",
	[1457] = "+31 Shadow Resistance",
	[1458] = "+32 Shadow Resistance",
	[1459] = "+33 Shadow Resistance",
	[1460] = "+34 Shadow Resistance",
	[1461] = "+35 Shadow Resistance",
	[1462] = "+36 Shadow Resistance",
	[1463] = "+37 Shadow Resistance",
	[1464] = "+38 Shadow Resistance",
	[1465] = "+39 Shadow Resistance",
	[1466] = "+40 Shadow Resistance",
	[1467] = "+41 Shadow Resistance",
	[1468] = "+42 Shadow Resistance",
	[1469] = "+43 Shadow Resistance",
	[1470] = "+44 Shadow Resistance",
	[1471] = "+45 Shadow Resistance",
	[1472] = "+46 Shadow Resistance",
	[1483] = "+150 Mana",
	[1503] = "+100 Health",
	[1504] = "+125 Armor",
	[1505] = "+20 Fire Resistance",
	[1506] = "+8 Strength",
	[1507] = "+8 Stamina",
	[1508] = "+8 Agility",
	[1509] = "+8 Intellect",
	[1510] = "+8 Spirit",
	[1523] = "+85/14 MANA/FR",
	[1524] = "+75/14 HP/FR",
	[1525] = "+110/14 AC/FR",
	[1526] = "+10/14 STR/FR",
	[1527] = "+10/14 STA/FR",
	[1528] = "+10/14 AGI/FR",
	[1529] = "+10/14 INT/FR",
	[1530] = "+10/14 SPI/FR",
	[1531] = "+10/10 STR/STA",
	[1532] = "+10/10/110/15 STR/STA/AC/FR",
	[1543] = "+10/10/100/15 INT/SPI/MANA/FR",
	[1563] = "+2 Attack Power",
	[1583] = "+4 Attack Power",
	[1584] = "+6 Attack Power",
	[1585] = "+8 Attack Power",
	[1586] = "+10 Attack Power",
	[1587] = "+12 Attack Power",
	[1588] = "+14 Attack Power",
	[1589] = "+16 Attack Power",
	[1590] = "+18 Attack Power",
	[1591] = "+20 Attack Power",
	[1592] = "+22 Attack Power",
	[1593] = "+24 Attack Power",
	[1594] = "+26 Attack Power",
	[1595] = "+28 Attack Power",
	[1596] = "+30 Attack Power",
	[1597] = "+32 Attack Power",
	[1598] = "+34 Attack Power",
	[1599] = "+36 Attack Power",
	[1600] = "+38 Attack Power",
	[1601] = "+32 Attack Power",
	[1602] = "+42 Attack Power",
	[1603] = "+44 Attack Power",
	[1604] = "+46 Attack Power",
	[1605] = "+48 Attack Power",
	[1606] = "+50 Attack Power",
	[1607] = "+52 Attack Power",
	[1608] = "+54 Attack Power",
	[1609] = "+56 Attack Power",
	[1610] = "+58 Attack Power",
	[1611] = "+60 Attack Power",
	[1612] = "+62 Attack Power",
	[1613] = "+64 Attack Power",
	[1614] = "+66 Attack Power",
	[1615] = "+68 Attack Power",
	[1616] = "+70 Attack Power",
	[1617] = "+72 Attack Power",
	[1618] = "+74 Attack Power",
	[1619] = "+76 Attack Power",
	[1620] = "+78 Attack Power",
	[1621] = "+80 Attack Power",
	[1622] = "+82 Attack Power",
	[1623] = "+84 Attack Power",
	[1624] = "+86 Attack Power",
	[1625] = "+88 Attack Power",
	[1626] = "+90 Attack Power",
	[1627] = "+92 Attack Power",
	[1643] = "Sharpened (+8 Damage)",
	[1663] = "Rockbiter 5",
	[1664] = "Rockbiter 7",
	[1665] = "Flametongue 5",
	[1666] = "Flametongue 6",
	[1667] = "Frostbrand 4",
	[1668] = "Frostbrand 5",
	[1669] = "Windfury 4",
	[1683] = "Flametongue Totem 4",
	[1703] = "Weighted (+8 Damage)",
	[1704] = "Thorium Spike (20-30)",
	[1723] = "Omen of Clarity",
	[1743] = "MHTest02",
	[1763] = "Cold Blood",
	[1783] = "Windfury Totem 1",
	[1803] = "Firestone 1",
	[1823] = "Firestone 2",
	[1824] = "Firestone 3",
	[1825] = "Firestone 4",
	[1843] = "Reinforced (+40 Armor)",
	[1863] = "Feedback 2",
	[1864] = "Feedback 3",
	[1865] = "Feedback 4",
	[1866] = "Feedback 5",
	[1883] = "+7 Intellect",
	[1884] = "+9 Spirit",
	[1885] = "+9 Strength",
	[1886] = "+9 Stamina",
	[1887] = "+7 Agility",
	[1888] = "+5 All Resistances",
	[1889] = "+70 Armor",
	[1890] = "+4 Mana and Health every 5 sec",
	[1891] = "+4 All Stats",
	[1892] = "+100 Health",
	[1893] = "+100 Mana",
	[1894] = "Icy Weapon",
	[1895] = "+9 Damage",
	[1896] = "+9 Weapon Damage",
	[1897] = "+5 Weapon Damage",
	[1898] = "Lifestealing",
	[1899] = "Unholy Weapon",
	[1900] = "Crusader",
	[1901] = "+9 Intellect",
	[1903] = "+9 Spirit",
	[1904] = "+9 Intellect",
	[1923] = "+3 Fire Resistance",
	[1943] = "+12 Defense Rating",
	[1944] = "+8 Defense Rating",
	[1945] = "+9 Defense Rating",
	[1946] = "+10 Defense Rating",
	[1947] = "+11 Defense Rating",
	[1948] = "+13 Defense Rating",
	[1949] = "+14 Defense Rating",
	[1950] = "+15 Defense Rating",
	[1951] = "+16 Defense Rating",
	[1952] = "+20 Defense Rating",
	[1953] = "+22 Defense Rating",
	[1954] = "+25 Defense Rating",
	[1955] = "+32 Defense Rating",
	[1956] = "+17 Defense Rating",
	[1957] = "+18 Defense Rating",
	[1958] = "+19 Defense Rating",
	[1959] = "+21 Defense Rating",
	[1960] = "+23 Defense Rating",
	[1961] = "+24 Defense Rating",
	[1962] = "+26 Defense Rating",
	[1963] = "+27 Defense Rating",
	[1964] = "+28 Defense Rating",
	[1965] = "+29 Defense Rating",
	[1966] = "+30 Defense Rating",
	[1967] = "+31 Defense Rating",
	[1968] = "+33 Defense Rating",
	[1969] = "+34 Defense Rating",
	[1970] = "+35 Defense Rating",
	[1971] = "+36 Defense Rating",
	[1972] = "+37 Defense Rating",
	[1973] = "+38 Defense Rating",
	[1983] = "+5 Block Rating",
	[1984] = "+10 Block Rating",
	[1985] = "+15 Block Rating",
	[1986] = "+20 Block Rating",
	[1987] = "Block Level 14",
	[1988] = "Block Level 15",
	[1989] = "Block Level 16",
	[1990] = "Block Level 17",
	[1991] = "Block Level 18",
	[1992] = "Block Level 19",
	[1993] = "Block Level 20",
	[1994] = "Block Level 21",
	[1995] = "Block Level 22",
	[1996] = "Block Level 23",
	[1997] = "Block Level 24",
	[1998] = "Block Level 25",
	[1999] = "Block Level 26",
	[2000] = "Block Level 27",
	[2001] = "Block Level 28",
	[2002] = "Block Level 29",
	[2003] = "Block Level 30",
	[2004] = "Block Level 31",
	[2005] = "Block Level 32",
	[2006] = "Block Level 33",
	[2007] = "Block Level 34",
	[2008] = "Block Level 35",
	[2009] = "Block Level 36",
	[2010] = "Block Level 37",
	[2011] = "Block Level 38",
	[2012] = "Block Level 39",
	[2013] = "Block Level 40",
	[2014] = "Block Level 41",
	[2015] = "Block Level 42",
	[2016] = "Block Level 43",
	[2017] = "Block Level 44",
	[2018] = "Block Level 45",
	[2019] = "Block Level 46",
	[2020] = "Block Level 47",
	[2021] = "Block Level 48",
	[2022] = "Block Level 49",
	[2023] = "Block Level 50",
	[2024] = "Block Level 51",
	[2025] = "Block Level 52",
	[2026] = "Block Level 53",
	[2027] = "Block Level 54",
	[2028] = "Block Level 55",
	[2029] = "Block Level 56",
	[2030] = "Block Level 57",
	[2031] = "Block Level 58",
	[2032] = "Block Level 59",
	[2033] = "Block Level 60",
	[2034] = "Block Level 61",
	[2035] = "Block Level 62",
	[2036] = "Block Level 63",
	[2037] = "Block Level 64",
	[2038] = "Block Level 65",
	[2039] = "Block Level 66",
	[2040] = "+2 Ranged Attack Power",
	[2041] = "+5 Ranged Attack Power",
	[2042] = "+7 Ranged Attack Power",
	[2043] = "+10 Ranged Attack Power",
	[2044] = "+12 Ranged Attack Power",
	[2045] = "+14 Ranged Attack Power",
	[2046] = "+17 Ranged Attack Power",
	[2047] = "+19 Ranged Attack Power",
	[2048] = "+22 Ranged Attack Power",
	[2049] = "+24 Ranged Attack Power",
	[2050] = "+26 Ranged Attack Power",
	[2051] = "+29 Ranged Attack Power",
	[2052] = "+31 Ranged Attack Power",
	[2053] = "+34 Ranged Attack Power",
	[2054] = "+36 Ranged Attack Power",
	[2055] = "+38 Ranged Attack Power",
	[2056] = "+41 Ranged Attack Power",
	[2057] = "+43 Ranged Attack Power",
	[2058] = "+46 Ranged Attack Power",
	[2059] = "+48 Ranged Attack Power",
	[2060] = "+50 Ranged Attack Power",
	[2061] = "+53 Ranged Attack Power",
	[2062] = "+55 Ranged Attack Power",
	[2063] = "+58 Ranged Attack Power",
	[2064] = "+60 Ranged Attack Power",
	[2065] = "+62 Ranged Attack Power",
	[2066] = "+65 Ranged Attack Power",
	[2067] = "+67 Ranged Attack Power",
	[2068] = "+70 Ranged Attack Power",
	[2069] = "+72 Ranged Attack Power",
	[2070] = "+74 Ranged Attack Power",
	[2071] = "+77 Ranged Attack Power",
	[2072] = "+79 Ranged Attack Power",
	[2073] = "+82 Ranged Attack Power",
	[2074] = "+84 Ranged Attack Power",
	[2075] = "+86 Ranged Attack Power",
	[2076] = "+89 Ranged Attack Power",
	[2077] = "+91 Ranged Attack Power",
	[2078] = "+12 Dodge Rating",
	[2079] = "+1 Arcane Spell Damage",
	[2080] = "+3 Arcane Spell Damage",
	[2081] = "+4 Arcane Spell Damage",
	[2082] = "+6 Arcane Spell Damage",
	[2083] = "+7 Arcane Spell Damage",
	[2084] = "+9 Arcane Spell Damage",
	[2085] = "+10 Arcane Spell Damage",
	[2086] = "+11 Arcane Spell Damage",
	[2087] = "+13 Arcane Spell Damage",
	[2088] = "+14 Arcane Spell Damage",
	[2089] = "+16 Arcane Spell Damage",
	[2090] = "+17 Arcane Spell Damage",
	[2091] = "+19 Arcane Spell Damage",
	[2092] = "+20 Arcane Spell Damage",
	[2093] = "+21 Arcane Spell Damage",
	[2094] = "+23 Arcane Spell Damage",
	[2095] = "+24 Arcane Spell Damage",
	[2096] = "+26 Arcane Spell Damage",
	[2097] = "+27 Arcane Spell Damage",
	[2098] = "+29 Arcane Spell Damage",
	[2099] = "+30 Arcane Spell Damage",
	[2100] = "+31 Arcane Spell Damage",
	[2101] = "+33 Arcane Spell Damage",
	[2102] = "+34 Arcane Spell Damage",
	[2103] = "+36 Arcane Spell Damage",
	[2104] = "+37 Arcane Spell Damage",
	[2105] = "+39 Arcane Spell Damage",
	[2106] = "+40 Arcane Spell Damage",
	[2107] = "+41 Arcane Spell Damage",
	[2108] = "+43 Arcane Spell Damage",
	[2109] = "+44 Arcane Spell Damage",
	[2110] = "+46 Arcane Spell Damage",
	[2111] = "+47 Arcane Spell Damage",
	[2112] = "+49 Arcane Spell Damage",
	[2113] = "+50 Arcane Spell Damage",
	[2114] = "+51 Arcane Spell Damage",
	[2115] = "+53 Arcane Spell Damage",
	[2116] = "+54 Arcane Spell Damage",
	[2117] = "+1 Shadow Spell Damage",
	[2118] = "+3 Shadow Spell Damage",
	[2119] = "+4 Shadow Spell Damage",
	[2120] = "+6 Shadow Spell Damage",
	[2121] = "+7 Shadow Spell Damage",
	[2122] = "+9 Shadow Spell Damage",
	[2123] = "+10 Shadow Spell Damage",
	[2124] = "+11 Shadow Spell Damage",
	[2125] = "+13 Shadow Spell Damage",
	[2126] = "+14 Shadow Spell Damage",
	[2127] = "+16 Shadow Spell Damage",
	[2128] = "+17 Shadow Spell Damage",
	[2129] = "+19 Shadow Spell Damage",
	[2130] = "+20 Shadow Spell Damage",
	[2131] = "+21 Shadow Spell Damage",
	[2132] = "+23 Shadow Spell Damage",
	[2133] = "+24 Shadow Spell Damage",
	[2134] = "+26 Shadow Spell Damage",
	[2135] = "+27 Shadow Spell Damage",
	[2136] = "+29 Shadow Spell Damage",
	[2137] = "+30 Shadow Spell Damage",
	[2138] = "+31 Shadow Spell Damage",
	[2139] = "+33 Shadow Spell Damage",
	[2140] = "+34 Shadow Spell Damage",
	[2141] = "+36 Shadow Spell Damage",
	[2142] = "+37 Shadow Spell Damage",
	[2143] = "+39 Shadow Spell Damage",
	[2144] = "+40 Shadow Spell Damage",
	[2145] = "+41 Shadow Spell Damage",
	[2146] = "+43 Shadow Spell Damage",
	[2147] = "+44 Shadow Spell Damage",
	[2148] = "+46 Shadow Spell Damage",
	[2149] = "+47 Shadow Spell Damage",
	[2150] = "+49 Shadow Spell Damage",
	[2151] = "+50 Shadow Spell Damage",
	[2152] = "+51 Shadow Spell Damage",
	[2153] = "+53 Shadow Spell Damage",
	[2154] = "+54 Shadow Spell Damage",
	[2155] = "+1 Fire Spell Damage",
	[2156] = "+3 Fire Spell Damage",
	[2157] = "+4 Fire Spell Damage",
	[2158] = "+6 Fire Spell Damage",
	[2159] = "+7 Fire Spell Damage",
	[2160] = "+9 Fire Spell Damage",
	[2161] = "+10 Fire Spell Damage",
	[2162] = "+11 Fire Spell Damage",
	[2163] = "+13 Fire Spell Damage",
	[2164] = "+14 Fire Spell Damage",
	[2165] = "+16 Fire Spell Damage",
	[2166] = "+17 Fire Spell Damage",
	[2167] = "+19 Fire Spell Damage",
	[2168] = "+20 Fire Spell Damage",
	[2169] = "+21 Fire Spell Damage",
	[2170] = "+23 Fire Spell Damage",
	[2171] = "+24 Fire Spell Damage",
	[2172] = "+26 Fire Spell Damage",
	[2173] = "+27 Fire Spell Damage",
	[2174] = "+29 Fire Spell Damage",
	[2175] = "+30 Fire Spell Damage",
	[2176] = "+31 Fire Spell Damage",
	[2177] = "+33 Fire Spell Damage",
	[2178] = "+34 Fire Spell Damage",
	[2179] = "+36 Fire Spell Damage",
	[2180] = "+37 Fire Spell Damage",
	[2181] = "+39 Fire Spell Damage",
	[2182] = "+40 Fire Spell Damage",
	[2183] = "+41 Fire Spell Damage",
	[2184] = "+43 Fire Spell Damage",
	[2185] = "+44 Fire Spell Damage",
	[2186] = "+46 Fire Spell Damage",
	[2187] = "+47 Fire Spell Damage",
	[2188] = "+49 Fire Spell Damage",
	[2189] = "+50 Fire Spell Damage",
	[2190] = "+51 Fire Spell Damage",
	[2191] = "+53 Fire Spell Damage",
	[2192] = "+54 Fire Spell Damage",
	[2193] = "+1 Holy Spell Damage",
	[2194] = "+3 Holy Spell Damage",
	[2195] = "+4 Holy Spell Damage",
	[2196] = "+6 Holy Spell Damage",
	[2197] = "+7 Holy Spell Damage",
	[2198] = "+9 Holy Spell Damage",
	[2199] = "+10 Holy Spell Damage",
	[2200] = "+11 Holy Spell Damage",
	[2201] = "+13 Holy Spell Damage",
	[2202] = "+14 Holy Spell Damage",
	[2203] = "+16 Holy Spell Damage",
	[2204] = "+17 Holy Spell Damage",
	[2205] = "+19 Holy Spell Damage",
	[2206] = "+20 Holy Spell Damage",
	[2207] = "+21 Holy Spell Damage",
	[2208] = "+23 Holy Spell Damage",
	[2209] = "+24 Holy Spell Damage",
	[2210] = "+26 Holy Spell Damage",
	[2211] = "+27 Holy Spell Damage",
	[2212] = "+29 Holy Spell Damage",
	[2213] = "+30 Holy Spell Damage",
	[2214] = "+31 Holy Spell Damage",
	[2215] = "+33 Holy Spell Damage",
	[2216] = "+34 Holy Spell Damage",
	[2217] = "+36 Holy Spell Damage",
	[2218] = "+37 Holy Spell Damage",
	[2219] = "+39 Holy Spell Damage",
	[2220] = "+40 Holy Spell Damage",
	[2221] = "+41 Holy Spell Damage",
	[2222] = "+43 Holy Spell Damage",
	[2223] = "+44 Holy Spell Damage",
	[2224] = "+46 Holy Spell Damage",
	[2225] = "+47 Holy Spell Damage",
	[2226] = "+49 Holy Spell Damage",
	[2227] = "+50 Holy Spell Damage",
	[2228] = "+51 Holy Spell Damage",
	[2229] = "+53 Holy Spell Damage",
	[2230] = "+54 Holy Spell Damage",
	[2231] = "+1 Frost Spell Damage",
	[2232] = "+3 Frost Spell Damage",
	[2233] = "+4 Frost Spell Damage",
	[2234] = "+6 Frost Spell Damage",
	[2235] = "+7 Frost Spell Damage",
	[2236] = "+9 Frost Spell Damage",
	[2237] = "+10 Frost Spell Damage",
	[2238] = "+11 Frost Spell Damage",
	[2239] = "+13 Frost Spell Damage",
	[2240] = "+14 Frost Spell Damage",
	[2241] = "+16 Frost Spell Damage",
	[2242] = "+17 Frost Spell Damage",
	[2243] = "+19 Frost Spell Damage",
	[2244] = "+20 Frost Spell Damage",
	[2245] = "+21 Frost Spell Damage",
	[2246] = "+23 Frost Spell Damage",
	[2247] = "+24 Frost Spell Damage",
	[2248] = "+26 Frost Spell Damage",
	[2249] = "+27 Frost Spell Damage",
	[2250] = "+29 Frost Spell Damage",
	[2251] = "+30 Frost Spell Damage",
	[2252] = "+31 Frost Spell Damage",
	[2253] = "+33 Frost Spell Damage",
	[2254] = "+34 Frost Spell Damage",
	[2255] = "+36 Frost Spell Damage",
	[2256] = "+37 Frost Spell Damage",
	[2257] = "+39 Frost Spell Damage",
	[2258] = "+40 Frost Spell Damage",
	[2259] = "+41 Frost Spell Damage",
	[2260] = "+43 Frost Spell Damage",
	[2261] = "+44 Frost Spell Damage",
	[2262] = "+46 Frost Spell Damage",
	[2263] = "+47 Frost Spell Damage",
	[2264] = "+49 Frost Spell Damage",
	[2265] = "+50 Frost Spell Damage",
	[2266] = "+51 Frost Spell Damage",
	[2267] = "+53 Frost Spell Damage",
	[2268] = "+54 Frost Spell Damage",
	[2269] = "+1 Nature Spell Damage",
	[2270] = "+3 Nature Spell Damage",
	[2271] = "+4 Nature Spell Damage",
	[2272] = "+6 Nature Spell Damage",
	[2273] = "+7 Nature Spell Damage",
	[2274] = "+9 Nature Spell Damage",
	[2275] = "+10 Nature Spell Damage",
	[2276] = "+11 Nature Spell Damage",
	[2277] = "+13 Nature Spell Damage",
	[2278] = "+14 Nature Spell Damage",
	[2279] = "+16 Nature Spell Damage",
	[2280] = "+17 Nature Spell Damage",
	[2281] = "+19 Nature Spell Damage",
	[2282] = "+20 Nature Spell Damage",
	[2283] = "+21 Nature Spell Damage",
	[2284] = "+23 Nature Spell Damage",
	[2285] = "+24 Nature Spell Damage",
	[2286] = "+26 Nature Spell Damage",
	[2287] = "+27 Nature Spell Damage",
	[2288] = "+29 Nature Spell Damage",
	[2289] = "+30 Nature Spell Damage",
	[2290] = "+31 Nature Spell Damage",
	[2291] = "+33 Nature Spell Damage",
	[2292] = "+34 Nature Spell Damage",
	[2293] = "+36 Nature Spell Damage",
	[2294] = "+37 Nature Spell Damage",
	[2295] = "+39 Nature Spell Damage",
	[2296] = "+40 Nature Spell Damage",
	[2297] = "+41 Nature Spell Damage",
	[2298] = "+43 Nature Spell Damage",
	[2299] = "+44 Nature Spell Damage",
	[2300] = "+46 Nature Spell Damage",
	[2301] = "+47 Nature Spell Damage",
	[2302] = "+49 Nature Spell Damage",
	[2303] = "+50 Nature Spell Damage",
	[2304] = "+51 Nature Spell Damage",
	[2305] = "+53 Nature Spell Damage",
	[2306] = "+54 Nature Spell Damage",
	[2307] = "+1 Spell Power",
	[2308] = "+2 Spell Power",
	[2309] = "+4 Spell Power",
	[2310] = "+5 Spell Power",
	[2311] = "+6 Spell Power",
	[2312] = "+7 Spell Power",
	[2313] = "+8 Spell Power",
	[2314] = "+9 Spell Power",
	[2315] = "+11 Spell Power",
	[2316] = "+12 Spell Power",
	[2317] = "+13 Spell Power",
	[2318] = "+14 Spell Power",
	[2319] = "+15 Spell Power",
	[2320] = "+16 Spell Power",
	[2321] = "+18 Spell Power",
	[2322] = "+19 Spell Power",
	[2323] = "+20 Spell Power",
	[2324] = "+21 Spell Power",
	[2325] = "+22 Spell Power",
	[2326] = "+23 Spell Power",
	[2327] = "+25 Spell Power",
	[2328] = "+26 Spell Power",
	[2329] = "+27 Spell Power",
	[2330] = "+28 Spell Power",
	[2331] = "+29 Spell Power",
	[2332] = "+30 Spell Power",
	[2333] = "+32 Spell Power",
	[2334] = "+33 Spell Power",
	[2335] = "+34 Spell Power",
	[2336] = "+35 Spell Power",
	[2337] = "+36 Spell Power",
	[2338] = "+37 Spell Power",
	[2339] = "+39 Spell Power",
	[2340] = "+40 Spell Power",
	[2341] = "+41 Spell Power",
	[2342] = "+42 Spell Power",
	[2343] = "+43 Spell Power",
	[2344] = "+44 Spell Power",
	[2363] = "+1 mana every 5 sec.",
	[2364] = "+1 mana every 5 sec.",
	[2365] = "+1 mana every 5 sec.",
	[2366] = "+2 mana every 5 sec.",
	[2367] = "+2 mana every 5 sec.",
	[2368] = "+2 mana every 5 sec.",
	[2369] = "+3 mana every 5 sec.",
	[2370] = "+3 mana every 5 sec.",
	[2371] = "+4 mana every 5 sec.",
	[2372] = "+4 mana every 5 sec.",
	[2373] = "+4 mana every 5 sec.",
	[2374] = "+5 mana every 5 sec.",
	[2375] = "+5 mana every 5 sec.",
	[2376] = "+6 mana every 5 sec.",
	[2377] = "+6 mana every 5 sec.",
	[2378] = "+6 mana every 5 sec.",
	[2379] = "+7 mana every 5 sec.",
	[2380] = "+7 mana every 5 sec.",
	[2381] = "+10 mana every 5 sec.",
	[2382] = "+8 mana every 5 sec.",
	[2383] = "+8 mana every 5 sec.",
	[2384] = "+9 mana every 5 sec.",
	[2385] = "+9 mana every 5 sec.",
	[2386] = "+10 mana every 5 sec.",
	[2387] = "+10 mana every 5 sec.",
	[2388] = "+10 mana every 5 sec.",
	[2389] = "+11 mana every 5 sec.",
	[2390] = "+11 mana every 5 sec.",
	[2391] = "+12 mana every 5 sec.",
	[2392] = "+12 mana every 5 sec.",
	[2393] = "+12 mana every 5 sec.",
	[2394] = "+13 mana every 5 sec.",
	[2395] = "+13 mana every 5 sec.",
	[2396] = "+14 mana every 5 sec.",
	[2397] = "+14 mana every 5 sec.",
	[2398] = "+14 mana every 5 sec.",
	[2399] = "+15 mana every 5 sec.",
	[2400] = "+15 mana every 5 sec.",
	[2401] = "+1 health every 5 sec.",
	[2402] = "+1 health every 5 sec.",
	[2403] = "+1 health every 5 sec.",
	[2404] = "+1 health every 5 sec.",
	[2405] = "+1 health every 5 sec.",
	[2406] = "+2 health every 5 sec.",
	[2407] = "+2 health every 5 sec.",
	[2408] = "+2 health every 5 sec.",
	[2409] = "+2 health every 5 sec.",
	[2410] = "+3 health every 5 sec.",
	[2411] = "+3 health every 5 sec.",
	[2412] = "+3 health every 5 sec.",
	[2413] = "+3 health every 5 sec.",
	[2414] = "+4 health every 5 sec.",
	[2415] = "+4 health every 5 sec.",
	[2416] = "+4 health every 5 sec.",
	[2417] = "+4 health every 5 sec.",
	[2418] = "+5 health every 5 sec.",
	[2419] = "+5 health every 5 sec.",
	[2420] = "+5 health every 5 sec.",
	[2421] = "+5 health every 5 sec.",
	[2422] = "+6 health every 5 sec.",
	[2423] = "+6 health every 5 sec.",
	[2424] = "+6 health every 5 sec.",
	[2425] = "+6 health every 5 sec.",
	[2426] = "+7 health every 5 sec.",
	[2427] = "+7 health every 5 sec.",
	[2428] = "+7 health every 5 sec.",
	[2429] = "+7 health every 5 sec.",
	[2430] = "+8 health every 5 sec.",
	[2431] = "+8 health every 5 sec.",
	[2432] = "+8 health every 5 sec.",
	[2433] = "+8 health every 5 sec.",
	[2434] = "+9 health every 5 sec.",
	[2435] = "+9 health every 5 sec.",
	[2436] = "+9 health every 5 sec.",
	[2437] = "+9 health every 5 sec.",
	[2438] = "+10 health every 5 sec.",
	[2443] = "+7 Frost Spell Damage",
	[2463] = "+7 Fire Resistance",
	[2483] = "+5 Fire Resistance",
	[2484] = "+5 Frost Resistance",
	[2485] = "+5 Arcane Resistance",
	[2486] = "+5 Nature Resistance",
	[2487] = "+5 Shadow Resistance",
	[2488] = "+5 All Resistances",
	[2503] = "+5 Defense Rating",
	[2504] = "+30 Spell Power",
	[2505] = "+29 Spell Power",
	[2506] = "+28 Melee Critical Strike Rating",
	[2523] = "+30 Ranged Hit Rating",
	[2543] = "+10 Haste Rating",
	[2544] = "+8 Spell Power",
	[2545] = "+12 Dodge Rating",
	[2563] = "+15 Strength",
	[2564] = "+15 Agility",
	[2565] = "Mana Regen 5 per 5 sec.",
	[2566] = "+13 Spell Power",
	[2567] = "+20 Spirit",
	[2568] = "+22 Intellect",
	[2583] = "+10 Defense Rating +10 Stamina +30 Block Value",
	[2584] = "+10 Defense +10 Stamina and +12 Spell Power",
	[2585] = "+28 Attack Power/+12 Dodge Rating",
	[2586] = "+24 Ranged Attack Power/+10 Stamina/+10 Hit Rating",
	[2587] = "+13 Spell Power and +15 Intellect",
	[2588] = "+18 Spell Power and +8 Hit Rating",
	[2589] = "+18 Spell Power and +10 Stamina",
	[2590] = "+13 Spell Power +10 Stamina and +5 Mana every 5 seconds",
	[2591] = "+10 Intellect +10 Stamina +12 Spell Power",
	[2603] = "+5 Fishing",
	[2604] = "+18 Spell Power",
	[2605] = "+18 Spell Power",
	[2606] = "+30 Attack Power",
	[2607] = "+12 Spell Power",
	[2608] = "+13 Spell Power",
	[2609] = "+15 Spell Power",
	[2610] = "+14 Spell Power",
	[2611] = "zzOLDBlank",
	[2612] = "+18 Spell Power",
	[2613] = "+2% Threat",
	[2614] = "+20 Shadow Spell Power",
	[2615] = "+20 Frost Spell Power",
	[2616] = "+20 Fire Spell Power",
	[2617] = "+16 Spell Power",
	[2618] = "+15 Agility",
	[2619] = "+15 Fire Resistance",
	[2620] = "+15 Nature Resistance",
	[2621] = "2% Reduced Threat",
	[2622] = "+12 Dodge Rating",
	[2623] = "Minor Wizard Oil",
	[2624] = "Minor Mana Oil",
	[2625] = "Lesser Mana Oil",
	[2626] = "Lesser Wizard Oil",
	[2627] = "Wizard Oil",
	[2628] = "Brilliant Wizard Oil",
	[2629] = "Brilliant Mana Oil",
	[2630] = "Deadly Poison V",
	[2631] = "Feedback 6",
	[2632] = "Rockbiter 8",
	[2633] = "Rockbiter 9",
	[2634] = "Flametongue 7",
	[2635] = "Frostbrand 6",
	[2636] = "Windfury 5",
	[2637] = "Flametongue Totem 5",
	[2638] = "Windfury Totem 4",
	[2639] = "Windfury Totem 5",
	[2640] = "Anesthetic Poison",
	[2641] = "Instant Poison VII",
	[2642] = "Deadly Poison VI",
	[2643] = "Deadly Poison VII",
	[2644] = "Wound Poison V",
	[2645] = "Firestone 5",
	[2646] = "+25 Agility",
	[2647] = "+12 Strength",
	[2648] = "+12 Defense Rating",
	[2649] = "+12 Stamina",
	[2650] = "+15 Spell Power",
	[2651] = "+12 Spell Power",
	[2652] = "+11 Spell Power",
	[2653] = "+36 Block Value",
	[2654] = "+12 Intellect",
	[2655] = "+15 Shield Block Rating",
	[2656] = "+5 Health and Mana every 5 sec",
	[2657] = "+12 Agility",
	[2658] = "+10 Hit Rating and +10 Critical Strike Rating",
	[2659] = "+150 Health",
	[2660] = "+150 Mana",
	[2661] = "+6 All Stats",
	[2662] = "+120 Armor",
	[2663] = "+7 Resist All",
	[2664] = "+7 Resist All",
	[2665] = "+35 Spirit",
	[2666] = "+30 Intellect",
	[2667] = "+70 Attack Power",
	[2668] = "+20 Strength",
	[2669] = "+40 Spell Power",
	[2670] = "+35 Agility",
	[2671] = "+50 Arcane and Fire Spell Power",
	[2672] = "+54 Shadow and Frost Spell Power",
	[2673] = "Mongoose",
	[2674] = "Spellsurge",
	[2675] = "Battlemaster",
	[2676] = "Superior Mana Oil",
	[2677] = "Superior Mana Oil",
	[2678] = "Superior Wizard Oil",
	[2679] = "8 Mana per 5 Sec.",
	[2680] = "+7 Resist All",
	[2681] = "+10 Nature Resistance",
	[2682] = "+10 Frost Resistance",
	[2683] = "+10 Shadow Resistance",
	[2684] = "+100 Attack Power vs Undead",
	[2685] = "+60 Spell Power vs Undead",
	[2686] = "+8 Strength",
	[2687] = "+8 Agility",
	[2688] = "+8 Stamina",
	[2689] = "+8 mana every 5 sec.",
	[2690] = "+7 Spell Power",
	[2691] = "+6 Strength",
	[2692] = "+7 Spell Power",
	[2693] = "+6 Agility",
	[2694] = "+6 Intellect",
	[2695] = "+6 Critical Strike Rating",
	[2696] = "+6 Defense Rating",
	[2697] = "+6 Hit Rating",
	[2698] = "+9 Stamina",
	[2699] = "+6 Spirit",
	[2700] = "+8 Spell Penetration",
	[2701] = "+3 Mana every 5 seconds",
	[2702] = "+12 Agility (2 Red Gems)",
	[2703] = "+4 Agility per different colored gem",
	[2704] = "+12 Strength if 4 blue gems equipped",
	[2705] = "+4 Spell Power and +3 Intellect",
	[2706] = "+3 Defense Rating and +4 Stamina",
	[2707] = "+3 Intellect and +2 Mana every 5 Sec",
	[2708] = "+4 Spell Power and +4 Stamina",
	[2709] = "+4 Spell Power and +2 Mana every 5 seconds",
	[2710] = "+3 Agility and +4 Stamina",
	[2711] = "+3 Strength and +4 Stamina",
	[2712] = "Sharpened (+12 Damage)",
	[2713] = "Sharpened (+14 Crit Rating and +12 Damage)",
	[2714] = "Felsteel Spike (26-38)",
	[2715] = "+16 Spell Power and 6 Mana every 5 seconds",
	[2716] = "+16 Stamina and +100 Armor",
	[2717] = "+26 Attack Power and +14 Critical Strike Rating",
	[2718] = "Lesser Rune of Warding",
	[2719] = "Lesser Ward of Shielding",
	[2720] = "Greater Ward of Shielding",
	[2721] = "+15 Spell Power and +14 Critical Strike Rating",
-- ############## TBC IDs ##########################################
-- ############## TBC IDs ##########################################
-- ############## TBC IDs ##########################################
	[2722] = "Scp (+10 Damage)",
	[2723] = "Scp (+12 Damage)",
	[2724] = "Scp (+28 Critical Strike Rating)",
	[2725] = "+8 Strength",
	[2726] = "+8 Agility",
	[2727] = "+9 Spell Power",
	[2728] = "+9 Spell Power",
	[2729] = "+16 Attack Power",
	[2730] = "+8 Dodge Rating",
	[2731] = "+12 Stamina",
	[2732] = "+8 Spirit",
	[2733] = "+4 Mana every 5 seconds",
	[2734] = "+8 Intellect",
	[2735] = "+8 Critical Strike Rating",
	[2736] = "+8 Critical Strike Rating",
	[2737] = "+8 Defense Rating",
	[2738] = "+4 Strength and +6 Stamina",
	[2739] = "+4 Agility and +6 Stamina",
	[2740] = "+5 Spell Power and +6 Stamina",
	[2741] = "+5 Spell Power and +2 Mana every 5 seconds",
	[2742] = "+5 Spell Power and +4 Intellect",
	[2743] = "+4 Defense Rating and +6 Stamina",
	[2744] = "+4 Intellect and +2 Mana every 5 seconds",
	[2745] = "+25 Spell Power and +15 Stamina",
	[2746] = "+35 Spell Power and +20 Stamina",
	[2747] = "+25 Spell Power and +15 Stamina",
	[2748] = "+35 Spell Power and +20 Stamina",
	[2749] = "+12 Intellect",
	[2750] = "6 mana per 5 sec.",
	[2751] = "+14 Critical Strike Rating",
	[2752] = "+3 Critical Strike Rating and +3 Strength",
	[2753] = "+4 Critical Strike Rating and +4 Strength",
	[2754] = "+8 Parry Rating",
	[2755] = "+3 Hit Rating and +3 Agility",
	[2756] = "+4 Hit Rating and +4 Agility",
	[2757] = "+3 Critical Strike Rating and +4 Stamina",
	[2758] = "+4 Critical Strike Rating and +6 Stamina",
	[2759] = "+8 Resilience Rating",
	[2760] = "+3 Critical Strike Rating and +4 Spell Power",
	[2761] = "+4 Critical Strike Rating and +5 Spell Power",
	[2762] = "+3 Critical Strike Rating and +4 Spell Penetration",
	[2763] = "+4 Critical Strike Rating and +5 Spell Penetration",
	[2764] = "+8 Hit Rating",
	[2765] = "+10 Spell Penetration",
	[2766] = "+8 Intellect",
	[2767] = "+8 Hit Rating",
	[2768] = "+16 Spell Power",
	[2769] = "+11 Hit Rating",
	[2770] = "+7 Spell Power",
	[2771] = "+8 Critical Strike Rating",
	[2772] = "+14 Critical Strike Rating",
	[2773] = "+16 Critical Strike Rating",
	[2774] = "+11 Intellect",
	[2775] = "+11 Critical Strike Rating",
	[2776] = "+3 Mana every 5 seconds",
	[2777] = "+13 Spirit",
	[2778] = "+13 Spell Penetration",
	[2779] = "+16 Spirit",
	[2780] = "+20 Spell Penetration",
	[2781] = "+19 Stamina",
	[2782] = "+10 Agility",
	[2783] = "+14 Hit Rating",
	[2784] = "+12 Hit Rating",
	[2785] = "+13 Hit Rating",
	[2786] = "+7 Hit Rating",
	[2787] = "+8 Critical Strike Rating",
	[2788] = "+9 Resilience",
	[2789] = "+15 Resilience",
	[2790] = "ZZOLDLesser Rune of Warding",
	[2791] = "Greater Rune of Warding",
	[2792] = "+8 Stamina",
	[2793] = "+8 Defense Rating",
	[2794] = "+4 Mana restored per 5 seconds",
	[2795] = "Comfortable Insoles",
	[2796] = "+15 Dodge Rating",
	[2797] = "+9 Dodge Rating",
	[2798] = "+$i Intellect (+$n/+$f)",
	[2799] = "+$i Stamina (+$n/+$f)",
	[2800] = "+$i Armor (+$n/+$f)",
	[2801] = "+8 Resilience",
	[2802] = "+$i Agility",
	[2803] = "+$i Stamina",
	[2804] = "+$i Intellect",
	[2805] = "+$i Strength",
	[2806] = "+$i Spirit",
	[2807] = "+$i Arcane Damage",
	[2808] = "+$i Fire Damage",
	[2809] = "+$i Nature Damage",
	[2810] = "+$i Frost Damage",
	[2811] = "+$i Shadow Damage",
	[2812] = "+$i Healing",
	[2813] = "+$i Defense Rating",
	[2814] = "+$i Health per 5 sec.",
	[2815] = "+$i Dodge Rating",
	[2816] = "+$i Mana Per 5 sec.",
	[2817] = "+$i Arcane Resistance",
	[2818] = "+$i Fire Resistance",
	[2819] = "+$i Frost Resistance",
	[2820] = "+$i Nature Resistance",
	[2821] = "+$i Shadow Resistance",
	[2822] = "+$i Critical Strike Rating",
	[2823] = "+$i Critical Strike Rating",
	[2824] = "+$i Spell Power",
	[2825] = "+$i Attack Power",
	[2826] = "+$i Block Rating",
	[2827] = "+14 Critical Strike Rating and 1% Spell Reflect",
	[2828] = "Chance to Increase Spell Cast Speed",
	[2829] = "+24 Attack Power and Minor Run Speed Increase",
	[2830] = "+12 Critical Strike Rating and Reduces Snare/Root Duration by 10%",
	[2831] = "+18 Stamina and Stun Duration Reduced by 15%",
	[2832] = "+14 Spell Power and 2% Reduced Threat",
	[2833] = "+12 Defense Rating and Chance to Restore Health on hit",
	[2834] = "+3 Melee Damage and Chance to Stun Target",
	[2835] = "+12 Intellect and Chance to restore mana on spellcast",
	[2836] = "3 mana per 5 sec.",
	[2837] = "+7 Spirit",
	[2838] = "+7 Critical Strike Rating",
	[2839] = "+14 Critical Strike Rating",
	[2840] = "+21 Stamina",
	[2841] = "+10 Stamina",
	[2842] = "+8 Spirit",
	[2843] = "+8 Critical Strike Rating",
	[2844] = "+8 Hit Rating",
	[2845] = "+11 Hit Rating",
	[2846] = "4 mana per 5 sec.",
	[2847] = "4 mana per 5 sec.",
	[2848] = "5 mana per 5 sec.",
	[2849] = "+7 Dodge Rating",
	[2850] = "+13 Critical Strike Rating",
	[2851] = "+19 Stamina",
	[2852] = "7 mana per 5 sec",
	[2853] = "8 mana per 5 sec",
	[2854] = "3 mana per 5 sec",
	[2855] = "5 mana per 5 sec.",
	[2856] = "+4 Resilience Rating",
	[2857] = "+2 Critical Strike Rating",
	[2858] = "+2 Critical Strike Rating",
	[2859] = "+3 Resilience Rating",
	[2860] = "+3 Hit Rating",
	[2861] = "+3 Defense Rating",
	[2862] = "+3 Resilience Rating",
	[2863] = "+3 Intellect",
	[2864] = "+4 Critical Strike Rating",
	[2865] = "+2 mana per 5 sec.",
	[2866] = "+3 Spirit",
	[2867] = "+2 Resilience Rating",
	[2868] = "+6 Stamina",
	[2869] = "+4 Intellect",
	[2870] = "+3 Parry Rating",
	[2871] = "+4 Dodge Rating",
	[2872] = "+5 Spell Power",
	[2873] = "+4 Hit Rating",
	[2874] = "+4 Critical Strike Rating",
	[2875] = "+3 Critical Strike Rating",
	[2876] = "+3 Dodge Rating",
	[2877] = "+4 Agility",
	[2878] = "+4 Resilience Rating",
	[2879] = "+3 Strength",
	[2880] = "+3 Hit Rating",
	[2881] = "+1 Mana per 5 sec.",
	[2882] = "+6 Stamina",
	[2883] = "+4 Stamina",
	[2884] = "+2 Critical Strike Rating",
	[2885] = "+2 Critical Strike Rating",
	[2886] = "+2 Hit Rating",
	[2887] = "+3 Critical Strike Rating",
	[2888] = "+6 Block Value",
	[2889] = "+5 Spell Power",
	[2890] = "+4 Spirit",
	[2891] = "+10 Resilience Rating",
	[2892] = "+4 Strength",
	[2893] = "+3 Agility",
	[2894] = "+7 Strength",
	[2895] = "+4 Stamina",
	[2896] = "+8 Spell Power",
	[2897] = "+3 Stamina, +4 Crit Rating",
	[2898] = "+3 Stamina and +4 Critical Strike Rating",
	[2899] = "+3 Stamina and +4 Critical Strike Rating",
	[2900] = "+4 Spell Power",
	[2901] = "+2 Spell Power",
	[2902] = "+2 Critical Strike Rating",
	[2906] = "+$i Stamina and +$i Intellect",
	[2907] = "+2 Parry Rating",
	[2908] = "+4 Hit Rating",
	[2909] = "+2 Hit Rating",
	[2910] = "+3 Spell Power",
	[2911] = "+10 Strength",
	[2912] = "+12 Spell Power",
	[2913] = "+10 Critical Strike Rating",
	[2914] = "+10 Critical Strike Rating",
	[2915] = "+5 Strength, +5 Crit Rating",
	[2916] = "+5 Critical Strike Rating and +6 Spell Power",
	[2917] = "gem test enchantment",
	[2918] = "+3 Stamina, +4 Crit Rating",
	[2919] = "+7 Strength",
	[2921] = "+3 Stamina and +4 Critical Strike Rating",
	[2922] = "+7 Strength",
	[2923] = "+3 Stamina and +4 Critical Strike Rating",
	[2924] = "+8 Spell Power",
	[2925] = "+3 Stamina",
	[2926] = "+2 Dodge Rating",
	[2927] = "+4 Strength",
	[2928] = "+12 Spell Power",
	[2929] = "+2 Weapon Damage",
	[2930] = "+12 Spell Power",
	[2931] = "+4 All Stats",
	[2932] = "+4 Defense Rating",
	[2933] = "+15 Resilience Rating",
	[2934] = "+10 Critical Strike Rating",
	[2935] = "+15 Hit Rating",
	[2936] = "+8 Attack Power",
	[2937] = "+20 Spell Power",
	[2938] = "+20 Spell Penetration",
	[2939] = "Minor Speed and +6 Agility",
	[2940] = "Minor Speed and +9 Stamina",
	[2941] = "+2 Hit Rating",
	[2942] = "+6 Critical Strike Rating",
	[2943] = "+14 Attack Power",
	[2944] = "+14 Attack Power",
	[2945] = "+20 Attack Power",
	[2946] = "+10 Attack Power, +5 Critical Strike Rating",
	[2947] = "+3 Resist All",
	[2948] = "+4 Resist All",
	[2949] = "+20 Attack Power",
	[2950] = "+10 Critical Strike Rating",
	[2951] = "+4 Critical Strike Rating",
	[2952] = "+4 Critical Strike Rating",
	[2953] = "+2 Spell Power",
	[2954] = "Weighted (+12 Damage)",
	[2955] = "Weighted (+14 Crit Rating and +12 Damage)",
	[2956] = "+4 Strength",
	[2957] = "+4 Agility",
	[2958] = "+5 Spell Power",
	[2959] = "+5 Spell Power",
	[2960] = "+8 Attack Power",
	[2961] = "+6 Stamina",
	[2962] = "+4 Spirit",
	[2963] = "+2 Mana every 5 seconds",
	[2964] = "+4 Intellect",
	[2965] = "+4 Critical Strike Rating",
	[2966] = "+4 Hit Rating",
	[2967] = "+4 Critical Strike Rating",
	[2968] = "+4 Defense Rating",
	[2969] = "+20 Attack Power and Minor Run Speed Increase",
	[2970] = "+12 Spell Power and Minor Run Speed Increase",
	[2971] = "+12 Attack Power",
	[2972] = "+4 Block Rating",
	[2973] = "+6 Attack Power",
	[2974] = "+4 Spell Power",
	[2975] = "+5 Block Value",
	[2976] = "+2 Defense Rating",
	[2977] = "+13 Dodge Rating",
	[2978] = "+15 Dodge Rating and +10 Defense Rating",
	[2979] = "+15 Spell Power",
	[2980] = "+18 Spell Power and +5 Mana every 5 seconds",
	[2981] = "+15 Spell Power",
	[2982] = "+18 Spell Power and +10 Critical Strike Rating",
	[2983] = "+26 Attack Power",
	[2984] = "+8 Shadow Resist",
	[2985] = "+8 Fire Resist",
	[2986] = "+30 Attack Power and +10 Critical Strike Rating",
	[2987] = "+8 Frost Resist",
	[2988] = "+8 Nature Resist",
	[2989] = "+8 Arcane Resist",
	[2990] = "+13 Defense Rating",
	[2991] = "+15 Defense Rating and +10 Dodge Rating",
	[2992] = "+6 Mana Regen",
	[2993] = "+12 Spell Power and 8 Mana every 5 seconds",
	[2994] = "+13 Critical Strike Rating",
	[2995] = "+15 Critical Strike Rating and +12 Spell Power",
	[2996] = "+13 Critical Strike Rating",
	[2997] = "+15 Critical Strike Rating and +20 Attack Power",
	[2998] = "+7 All Resistances",
	[2999] = "+16 Defense Rating and +17 Dodge Rating",
	[3000] = "+18 Stamina, +12 Dodge Rating, and +12 Resilience Rating",
	[3001] = "+19 Spell Power and +9 Mana every 5 seconds",
	[3002] = "+22 Spell Power and +14 Hit Rating",
	[3003] = "+34 Attack Power and +16 Hit Rating",
	[3004] = "+18 Stamina and +20 Resilience Rating",
	[3005] = "+20 Nature Resistance",
	[3006] = "+20 Arcane Resistance",
	[3007] = "+20 Fire Resistance",
	[3008] = "+20 Frost Resistance",
	[3009] = "+20 Shadow Resistance",
	[3010] = "+40 Attack Power and +10 Critical Strike Rating",
	[3011] = "+30 Stamina and +10 Agility",
	[3012] = "+50 Attack Power and +12 Critical Strike Rating",
	[3013] = "+40 Stamina and +12 Agility",
	[3014] = "Windfury Totem 5 (L70 Testing)",
	[3015] = "+2 Strength",
	[3016] = "+2 Intellect",
	[3017] = "+3 Block Rating",
	[3018] = "Rockbiter 9",
	[3019] = "Rockbiter 9",
	[3020] = "Rockbiter 9",
	[3021] = "Rockbiter 1",
	[3022] = "Rockbiter 1",
	[3023] = "Rockbiter 1",
	[3024] = "Rockbiter 2",
	[3025] = "Rockbiter 2",
	[3026] = "Rockbiter 2",
	[3027] = "Rockbiter 3",
	[3028] = "Rockbiter 3",
	[3029] = "Rockbiter 3",
	[3030] = "Rockbiter 4",
	[3031] = "Rockbiter 4",
	[3032] = "Rockbiter 4",
	[3033] = "Rockbiter 5",
	[3034] = "Rockbiter 5",
	[3035] = "Rockbiter 5",
	[3036] = "Rockbiter 6",
	[3037] = "Rockbiter 6",
	[3038] = "Rockbiter 6",
	[3039] = "Rockbiter 7",
	[3040] = "Rockbiter 7",
	[3041] = "Rockbiter 7",
	[3042] = "Rockbiter 8",
	[3043] = "Rockbiter 8",
	[3044] = "Rockbiter 8",
	[3045] = "+5 Strength and +6 Stamina",
	[3046] = "+6 Spell Power and +4 Intellect",
	[3047] = "+6 Stamina and +5 Critical Strike Rating",
	[3048] = "+5 Agility and +6 Stamina",
	[3049] = "+5 Critical Strike Rating and +2 mana per 5 sec.",
	[3050] = "+6 Spell Power and +4 Intellect",
	[3051] = "+6 Spell Power and +6 Stamina",
	[3052] = "+10 Attack Power and +4 Hit Rating",
	[3053] = "+5 Defense Rating and +4 Dodge Rating",
	[3054] = "+6 Spell Power and +6 Stamina",
	[3055] = "+5 Agility and +4 Hit Rating",
	[3056] = "+5 Parry Rating and +4 Defense Rating",
	[3057] = "+5 Strength and +4 Hit Rating",
	[3058] = "+5 Critical Strike Rating and +2 mana per 5 sec",
	[3059] = "+5 Critical Strike Rating and 2 mana per 5 sec.",
	[3060] = "+5 Dodge Rating and +6 Stamina",
	[3061] = "+5 Hit Rating and +6 Spell Power",
	[3062] = "+6 Critical Strike Rating and +5 Dodge Rating",
	[3063] = "+5 Parry Rating and +6 Stamina",
	[3064] = "+5 Spirit and +5 Spell Power",
	[3065] = "+8 Strength",
	[3066] = "+6 Spell Power and +5 Spell Penetration",
	[3067] = "+10 Attack Power and +6 Stamina",
	[3068] = "+5 Dodge Rating and +4 Hit Rating",
	[3069] = "+6 Spell Power and +4 Resilience Rating",
	[3070] = "+8 Attack Power and +5 Critical Strike Rating",
	[3071] = "+5 Intellect and +6 Stamina",
	[3072] = "+5 Strength and +4 Critical Strike Rating",
	[3073] = "+4 Agility and +5 Defense Rating",
	[3074] = "+4 Intellect and +5 Spirit",
	[3075] = "+5 Strength and +4 Defense Rating",
	[3076] = "+4 Critical Strike Rating and +6 Spell Power",
	[3077] = "+5 Intellect and 2 mana per 5 sec.",
	[3078] = "+6 Stamina and +5 Defense Rating",
	[3079] = "+8 Attack Power and +5 Resilience Rating",
	[3080] = "+6 Stamina and +5 Resilience Rating",
	[3081] = "+6 Spell Power and +4 Critical Strike Rating",
	[3082] = "+5 Defense Rating and 2 mana per 5 sec.",
	[3083] = "+6 Spell Power and +4 Spirit",
	[3084] = "+5 Dodge Rating and +4 Resilience Rating",
	[3085] = "+6 Stamina and +5 Critical Strike Rating",
	[3086] = "+6 Spell Power and 2 mana per 5 sec.",
	[3087] = "+5 Strength and +4 Resilience Rating",
	[3088] = "+5 Hit Rating and +6 Stamina",
	[3089] = "+5 Hit Rating and 2 mana per 5 sec.",
	[3090] = "+5 Parry Rating and +4 Resilience Rating",
	[3091] = "+5 Critical Strike Rating and +5 Spell Penetration",
	[3092] = "+3 Critical Strike Rating",
	[3093] = "+150 Attack Power vs Undead and Demons",
	[3094] = "+4 Expertise Rating",
	[3095] = "+8 Resist All",
	[3096] = "+17 Strength and +16 Intellect",
	[3097] = "+2 Spirit",
	[3098] = "+2 Spell Power",
	[3099] = "+6 Spell Power and +6 Stamina",
	[3100] = "+6 Spell Power and +6 Stamina",
	[3101] = "+10 Attack Power and +6 Stamina",
	[3102] = "Poison",
	[3103] = "+8 Strength",
	[3104] = "+6 Hit Rating",
	[3105] = "+8 Hit Rating",
	[3106] = "+6 Attack Power and +4 Stamina",
	[3107] = "+8 Attack Power and +6 Stamina",
	[3108] = "+6 Attack Power & +1 Mana per 5 Seconds",
	[3109] = "+8 Attack Power and +2 Mana every 5 seconds",
	[3110] = "+3 Hit Rating and +4 Spell Power",
	[3111] = "+4 Hit Rating and +5 Spell Power",
	[3112] = "+4 Critical Strike Rating and +8 Attack Power",
	[3113] = "+3 Critical Strike Rating and +6 Attack Power",
	[3114] = "+4 Attack Power",
	[3115] = "+10 Strength",
	[3116] = "+10 Agility",
	[3117] = "+12 Spell Power",
	[3118] = "+12 Spell Power",
	[3119] = "+20 Attack Power",
	[3120] = "+10 Dodge Rating",
	[3121] = "+10 Parry Rating",
	[3122] = "+15 Stamina",
	[3123] = "+10 Spirit",
	[3124] = "+5 Mana every 5 seconds",
	[3125] = "+13 Spell Penetration",
	[3126] = "+10 Intellect",
	[3127] = "+10 Critical Strike Rating",
	[3128] = "+10 Hit Rating",
	[3129] = "+10 Critical Strike Rating",
	[3130] = "+10 Defense Rating",
	[3131] = "+10 Resilience Rating",
	[3132] = "+10 Hit Rating",
	[3133] = "+5 Strength and +7 Stamina",
	[3134] = "+5 Agility and +7 Stamina",
	[3135] = "+10 Attack Power and +7 Stamina",
	[3136] = "+10 Attack Power and +3 Mana every 5 Seconds",
	[3137] = "+6 Spell Power and +7 Stamina",
	[3138] = "+6 Spell Power and +3 Mana every 5 seconds",
	[3139] = "+5 Critical Strike Rating and +5 Strength",
	[3140] = "+5 Critical Strike Rating and +6 Spell Power",
	[3141] = "+6 Spell Power and +5 Intellect",
	[3142] = "+5 Hit Rating and +5 Agility",
	[3143] = "+5 Hit Rating and +6 Spell Power",
	[3144] = "+5 Critical Strike Rating and +10 Attack Power",
	[3145] = "+5 Defense Rating and +7 Stamina",
	[3146] = "+5 Critical Strike Rating and +6 Spell Penetration",
	[3147] = "+5 Intellect and +3 Mana every 5 seconds",
	[3148] = "+5 Critical Strike Rating and +7 Stamina",
	[3149] = "+2 Agility",
	[3150] = "+7 mana every 5 sec.",
	[3151] = "+2 Spell Power",
	[3152] = "+2 Critical Strike Rating",
	[3153] = "+2 Spell Power",
	[3154] = "+12 Agility and 3% Increased Critical Damage",
	[3155] = "Chance to Increase Melee/Ranged Attack Speed",
	[3156] = "+8 Attack Power and +6 Stamina",
	[3157] = "+4 Intellect and +6 Stamina",
	[3158] = "+5 Spell Power and +4 Spirit",
	[3159] = "+8 Attack Power and +4 Critical Strike Rating",
	[3160] = "+5 Spell Power and +4 Intellect",
	[3161] = "+4 Stamina and +4 Critical Strike Rating",
	[3162] = "+24 Attack Power and 5% Stun Resistance",
	[3163] = "+14 Spell Power and 5% Stun Resistance",
	[3164] = "+3 Stamina",
	[3197] = "+20 Attack Power",
	[3198] = "+5 Spell Power",
	[3199] = "+170 Armor",
	[3200] = "+4 Spirit and +5 Spell Power",
	[3201] = "+4 Spell Power and +3 Spirit",
	[3202] = "+5 Spell Power and +4 Spirit",
	[3204] = "+3 Critical Strike Rating",
	[3205] = "+3 Critical Strike Rating",
	[3206] = "+8 Agility",
	[3207] = "+12 Strength",
	[3208] = "+24 Attack Power",
	[3209] = "+12 Agility",
	[3210] = "+14 Spell Power",
	[3211] = "+14 Spell Power",
	[3212] = "+18 Stamina",
	[3213] = "+6 Mana every 5 seconds",
	[3214] = "+12 Spirit",
	[3215] = "+12 Resilience Rating",
	[3216] = "+12 Intellect",
	[3217] = "+12 Critical Strike Rating",
	[3218] = "+12 Hit Rating",
	[3219] = "+12 Hit Rating",
	[3220] = "+12 Critical Strike Rating",
	[3221] = "+12 Defense Rating",
	[3222] = "+20 Agility",
	[3223] = "Adamantite Weapon Chain",
	[3224] = "+6 Agility",
	[3225] = "Executioner",
	[3226] = "+4 Resilience Rating and +6 Stamina",
	[3227] = "+10 Critical Strike Rating",
	[3228] = "+34 Attack Power",
	[3229] = "+12 Resilience Rating",
	[3230] = "+20 Frost Resistance",
	[3231] = "+15 Expertise Rating",
	[3232] = "+15 Stamina and Minor Speed Increase",
	[3233] = "+250 Mana",
	[3234] = "+20 Hit Rating",
	[3235] = "+12 Resist All",
	[3236] = "+200 Health",
	[3237] = "+10 Weapon Damage",
	[3238] = "Gatherer",
	[3239] = "Icebreaker Weapon",
	[3240] = "+23 Spell Power",
	[3241] = "Lifeward",
	[3242] = "+5 Resist All",
	[3243] = "+35 Spell Penetration",
	[3244] = "+7 Health and Mana every 5 sec",
	[3245] = "+20 Resilience Rating",
	[3246] = "+28 Spell Power",
	[3247] = "+140 Attack Power versus Undead",
	[3248] = "+18 Expertise Rating",
	[3249] = "+16 Critical Strike Rating",
	[3250] = "Icewalker",
	[3251] = "Giantslaying",
	[3252] = "+8 All Stats",
	[3253] = "+2% Threat and 10 Parry Rating",
	[3254] = "+4 All Stats",
	[3255] = "+55 Spell Power",
	[3256] = "Increased Stealth and +10 Agility",
	[3257] = "+54 Spell Power",
	[3258] = "+18 Spell Power",
	[3259] = "+22 Stamina",
	[3260] = "+240 Armor",
	[3261] = "+12 Critical Strike Rating and 3% Increased Critical Damage",
	[3262] = "+15 Stamina",
	[3263] = "+4 Critical Strike Rating",
	[3264] = "+150 Armor, -10% Speed",
	[3265] = "Blessed Weapon Coating",
	[3266] = "Righteous Weapon Coating",
	[3267] = "+4 Haste Rating",
	[3268] = "+15 Stamina",
	[3269] = "+3 Fishing",
	[3270] = "+8 Haste Rating",
	[3271] = "+4 Haste Rating and +5 Spell Power",
	[3272] = "+4 Haste Rating and +6 Stamina",
	[3273] = "Deathfrost",
	[3274] = "+12 Defense Rating and +5% Shield Block Value",
	[3275] = "+14 Spell Power and +2% Intellect",
	[3276] = "+20 Attack Power",
	[3277] = "+12 Spell Power",
	[3278] = "+12 Spell Power",
	[3279] = "+3 Spell Power",
	[3280] = "+4 Dodge Rating and +6 Stamina",
	[3281] = "+20 Attack Power",
	[3282] = "+12 Spell Power",
	[3283] = "+12 Spell Power",
	[3284] = "+5 Resilience Rating and +7 Stamina",
	[3285] = "+5 Haste Rating and +7 Stamina",
	[3286] = "+5 Haste Rating and +6 Spell Power",
	[3287] = "+10 Haste Rating",
	[3288] = "Test Riding Crop Enchant",
	[3289] = "+10% Mount Speed",
-- ############## Wrath IDs ##########################################
-- ############## Wrath IDs ##########################################
-- ############## Wrath IDs ##########################################
	[3292] = "+68 Attack Power",
	[3293] = "+51 Stamina",
	[3294] = "+225 Armor",
	[3295] = "+16 Haste Rating",
	[3296] = "+10 Spirit and 2% Reduced Threat",
	[3297] = "+275 Health",
	[3298] = "Exceptional Mana Oil",
	[3299] = "Exceptional Wizard Oil",
	[3300] = "+19 Spell Power",
	[3301] = "+6 Critical Strike Rating",
	[3302] = "+8 Defense Rating",
	[3303] = "+8 Haste Rating",
	[3304] = "+8 Dodge Rating",
	[3305] = "+12 Stamina",
	[3306] = "2 mana per 5 sec.",
	[3307] = "+9 Stamina",
	[3308] = "+4 Haste Rating",
	[3309] = "+6 Haste Rating",
	[3310] = "+6 Intellect",
	[3311] = "+6 Spirit",
	[3312] = "+8 Strength",
	[3313] = "+8 Agility",
	[3314] = "+8 Critical Strike Rating",
	[3315] = "+3% Mount Speed",
	[3316] = "+6 Critical Strike Rating",
	[3317] = "+21 Stamina",
	[3318] = "+6 Spell Power and +5 Spirit",
	[3319] = "Test Add Sockets Enchant",
	[3320] = "Test Skill Req Enchant",
	[3321] = "+150 Armor",
	[3322] = "Frozen Rune Weapon",
	[3324] = "+10 Critical Strike Rating",
	[3325] = "+45 Stamina and +15 Agility",
	[3326] = "+55 Attack Power and +15 Critical Strike Rating",
	[3327] = "+55 Stamina and +22 Agility",
	[3328] = "+75 Attack Power and +22 Critical Strike Rating",
	[3329] = "+12 Stamina",
	[3330] = "+18 Stamina",
	[3331] = "+72 Stamina and +35 Agility",
	[3332] = "+100 Attack Power and +36 Critical Strike Rating",
	[3333] = "QA Test Blank Purple Gem Enchant",
	[3334] = "Northrend Flight",
	[3335] = "+20 Attack Power",
	[3336] = "+10 Critical Strike Rating",
	[3337] = "+10 Attack Power and +5 Critical Strike Rating",
	[3338] = "+6 Spell Power and +5 Critical Strike Rating",
	[3339] = "+12 Spell Power",
	[3340] = "+10 Critical Strike Rating",
	[3341] = "Frozen Rune Weapon 2",
	[3342] = "Frozen Rune Weapon 3",
	[3343] = "Frozen Rune Weapon 4",
	[3344] = "Frozen Rune Weapon 5",
	[3345] = "Earthliving 1",
	[3346] = "Earthliving 2",
	[3347] = "Earthliving 3",
	[3348] = "Earthliving 4",
	[3349] = "Earthliving 5",
	[3350] = "Earthliving 6",
	[3351] = "+6 Hit Rating",
	[3352] = "+8 Spirit",
	[3353] = "+8 Intellect",
	[3354] = "+12 Stamina",
	[3355] = "+6 Agility",
	[3356] = "+12 Attack Power",
	[3357] = "+6 Strength",
	[3358] = "+6 Dodge Rating",
	[3359] = "+4 Parry Rating",
	[3360] = "+8 Parry Rating",
	[3361] = "+6 Block Rating",
	[3362] = "+6 Expertise Rating",
	[3363] = "+9 Block Value",
	[3364] = "Empower Rune Weapon",
	[3365] = "Rune of Swordshattering",
	[3366] = "Rune of Lichbane",
	[3367] = "Rune of Spellshattering",
	[3368] = "Rune of the Fallen Crusader",
	[3369] = "Rune of Cinderglacier",
	[3370] = "Rune of Razorice",
	[3371] = "+12 Strength",
	[3374] = "+12 Agility",
	[3375] = "+24 Attack Power",
	[3376] = "+12 Dodge Rating",
	[3377] = "+12 Parry Rating",
	[3378] = "+12 Armor Penetration Rating",
	[3379] = "+12 Expertise Rating",
	[3380] = "+14 Spell Power",
	[3381] = "+12 Intellect",
	[3382] = "+12 Critical Strike Rating",
	[3383] = "+12 Hit Rating",
	[3384] = "+12 Defense Rating",
	[3385] = "+12 Resilience Rating",
	[3386] = "+12 Haste Rating",
	[3387] = "+18 Stamina",
	[3388] = "+12 Spirit",
	[3389] = "+6 Mana every 5 seconds",
	[3390] = "+15 Spell Penetration",
	[3391] = "+6 Armor Penetration Rating and +9 Stamina",
	[3392] = "+6 Strength and +9 Stamina",
	[3393] = "+6 Agility and +9 Stamina",
	[3394] = "+7 Spell Power and +9 Stamina",
	[3395] = "+12 Attack Power and +9 Stamina",
	[3396] = "+6 Dodge Rating and +9 Stamina",
	[3397] = "+6 Parry Rating and +9 Stamina",
	[3398] = "+6 Expertise Rating and +9 Stamina",
	[3399] = "+7 Spell Power and +6 Spirit",
	[3400] = "+6 Agility and +3 Mana every 5 seconds",
	[3401] = "+7 Spell Power and +3 Mana every 5 seconds",
	[3402] = "+12 Attack Power and +3 Mana every 5 seconds",
	[3403] = "+7 Spell Power and +8 Spell Penetration",
	[3404] = "+7 Spell Power and +6 Intellect",
	[3405] = "+6 Strength and +6 Critical Strike Rating",
	[3406] = "+6 Agility and +6 Hit Rating",
	[3407] = "+6 Strength and +6 Defense Rating",
	[3408] = "+6 Strength and +6 Resilience Rating",
	[3409] = "+6 Strength and +6 Haste Rating",
	[3410] = "+6 Agility and +6 Critical Strike Rating",
	[3411] = "+6 Strength and +6 Hit Rating",
	[3412] = "+6 Agility and +6 Resilience Rating",
	[3413] = "+6 Agility and +6 Haste Rating",
	[3414] = "+7 Spell Power and +6 Critical Strike Rating",
	[3415] = "+7 Spell Power and +6 Hit Rating",
	[3416] = "+7 Spell Power and +6 Resilience Rating",
	[3417] = "+7 Spell Power and +6 Haste Rating",
	[3418] = "+6 Dodge Rating and +6 Defense Rating",
	[3419] = "+6 Parry Rating and +6 Defense Rating",
	[3420] = "+6 Expertise Rating and +6 Hit Rating",
	[3421] = "+6 Expertise Rating and +6 Defense Rating",
	[3422] = "+12 Attack Power and +6 Critical Strike Rating",
	[3423] = "+12 Attack Power and +6 Hit Rating",
	[3424] = "+12 Attack Power and +6 Resilience Rating",
	[3426] = "+12 Attack Power and +6 Haste Rating",
	[3427] = "+6 Intellect and +9 Stamina",
	[3428] = "+6 Critical Strike Rating and +9 Stamina",
	[3429] = "+6 Hit Rating and +9 Stamina",
	[3430] = "+6 Defense Rating and +9 Stamina",
	[3431] = "+6 Resilience Rating and +9 Stamina",
	[3432] = "+6 Haste Rating and +9 Stamina",
	[3433] = "+6 Intellect and +6 Spirit",
	[3434] = "+6 Critical Strike Rating and +6 Spirit",
	[3435] = "+6 Hit Rating and +6 Spirit",
	[3436] = "+6 Resilience Rating and +6 Spirit",
	[3437] = "+6 Haste Rating and +6 Spirit",
	[3438] = "+6 Intellect and +3 Mana every 5 seconds",
	[3439] = "+6 Critical Strike Rating and +3 Mana every 5 seconds",
	[3440] = "+6 Hit Rating and +3 Mana every 5 seconds",
	[3441] = "+6 Resilience Rating and +3 Mana every 5 seconds",
	[3442] = "+6 Haste Rating and +3 Mana every 5 seconds",
	[3443] = "+6 Critical Strike Rating and +8 Spell Penetration",
	[3444] = "+6 Hit Rating and +8 Spell Penetration",
	[3445] = "+6 Haste Rating and +8 Spell Penetration",
	[3446] = "+16 Strength",
	[3447] = "+16 Agility",
	[3448] = "+19 Spell Power",
	[3449] = "+32 Attack Power",
	[3450] = "+16 Dodge Rating",
	[3451] = "+16 Parry Rating",
	[3452] = "+16 Armor Penetration Rating",
	[3453] = "+16 Expertise Rating",
	[3454] = "+24 Stamina",
	[3455] = "+16 Spirit",
	[3456] = "+8 Mana every 5 seconds",
	[3457] = "+20 Spell Penetration",
	[3458] = "+16 Intellect",
	[3459] = "+16 Critical Strike Rating",
	[3460] = "+16 Hit Rating",
	[3461] = "+16 Defense Rating",
	[3462] = "+16 Resilience Rating",
	[3463] = "+16 Haste Rating",
	[3464] = "+8 Strength and +12 Stamina",
	[3465] = "+8 Agility and +12 Stamina",
	[3466] = "+9 Spell Power and +12 Stamina",
	[3467] = "+16 Attack Power and +12 Stamina",
	[3468] = "+8 Dodge Rating and +12 Stamina",
	[3469] = "+8 Parry Rating and +12 Stamina",
	[3470] = "+8 Armor Penetration Rating and +12 Stamina",
	[3471] = "+8 Expertise Rating and +12 Stamina",
	[3472] = "+9 Spell Power and +8 Spirit",
	[3473] = "+9 Spell Power and +4 Mana every 5 seconds",
	[3474] = "+8 Agility and +4 Mana every 5 seconds",
	[3475] = "+16 Attack Power and +4 Mana every 5 seconds",
	[3476] = "+9 Spell Power and +10 Spell Penetration",
	[3477] = "+8 Strength and +8 Critical Strike Rating",
	[3478] = "+8 Strength and +8 Hit Rating",
	[3479] = "+8 Strength and +8 Defense Rating",
	[3480] = "+8 Strength and +8 Resilience Rating",
	[3481] = "+8 Strength and +8 Haste Rating",
	[3482] = "+8 Agility and +8 Critical Strike Rating",
	[3483] = "+8 Agility and +8 Hit Rating",
	[3484] = "+8 Agility and +8 Resilience Rating",
	[3485] = "+8 Agility and +8 Haste Rating",
	[3486] = "+9 Spell Power and +8 Intellect",
	[3487] = "+9 Spell Power and +8 Critical Strike Rating",
	[3488] = "+9 Spell Power and +8 Hit Rating",
	[3489] = "+9 Spell Power and +8 Resilience Rating",
	[3490] = "+9 Spell Power and +8 Haste Rating",
	[3491] = "+16 Attack Power and +8 Critical Strike Rating",
	[3492] = "+16 Attack Power and +8 Hit Rating",
	[3493] = "+16 Attack Power and +8 Resilience Rating",
	[3494] = "+16 Attack Power and +8 Haste Rating",
	[3495] = "+8 Dodge Rating and +8 Defense Rating",
	[3496] = "+8 Parry Rating and +8 Defense Rating",
	[3497] = "+8 Expertise Rating and +8 Hit Rating",
	[3498] = "+8 Expertise Rating and +8 Defense Rating",
	[3499] = "+8 Intellect and +12 Stamina",
	[3500] = "+8 Critical Strike Rating and +12 Stamina",
	[3501] = "+8 Hit Rating and +12 Stamina",
	[3502] = "+8 Defense Rating and +12 Stamina",
	[3503] = "+8 Resilience Rating and +12 Stamina",
	[3504] = "+8 Haste Rating and +12 Stamina",
	[3505] = "+8 Intellect and +8 Spirit",
	[3506] = "+8 Critical Strike Rating and +8 Spirit",
	[3507] = "+8 Hit Rating and +8 Spirit",
	[3508] = "+8 Resilience Rating and +8 Spirit",
	[3509] = "+8 Haste Rating and +8 Spirit",
	[3510] = "+8 Intellect and +4 Mana every 5 seconds",
	[3511] = "+8 Critical Strike Rating and +4 Mana every 5 seconds",
	[3512] = "+8 Hit Rating and +4 Mana every 5 seconds",
	[3513] = "+8 Resilience Rating and +4 Mana every 5 seconds",
	[3514] = "+8 Haste Rating and +4 Mana every 5 seconds",
	[3515] = "+8 Critical Strike Rating and +10 Spell Penetration",
	[3516] = "+8 Hit Rating and +10 Spell Penetration",
	[3517] = "+8 Haste Rating and +10 Spell Penetration",
	[3518] = "+20 Strength",
	[3519] = "+20 Agility",
	[3520] = "+23 Spell Power",
	[3521] = "+40 Attack Power",
	[3522] = "+20 Dodge Rating",
	[3523] = "+20 Parry Rating",
	[3524] = "+20 Expertise Rating",
	[3525] = "+20 Armor Penetration Rating",
	[3526] = "+20 Intellect",
	[3527] = "+20 Critical Strike Rating",
	[3528] = "+20 Hit Rating",
	[3529] = "+20 Defense Rating",
	[3530] = "+20 Resilience Rating",
	[3531] = "+20 Haste Rating",
	[3532] = "+30 Stamina",
	[3533] = "+20 Spirit",
	[3534] = "+10 Mana every 5 seconds",
	[3535] = "+25 Spell Penetration",
	[3536] = "+10 Strength and +15 Stamina",
	[3537] = "+10 Agility and +15 Stamina",
	[3538] = "+12 Spell Power and +15 Stamina",
	[3539] = "+20 Attack Power and +15 Stamina",
	[3540] = "+10 Dodge Rating and +15 Stamina",
	[3541] = "+10 Parry Rating and +15 Stamina",
	[3542] = "+10 Expertise Rating and +15 Stamina",
	[3543] = "+10 Armor Penetration Rating and +15 Stamina",
	[3544] = "+10 Agility and +5 Mana every 5 seconds",
	[3545] = "+12 Spell Power and +10 Spirit",
	[3546] = "+12 Spell Power and +5 Mana every 5 seconds",
	[3547] = "+20 Attack Power and +5 Mana every 5 seconds",
	[3548] = "+12 Spell Power and +13 Spell Penetration",
	[3549] = "+10 Strength and +10 Critical Strike Rating",
	[3550] = "+10 Strength and +10 Hit Rating",
	[3551] = "+10 Strength and +10 Defense Rating",
	[3552] = "+10 Strength and +10 Resilience Rating",
	[3553] = "+10 Strength and +10 Haste Rating",
	[3554] = "+10 Agility and +10 Critical Strike Rating",
	[3555] = "+10 Agility and +10 Hit Rating",
	[3556] = "+10 Agility and +10 Resilience Rating",
	[3557] = "+10 Agility and +10 Haste Rating",
	[3558] = "+12 Spell Power and +10 Intellect",
	[3559] = "+12 Spell Power and +10 Critical Strike Rating",
	[3560] = "+12 Spell Power and +10 Hit Rating",
	[3561] = "+12 Spell Power and +10 Resilience Rating",
	[3563] = "+12 Spell Power and +10 Haste Rating",
	[3564] = "+20 Attack Power and +10 Critical Strike Rating",
	[3565] = "+20 Attack Power and +10 Hit Rating",
	[3566] = "+20 Attack Power and +10 Resilience Rating",
	[3567] = "+20 Attack Power and +10 Haste Rating",
	[3568] = "+10 Dodge Rating and +10 Defense Rating",
	[3569] = "+10 Parry Rating and +10 Defense Rating",
	[3570] = "+10 Expertise Rating and +10 Hit Rating",
	[3571] = "+10 Expertise Rating and +10 Defense Rating",
	[3572] = "+10 Intellect and +15 Stamina",
	[3573] = "+10 Critical Strike Rating and +15 Stamina",
	[3574] = "+10 Hit Rating and +15 Stamina",
	[3575] = "+10 Defense Rating and +15 Stamina",
	[3576] = "+10 Resilience Rating and +15 Stamina",
	[3577] = "+10 Haste Rating and +15 Stamina",
	[3578] = "+10 Intellect and +10 Spirit",
	[3579] = "+10 Critical Strike Rating and +10 Spirit",
	[3580] = "+10 Hit Rating and +10 Spirit",
	[3581] = "+10 Resilience Rating and +10 Spirit",
	[3582] = "+10 Haste Rating and +10 Spirit",
	[3583] = "+10 Intellect and +5 Mana every 5 seconds",
	[3584] = "+10 Critical Strike Rating and +5 Mana every 5 seconds",
	[3585] = "+10 Hit Rating and +5 Mana every 5 seconds",
	[3586] = "+10 Resilience Rating and +5 Mana every 5 seconds",
	[3587] = "+10 Haste Rating and +5 Mana every 5 seconds",
	[3588] = "+10 Critical Strike Rating and +13 Spell Penetration",
	[3589] = "+10 Hit Rating and +13 Spell Penetration",
	[3590] = "+10 Haste Rating and +13 Spell Penetration",
	[3591] = "Test +4 Intellect and +2 Mana every 5 seconds",
	[3592] = "+100 Spell Power vs Undead",
	[3593] = "+170 Attack Power vs Undead",
	[3594] = "Rune of Swordbreaking",
	[3595] = "Rune of Spellbreaking",
	[3596] = "+5 Spell Power",
	[3597] = "Master Firestone",
	[3600] = "+6 Resilience Rating",
	[3602] = "+7 Spell Power",
	[3607] = "+40 Ranged Haste Rating",
	[3608] = "+40 Ranged Critical Strike",
	[3609] = "Lesser Firestone",
	[3610] = "Firestone",
	[3611] = "Greater Firestone",
	[3612] = "Major Firestone",
	[3613] = "Fel Firestone",
	[3614] = "Grand Firestone",
	[3615] = "Spellstone",
	[3616] = "Greater Spellstone",
	[3617] = "Major Spellstone",
	[3618] = "Master Spellstone",
	[3619] = "Demonic Spellstone",
	[3620] = "Grand Spellstone",
	[3621] = "+21 Critical Strike Rating and 3% Increased Critical Damage",
	[3622] = "+25 Critical Strike Rating and 1% Spell Reflect",
	[3623] = "+25 Spell Power and +2% Intellect",
	[3624] = "+21 Critical Strike Rating and Reduces Snare/Root Duration by 10%",
	[3625] = "+42 Attack Power and Minor Run Speed Increase",
	[3626] = "+25 Spell Power and 2% Reduced Threat",
	[3627] = "+21 Intellect and Chance to restore mana on spellcast",
	[3628] = "+21 Agility and 3% Increased Critical Damage",
	[3630] = "+21 Defense Rating and Chance to Restore Health on hit",
	[3631] = "+21 Defense Rating and +5% Shield Block Value",
	[3632] = "+25 Spell Power and Minor Run Speed Increase",
	[3633] = "+11 Mana every 5 seconds and 3% Increased Critical Healing Effect",
	[3634] = "+32 Stamina and Reduce Spell Damage Taken by 2%",
	[3635] = "+25 Spell Power and Silence Duration Reduced by 10%",
	[3636] = "+21 Critical Strike Rating and Fear Duration Reduced by 10%",
	[3637] = "+32 Stamina and 2% Increased Armor Value from Items",
	[3638] = "+42 Attack Power and Stun Duration Reduced by 10%",
	[3639] = "+25 Spell Power and Stun Duration Reduced by 10%",
	[3640] = "+42 Attack Power and Sometimes Heal on Your Crits",
	[3641] = "+21 Critical Strike Rating and +2% Mana",
	[3642] = "+32 Stamina and Stun Duration Reduced by 10%",
	[3643] = "Chance to Increase Melee/Ranged Attack Speed",
	[3644] = "+14 Agility",
	[3646] = "+14 Dodge Rating",
	[3647] = "+14 Expertise Rating",
	[3648] = "+14 Parry Rating",
	[3649] = "+14 Strength",
	[3650] = "+16 Spell Power",
	[3651] = "+28 Attack Power",
	[3652] = "+14 Armor Penetration Rating",
	[3653] = "+14 Spirit",
	[3654] = "+7 Mana every 5 seconds",
	[3655] = "+21 Stamina",
	[3656] = "+18 Spell Penetration",
	[3657] = "+14 Critical Strike Rating",
	[3658] = "+14 Defense Rating",
	[3659] = "+14 Haste Rating",
	[3660] = "+14 Hit Rating",
	[3661] = "+14 Intellect",
	[3662] = "+14 Resilience Rating",
	[3663] = "+14 Attack Power and +4 Mana every 5 seconds",
	[3664] = "+14 Attack Power and +11 Stamina",
	[3665] = "+7 Armor Penetration Rating and +11 Stamina",
	[3666] = "+7 Agility and +4 Mana every 5 seconds",
	[3667] = "+7 Agility and +11 Stamina",
	[3668] = "+7 Dodge Rating and +11 Stamina",
	[3669] = "+7 Expertise Rating and +11 Stamina",
	[3670] = "+7 Parry Rating and +11 Stamina",
	[3671] = "+7 Strength and +11 Stamina",
	[3672] = "+8 Spell Power and +4 Mana every 5 seconds",
	[3673] = "+8 Spell Power and +7 Spirit",
	[3674] = "+8 Spell Power and +9 Spell Penetration",
	[3675] = "+8 Spell Power and +11 Stamina",
	[3676] = "+14 Attack Power and +7 Critical Strike Rating (OLD)",
	[3677] = "+7 Agility and +7 Haste Rating",
	[3678] = "+14 Attack Power and +7 Haste Rating",
	[3679] = "+14 Attack Power and +7 Hit Rating",
	[3680] = "+14 Attack Power and +7 Resilience Rating",
	[3681] = "+7 Strength and +7 Critical Strike Rating",
	[3682] = "+7 Strength and +7 Hit Rating",
	[3683] = "+7 Strength and +7 Defense Rating",
	[3684] = "+7 Strength and +7 Resilience Rating",
	[3685] = "+7 Strength and +7 Haste Rating",
	[3686] = "+7 Agility and +7 Critical Strike Rating",
	[3687] = "+7 Agility and +7 Hit Rating",
	[3688] = "+7 Agility and +7 Resilience Rating",
	[3689] = "+8 Spell Power and +7 Intellect",
	[3690] = "+8 Spell Power and +7 Critical Strike Rating",
	[3691] = "+8 Spell Power and +7 Hit Rating",
	[3692] = "+8 Spell Power and +7 Resilience Rating",
	[3693] = "+8 Spell Power and +7 Haste Rating",
	[3694] = "+7 Dodge Rating and +7 Defense Rating",
	[3695] = "+7 Parry Rating and +7 Defense Rating",
	[3696] = "+7 Expertise Rating and +7 Hit Rating",
	[3697] = "+7 Expertise Rating and +7 Defense Rating",
	[3698] = "+7 Critical Strike Rating and +7 Spirit",
	[3699] = "+7 Critical Strike Rating and +11 Stamina",
	[3700] = "+7 Defense Rating and +11 Stamina",
	[3701] = "+7 Haste Rating and +7 Spirit",
	[3702] = "+7 Haste Rating and +11 Stamina",
	[3703] = "+7 Hit Rating and +7 Spirit",
	[3704] = "+7 Hit Rating and +11 Stamina",
	[3705] = "+7 Intellect and +7 Spirit",
	[3706] = "+7 Intellect and +11 Stamina",
	[3707] = "+7 Resilience Rating and +7 Spirit",
	[3708] = "+7 Resilience Rating and +11 Stamina",
	[3709] = "+7 Critical Strike Rating and +9 Spell Penetration",
	[3710] = "+7 Critical Strike Rating and +4 Mana every 5 seconds",
	[3711] = "+7 Intellect and +4 Mana every 5 seconds",
	[3712] = "+7 Hit Rating and +4 Mana every 5 seconds",
	[3713] = "+7 Resilience Rating and +4 Mana every 5 seconds",
	[3714] = "+7 Haste Rating and +4 Mana every 5 seconds",
	[3715] = "+7 Hit Rating and +9 Spell Penetration",
	[3716] = "+7 Haste Rating and +9 Spell Penetration",
	[3717] = "Socket Bracer",
	[3718] = "+35 Spell Power and +12 Spirit",
	[3719] = "+50 Spell Power and +20 Spirit",
	[3720] = "+35 Spell Power and +20 Stamina",
	[3721] = "+50 Spell Power and +30 Stamina",
	[3722] = "Lightweave Embroidery",
	[3723] = "Socket Gloves",
	[3726] = "+$i Haste Rating",
	[3727] = "+$i Hit Rating",
	[3728] = "Darkglow Embroidery",
	[3729] = "Socket Belt",
	[3730] = "Swordguard Embroidery",
	[3731] = "Titanium Weapon Chain",
	[3732] = "+34 Strength",
	[3733] = "+34 Agility",
	[3734] = "+39 Spell Power",
	[3735] = "+34 Spirit",
	[3736] = "+17 Mana every 5 seconds",
	[3737] = "+34 Intellect",
	[3738] = "+34 Critical Strike Rating",
	[3739] = "+34 Haste Rating",
	[3740] = "+34 Dodge Rating",
	[3741] = "+34 Parry Rating",
	[3742] = "+34 Hit Rating",
	[3743] = "+34 Defense Rating",
	[3744] = "+34 Resilience Rating",
	[3745] = "+34 Armor Penetration Rating",
	[3746] = "+34 Expertise Rating",
	[3747] = "+43 Spell Penetration",
	[3748] = "Titanium Spike (45-67)",
	[3749] = "+4 to All Stats",
	[3750] = "+6 to All Stats",
	[3751] = "+6 Defense Rating",
	[3752] = "+5 Spell Power",
	[3753] = "+9 Spell Power",
	[3754] = "+24 Attack Power +10 Stamina +10 Hit Rating",
	[3755] = "+28 Attack Power +12 Dodge Rating",
	[3756] = "+130 Attack Power",
	[3757] = "+102 Stamina",
	[3758] = "+76 Spell Power",
	[3759] = "+70 Fire Resistance",
	[3760] = "+70 Frost Resistance",
	[3761] = "+70 Shadow Resistance",
	[3762] = "+70 Nature Resistance",
	[3763] = "+70 Arcane Resistance",
	[3764] = "+12 Attack Power",
	[3765] = "+4 Armor Penetration Rating",
	[3766] = "+12 Stamina",
	[3767] = "+14 Attack Power and +7 Critical Strike Rating",
	[3768] = "Instant Poison VIII",
	[3769] = "Instant Poison IX",
	[3770] = "Deadly Poison VIII",
	[3771] = "Deadly Poison IX",
	[3772] = "Wound Poison VI",
	[3773] = "Wound Poison VII",
	[3774] = "Anesthetic Poison II",
	[3775] = "+30 Spell Power and +15 Critical Strike Rating",
	[3776] = "+45 Attack Power and +15 Critical Strike Rating",
	[3777] = "+20 Defense and +15 Dodge Rating",
	[3778] = "+8 Expertise Rating",
	[3779] = "Flametongue 8",
	[3780] = "Flametongue 9",
	[3781] = "Flametongue 10",
	[3782] = "Frostbrand 7",
	[3783] = "Frostbrand 8",
	[3784] = "Frostbrand 9",
	[3785] = "Windfury 6",
	[3786] = "Windfury 7",
	[3787] = "Windfury 8",
	[3788] = "+25 Hit Rating and +25 Critical Strike Rating",
	[3789] = "Berserking",
	[3790] = "Black Magic",
	[3791] = "+30 Stamina",
	[3792] = "+20 Resilience Rating",
	[3793] = "+40 Attack Power and +15 Resilience Rating",
	[3794] = "+23 Spell Power and +15 Resilience Rating",
	[3795] = "+50 Attack Power and +20 Resilience Rating",
	[3796] = "+29 Spell Power and +20 Resilience Rating",
	[3797] = "+29 Spell Power and +20 Resilience Rating",
	[3798] = "+34 Attack Power and Minor Run Speed Increase",
	[3799] = "+20 Spell Power and Minor Run Speed Increase",
	[3800] = "+17 Critical Strike Rating and Fear Duration Reduced by 10%",
	[3801] = "+17 Critical Strike Rating and Reduces Snare/Root Duration by 10%",
	[3802] = "+20 Spell Power and Silence Duration Reduced by 10%",
	[3803] = "+34 Attack Power and Stun Duration Reduced by 10%",
	[3804] = "+26 Stamina and Stun Duration Reduced by 10%",
	[3805] = "+20 Spell Power and Stun Duration Reduced by 10%",
	[3806] = "+18 Spell Power and +10 Critical Strike Rating",
	[3807] = "+18 Spell Power and +5 Mana per 5 sec",
	[3808] = "+40 Attack Power and +15 Crit Rating",
	[3809] = "+24 Spell Power and +8 Mana per 5 sec",
	[3810] = "+24 Spell Power and +15 Critical Strike Rating",
	[3811] = "+20 Dodge Rating and +15 Defense Rating",
	[3812] = "+25 Frost Resistance and +30 Stamina",
	[3813] = "+25 Nature Resistance and +30 Stamina",
	[3814] = "+25 Shadow Resistance and +30 Stamina",
	[3815] = "+25 Arcane Resistance and +30 Stamina",
	[3816] = "+25 Fire Resistance and +30 Stamina",
	[3817] = "+50 Attack Power and +20 Critical Strike Rating",
	[3818] = "+37 Stamina and +20 Defense Rating",
	[3819] = "+30 Spell Power and 10 mana per 5 seconds.",
	[3820] = "+30 Spell Power and 20 Critical strike rating.",
	[3821] = "+8 Resilience Rating",
	[3822] = "+55 Stamina and +22 Agility",
	[3823] = "+75 Attack Power and +22 Critical Strike Rating",
	[3824] = "+24 Attack Power",
	[3825] = "+15 Haste Rating",
	[3826] = "+12 Hit Rating and +12 Critical Strike Rating",
	[3827] = "+110 Attack Power",
	[3828] = "+85 Attack Power",
	[3829] = "+35 Attack Power",
	[3830] = "+50 Spell Power",
	[3831] = "+23 Haste Rating",
	[3832] = "+10 All Stats",
	[3833] = "+65 Attack Power",
	[3834] = "+63 Spell Power",
	[3835] = "+120 Attack Power and +15 Crit Rating",
	[3836] = "+70 Spell Power and +6 Mana/5 seconds",
	[3837] = "+60 Dodge Rating and +15 Defense Rating",
	[3838] = "+70 Spell Power and +15 Crit Rating",
	[3839] = "+40 Attack Power",
	[3840] = "+23 Spell Power",
	[3841] = "+23 Spell Power",
	[3842] = "+30 Stamina and +25 Resilience Rating",
	[3843] = "Scp (+15 Damage)",
	[3844] = "+45 Spirit",
	[3845] = "+50 Attack Power",
	[3846] = "+40 Spell Power",
	[3847] = "Rune of the Stoneskin Gargoyle",
	[3848] = "Socket Staff",
	[3849] = "Titanium Plating",
	[3850] = "+40 Stamina",
	[3851] = "+50 Stamina",
	[3852] = "+30 Stamina and +15 Resilience Rating",
	[3853] = "+40 Resilience Rating and +28 Stamina",
	[3854] = "+81 Spell Power",
	[3855] = "+69 Spell Power",
	[3856] = "+100 Agility",
	[3857] = "+6 Defense Rating",
	[3858] = "+5 Hit Rating",
	[3860] = "+885 Armor",
	[3861] = "+20 Strength",
	[3862] = "+20 Agility",
	[3863] = "+30 Stamina",
	[3864] = "+20 Spirit",
	[3865] = "+20 Intellect",
	[3866] = "+23 Spell Power",
	[3867] = "+20 Hit Rating",
	[3868] = "Fishing Lure (+100 Fishing Skill)",
	[3869] = "Blade Ward",
	[3870] = "Blood Draining",
	[3871] = "+6 Parry Rating",
	[3872] = "+50 Spell Power and +20 Spirit",
	[3873] = "+50 Spell Power and +30 Stamina",
	[3874] = "+130 Attack Power",
	[3875] = "+30 Attack Power and +10 Critical Strike Rating",
	[3876] = "+15 Dodge Rating and +10 Defense Rating",
	[3877] = "+16 Attack Power",
	[3879] = "+10 All Stats",
	[3880] = "+6 Armor Penetration Rating",
	[3881] = "+17 Mana every 5 seconds",
	[3882] = "+8 Armor Penetration Rating",
}

local DCS_ABBREV_ENCHANT_IDS = {
	[1] = "RB 3",
	[2] = "FB 1",
	[3] = "FT 3",
	[4] = "FT 2",
	[5] = "FT 1",
	[6] = "RB 2",
	[7] = "D Psn",
	[8] = "D Psn 2",
	[9] = "Psn 15 Dmg",
	[10] = "Psn 20 Dmg",
	[11] = "Psn 25 Dmg",
	[12] = "FB 2",
	[13] = "Sharp +3",
	[14] = "Sharp +4",
	[15] = "AC +8",
	[16] = "AC +16",
	[17] = "AC +24",
	[18] = "AC +32",
	[19] = "Weight +2",
	[20] = "Weight +3",
	[21] = "Weight +4",
	[22] = "Crp Psn",
	[23] = "MN Psn 2",
	[24] = "Mana +5",
	[25] = "Shdw Oil",
	[26] = "Frost Oil",
	[27] = "Sundered",
	[28] = "+4 All Res",
	[29] = "RB 1",
	[30] = "Scp +1",
	[31] = "BS +4",
	[32] = "Scp +2",
	[33] = "Scp +3",
	[34] = "CW +3% A Spd",
	[35] = "MN Psn",
	[36] = "Fiery Blaze",
	[37] = "Chain",
	[38] = "Def Skill +3",
	[39] = "Sharp +1",
	[40] = "Sharp +2",
	[41] = "HP +5",
	[42] = "Psn Insta 20",
	[43] = "Spk 8-12",
	[44] = "Absorb 10",
	[63] = "Absorb 25",
	[64] = "Spi +3",
	[65] = "+1 All Res",
	[66] = "Stam +1",
	[67] = "+1 Dmg",
	[68] = "+1 Str",
	[69] = "+2 Str",
	[70] = "+3 Str",
	[71] = "+1 Stam",
	[72] = "+2 Stam",
	[73] = "+3 Stam",
	[74] = "+1 Agi",
	[75] = "+2 Agi",
	[76] = "+3 Agi",
	[77] = "+2 Dmg",
	[78] = "+3 Dmg",
	[79] = "+1 Int",
	[80] = "+2 Int",
	[81] = "+3 Int",
	[82] = "+1 Spi",
	[83] = "+2 Spi",
	[84] = "+3 Spi",
	[85] = "+3 AC",
	[86] = "+8 AC",
	[87] = "+12 AC",
	[89] = "+16 AC",
	[90] = "+4 Agi",
	[91] = "+5 Agi",
	[92] = "+6 Agi",
	[93] = "+7 Agi",
	[94] = "+4 Int",
	[95] = "+5 Int",
	[96] = "+6 Int",
	[97] = "+7 Int",
	[98] = "+4 Spi",
	[99] = "+5 Spi",
	[100] = "+6 Spi",
	[101] = "+7 Spi",
	[102] = "+4 Stam",
	[103] = "+5 Stam",
	[104] = "+6 Stam",
	[105] = "+7 Stam",
	[106] = "+4 Str",
	[107] = "+5 Str",
	[108] = "+6 Str",
	[109] = "+7 Str",
	[110] = "+1 Def",
	[111] = "+1 Def",
	[112] = "+2 Def",
	[113] = "+3 Def",
	[114] = "+3 Def",
	[115] = "+4 Def",
	[116] = "+5 Def",
	[117] = "+4 Dmg",
	[118] = "+5 Dmg",
	[119] = "+6 Dmg",
	[120] = "+7 Dmg",
	[121] = "+20 AC",
	[122] = "+24 AC",
	[123] = "+28 AC",
	[124] = "FT Tot 1",
	[125] = "Swords +1",
	[126] = "Swords +2",
	[127] = "Swords +3",
	[128] = "Swords +4",
	[129] = "Swords +5",
	[130] = "Swords +6",
	[131] = "Swords +7",
	[132] = "2H Swords +1",
	[133] = "2H Swords +2",
	[134] = "2H Swords +3",
	[135] = "2H Swords +4",
	[136] = "2H Swords +5",
	[137] = "2H Swords +6",
	[138] = "2H Swords +7",
	[139] = "Maces +1",
	[140] = "Maces +2",
	[141] = "Maces +3",
	[142] = "Maces +4",
	[143] = "Maces +5",
	[144] = "Maces +6",
	[145] = "Maces +7",
	[146] = "2H Maces +1",
	[147] = "2H Maces +2",
	[148] = "2H Maces +3",
	[149] = "2H Maces +4",
	[150] = "2H Maces +5",
	[151] = "2H Maces +6",
	[152] = "2H Maces +7",
	[153] = "Axes +1",
	[154] = "Axes +2",
	[155] = "Axes +3",
	[156] = "Axes +4",
	[157] = "Axes +5",
	[158] = "Axes +6",
	[159] = "Axes +7",
	[160] = "2H Axes +1",
	[161] = "2H Axes +2",
	[162] = "2H Axes +3",
	[163] = "2H Axes +4",
	[164] = "2H Axes +5",
	[165] = "2H Axes +6",
	[166] = "2H Axes +7",
	[167] = "Daggers +1",
	[168] = "Daggers +2",
	[169] = "Daggers +3",
	[170] = "Daggers +4",
	[171] = "Daggers +5",
	[172] = "Daggers +6",
	[173] = "Daggers +7",
	[174] = "Guns +1",
	[175] = "Guns +2",
	[176] = "Guns +3",
	[177] = "Guns +4",
	[178] = "Guns +5",
	[179] = "Guns +6",
	[180] = "Guns +7",
	[181] = "Bows +1",
	[182] = "Bows +2",
	[183] = "Bows +3",
	[184] = "Bows +4",
	[185] = "Bows +5",
	[186] = "Bows +6",
	[187] = "Bows +7",
	[188] = "+2 Bst Slay",
	[189] = "+4 Bst Slay",
	[190] = "+6 Bst Slay",
	[191] = "+8 Bst Slay",
	[192] = "+10 Bst Slay",
	[193] = "+12 Bst Slay",
	[194] = "+14 Bst Slay",
	[195] = "Crit +1%",
	[196] = "Crit +2%",
	[197] = "Crit +3%",
	[198] = "Crit +4%",
	[199] = "10% On Hit 10 SB Dmg",
	[200] = "10% On Hit 20 SB Dmg",
	[201] = "10% On Hit 30 SB Dmg",
	[202] = "10% On Hit 40 SB Dmg",
	[203] = "10% On Hit 50 SB Dmg",
	[204] = "10% On Hit 60 SB Dmg",
	[205] = "10% On Hit 70 SB Dmg",
	[206] = "Heals +2",
	[207] = "Heals +4",
	[208] = "Heals +7",
	[209] = "Heals +9",
	[210] = "Heals +11",
	[211] = "Heals +13",
	[212] = "Heals +15",
	[213] = "Fir +1",
	[214] = "Fir +3",
	[215] = "Fir +4",
	[216] = "Fir +6",
	[217] = "Fir +7",
	[218] = "Fir Dmg +9",
	[219] = "Fir Dmg +10",
	[220] = "Nat +1",
	[221] = "Nat +3",
	[222] = "Nat +4",
	[223] = "Nat +6",
	[224] = "Nat +7",
	[225] = "Nat +9",
	[226] = "Nat +10",
	[227] = "Frost +1",
	[228] = "Frost +3",
	[229] = "Frost +4",
	[230] = "Frost +6",
	[231] = "Frost +7",
	[232] = "Frost +9",
	[233] = "Frost +10",
	[234] = "Shdw +1",
	[235] = "Shdw +3",
	[236] = "Shdw +4",
	[237] = "Shdw +6",
	[238] = "Shdw +7",
	[239] = "Shdw +9",
	[240] = "Shdw +10",
	[241] = "Wpn Dmg +2",
	[242] = "HP +15",
	[243] = "Spi +1",
	[244] = "Int +4",
	[245] = "AC +5",
	[246] = "Mana +20",
	[247] = "Agi +1",
	[248] = "Str +1",
	[249] = "BS +2",
	[250] = "Wpn Dmg +1 ",
	[251] = "Int +1",
	[252] = "Spi +6",
	[253] = "Absorb 50",
	[254] = "HP +25",
	[255] = "Spi +3",
	[256] = "+5 Fir Res",
	[257] = "AC +10",
	[263] = "Fish +25",
	[264] = "Fish +50",
	[265] = "Fish +75",
	[266] = "Fish +100",
	[283] = "WF 1",
	[284] = "WF 2",
	[285] = "FT Tot 2",
	[286] = "+2 Fir Dmg",
	[287] = "+4 Fir Dmg",
	[288] = "+6 Fir Dmg",
	[289] = "+8 Fir Dmg",
	[290] = "+10 Fir Dmg",
	[291] = "+12 Fir Dmg",
	[292] = "+14 Fir Dmg",
	[303] = "Orb of Fir",
	[323] = "Insta Psn",
	[324] = "Insta Psn 2",
	[325] = "Insta Psn 2I",
	[343] = "+8 Agi",
	[344] = "+32 AC",
	[345] = "+40 AC",
	[346] = "+36 AC",
	[347] = "+44 AC",
	[348] = "+48 AC",
	[349] = "+9 Agi",
	[350] = "+8 Int",
	[351] = "+8 Spi",
	[352] = "+8 Str",
	[353] = "+8 Stam",
	[354] = "+9 Int",
	[355] = "+9 Spi",
	[356] = "+9 Stam",
	[357] = "+9 Str",
	[358] = "+10 Agi",
	[359] = "+10 Int",
	[360] = "+10 Spi",
	[361] = "+10 Stam",
	[362] = "+10 Str",
	[363] = "+11 Agi",
	[364] = "+11 Int",
	[365] = "+11 Spi",
	[366] = "+11 Stam",
	[367] = "+11 Str",
	[368] = "+12 Agi",
	[369] = "+12 Int",
	[370] = "+12 Spi",
	[371] = "+12 Stam",
	[372] = "+12 Str",
	[383] = "+52 AC",
	[384] = "+56 AC",
	[385] = "+60 AC",
	[386] = "+16 AC",
	[387] = "+17 AC",
	[388] = "+18 AC",
	[389] = "+19 AC",
	[403] = "+13 Agi",
	[404] = "+14 Agi",
	[405] = "+13 Int",
	[406] = "+14 Int",
	[407] = "+13 Spi",
	[408] = "+14 Spi",
	[409] = "+13 Stam",
	[410] = "+13 Str",
	[411] = "+14 Stam",
	[412] = "+14 Str",
	[423] = "Dmg +1",
	[424] = "Dmg +2",
	[425] = "Dmg +4",
	[426] = "Dmg +5",
	[427] = "Dmg +6",
	[428] = "Dmg +7",
	[429] = "Dmg +8",
	[430] = "Dmg +9",
	[431] = "Dmg +11",
	[432] = "Dmg +12",
	[433] = "Fir Dmg +11",
	[434] = "Fir Dmg +13",
	[435] = "Fir Dmg +14",
	[436] = "Crit +5%",
	[437] = "Frost +11",
	[438] = "Frost +13",
	[439] = "Frost +14",
	[440] = "Heals +12",
	[441] = "Heals +20",
	[442] = "Heals +22",
	[443] = "Nat +11",
	[444] = "Nat +13",
	[445] = "Nat +14",
	[446] = "Shdw +11",
	[447] = "Shdw +13",
	[448] = "Shdw +14",
	[463] = "Spk 16-20",
	[464] = "4% Mnt Spd",
	[483] = "Sharp +6",
	[484] = "Weight +6",
	[503] = "RB 4",
	[504] = "RB +80",
	[523] = "FT 4",
	[524] = "FB 3",
	[525] = "WF 3",
	[543] = "FT Tot 3",
	[563] = "WF Tot 2",
	[564] = "WF Tot 3",
	[583] = "+1 Agi /\n +1 Spi",
	[584] = "+1 Agi /\n +1 Int",
	[585] = "+1 Agi /\n +1 Stam",
	[586] = "+1 Agi /\n +1 Str",
	[587] = "+1 Int /\n +1 Spi",
	[588] = "+1 Int /\n +1 Stam",
	[589] = "+1 Int /\n +1 Str",
	[590] = "+1 Spi /\n +1 Stam",
	[591] = "+1 Spi /\n +1 Str",
	[592] = "+1 Stam /\n +1 Str",
	[603] = "Crp Psn 2",
	[623] = "Insta Psn 4",
	[624] = "Insta Psn5",
	[625] = "Insta Psn 6",
	[626] = "D Psn 2I",
	[627] = "D Psn 4",
	[643] = "MN Psn 2I",
	[663] = "Scp +5",
	[664] = "Scp +7",
	[683] = "RB 6",
	[684] = "+15 Str",
	[703] = "Wound Psn",
	[704] = "Wound Psn 2",
	[705] = "Wound Psn 2I",
	[706] = "Wound Psn 4",
	[723] = "Int +3",
	[724] = "Stam +3",
	[743] = "Stealth +2",
	[744] = "AC +20",
	[763] = "Blk +1%",
	[783] = "AC +10",
	[803] = "Fiery",
	[804] = "+10 Shdw Res",
	[805] = "Wpn Dmg +4",
	[823] = "Str +3",
	[843] = "Mana +30",
	[844] = "Mining +2",
	[845] = "Herbalism +2",
	[846] = "Fish +2",
	[847] = "Stats +1",
	[848] = "AC +30",
	[849] = "Agi +3",
	[850] = "HP +35",
	[851] = "Spi +5",
	[852] = "Stam +5",
	[853] = "BS +6",
	[854] = "Ele Slay +6",
	[855] = "+5 Fir Res",
	[856] = "Str +5",
	[857] = "Mana +50",
	[863] = "Blk +2%",
	[864] = "Wpn Dmg +4",
	[865] = "Skinning +5",
	[866] = "Stats +2",
	[883] = "+15 Agi",
	[884] = "AC +50",
	[903] = "+3 All Res",
	[904] = "Agi +5",
	[905] = "Int +5",
	[906] = "Mining +5",
	[907] = "Spi +7",
	[908] = "HP +50",
	[909] = "Herbalism +5",
	[910] = "Inc Stealth",
	[911] = "8% Run Spd",
	[912] = "Demonslay",
	[913] = "Mana +65",
	[923] = "Def +3",
	[924] = "Def +1",
	[925] = "Def +2",
	[926] = "+8 Frost Res",
	[927] = "Str +7",
	[928] = "Stats +3",
	[929] = "Stam +7",
	[930] = "2% Mnt Spd",
	[931] = "A Spd +1%",
	[943] = "Wpn Dmg +3",
	[963] = "Wpn Dmg +7",
	[983] = "+16 Agi",
	[1003] = "VH Psn",
	[1023] = "Feedback 1",
	[1043] = "+16 Str",
	[1044] = "+17 Str",
	[1045] = "+18 Str",
	[1046] = "+19 Str",
	[1047] = "+20 Str",
	[1048] = "+21 Str",
	[1049] = "+22 Str",
	[1050] = "+23 Str",
	[1051] = "+24 Str",
	[1052] = "+25 Str",
	[1053] = "+26 Str",
	[1054] = "+27 Str",
	[1055] = "+28 Str",
	[1056] = "+29 Str",
	[1057] = "+30 Str",
	[1058] = "+31 Str",
	[1059] = "+32 Str",
	[1060] = "+33 Str",
	[1061] = "+34 Str",
	[1062] = "+35 Str",
	[1063] = "+36 Str",
	[1064] = "+37 Str",
	[1065] = "+38 Str",
	[1066] = "+39 Str",
	[1067] = "+40 Str",
	[1068] = "+15 Stam",
	[1069] = "+16 Stam",
	[1070] = "+17 Stam",
	[1071] = "+18 Stam",
	[1072] = "+19 Stam",
	[1073] = "+20 Stam",
	[1074] = "+21 Stam",
	[1075] = "+22 Stam",
	[1076] = "+23 Stam",
	[1077] = "+24 Stam",
	[1078] = "+25 Stam",
	[1079] = "+26 Stam",
	[1080] = "+27 Stam",
	[1081] = "+28 Stam",
	[1082] = "+29 Stam",
	[1083] = "+30 Stam",
	[1084] = "+31 Stam",
	[1085] = "+32 Stam",
	[1086] = "+33 Stam",
	[1087] = "+34 Stam",
	[1088] = "+35 Stam",
	[1089] = "+36 Stam",
	[1090] = "+37 Stam",
	[1091] = "+38 Stam",
	[1092] = "+39 Stam",
	[1093] = "+40 Stam",
	[1094] = "+17 Agi",
	[1095] = "+18 Agi",
	[1096] = "+19 Agi",
	[1097] = "+20 Agi",
	[1098] = "+21 Agi",
	[1099] = "+22 Agi",
	[1100] = "+23 Agi",
	[1101] = "+24 Agi",
	[1102] = "+25 Agi",
	[1103] = "+26 Agi",
	[1104] = "+27 Agi",
	[1105] = "+28 Agi",
	[1106] = "+29 Agi",
	[1107] = "+30 Agi",
	[1108] = "+31 Agi",
	[1109] = "+32 Agi",
	[1110] = "+33 Agi",
	[1111] = "+34 Agi",
	[1112] = "+35 Agi",
	[1113] = "+36 Agi",
	[1114] = "+37 Agi",
	[1115] = "+38 Agi",
	[1116] = "+39 Agi",
	[1117] = "+40 Agi",
	[1118] = "+15 Int",
	[1119] = "+16 Int",
	[1120] = "+17 Int",
	[1121] = "+18 Int",
	[1122] = "+19 Int",
	[1123] = "+20 Int",
	[1124] = "+21 Int",
	[1125] = "+22 Int",
	[1126] = "+23 Int",
	[1127] = "+24 Int",
	[1128] = "+25 Int",
	[1129] = "+26 Int",
	[1130] = "+27 Int",
	[1131] = "+28 Int",
	[1132] = "+29 Int",
	[1133] = "+30 Int",
	[1134] = "+31 Int",
	[1135] = "+32 Int",
	[1136] = "+33 Int",
	[1137] = "+34 Int",
	[1138] = "+35 Int",
	[1139] = "+36 Int",
	[1140] = "+37 Int",
	[1141] = "+38 Int",
	[1142] = "+39 Int",
	[1143] = "+40 Int",
	[1144] = "+15 Spi",
	[1145] = "+16 Spi",
	[1146] = "+17 Spi",
	[1147] = "+18 Spi",
	[1148] = "+19 Spi",
	[1149] = "+20 Spi",
	[1150] = "+21 Spi",
	[1151] = "+22 Spi",
	[1152] = "+23 Spi",
	[1153] = "+24 Spi",
	[1154] = "+25 Spi",
	[1155] = "+26 Spi",
	[1156] = "+27 Spi",
	[1157] = "+28 Spi",
	[1158] = "+29 Spi",
	[1159] = "+30 Spi",
	[1160] = "+31 Spi",
	[1161] = "+32 Spi",
	[1162] = "+33 Spi",
	[1163] = "+34 Spi",
	[1164] = "+36 Spi",
	[1165] = "+37 Spi",
	[1166] = "+38 Spi",
	[1167] = "+39 Spi",
	[1168] = "+40 Spi",
	[1183] = "+35 Spi",
	[1203] = "+41 Str",
	[1204] = "+42 Str",
	[1205] = "+43 Str",
	[1206] = "+44 Str",
	[1207] = "+45 Str",
	[1208] = "+46 Str",
	[1209] = "+41 Stam",
	[1210] = "+42 Stam",
	[1211] = "+43 Stam",
	[1212] = "+44 Stam",
	[1213] = "+45 Stam",
	[1214] = "+46 Stam",
	[1215] = "+41 Agi",
	[1216] = "+42 Agi",
	[1217] = "+43 Agi",
	[1218] = "+44 Agi",
	[1219] = "+45 Agi",
	[1220] = "+46 Agi",
	[1221] = "+41 Int",
	[1222] = "+42 Int",
	[1223] = "+43 Int",
	[1224] = "+44 Int",
	[1225] = "+45 Int",
	[1226] = "+46 Int",
	[1227] = "+41 Spi",
	[1228] = "+42 Spi",
	[1229] = "+43 Spi",
	[1230] = "+44 Spi",
	[1231] = "+45 Spi",
	[1232] = "+46 Spi",
	[1243] = "+1 Arc Res",
	[1244] = "+2 Arc Res",
	[1245] = "+3 Arc Res",
	[1246] = "+4 Arc Res",
	[1247] = "+5 Arc Res",
	[1248] = "+6 Arc Res",
	[1249] = "+7 Arc Res",
	[1250] = "+8 Arc Res",
	[1251] = "+9 Arc Res",
	[1252] = "+10 Arc Res",
	[1253] = "+11 Arc Res",
	[1254] = "+12 Arc Res",
	[1255] = "+13 Arc Res",
	[1256] = "+14 Arc Res",
	[1257] = "+15 Arc Res",
	[1258] = "+16 Arc Res",
	[1259] = "+17 Arc Res",
	[1260] = "+18 Arc Res",
	[1261] = "+19 Arc Res",
	[1262] = "+20 Arc Res",
	[1263] = "+21 Arc Res",
	[1264] = "+22 Arc Res",
	[1265] = "+23 Arc Res",
	[1266] = "+24 Arc Res",
	[1267] = "+25 Arc Res",
	[1268] = "+26 Arc Res",
	[1269] = "+27 Arc Res",
	[1270] = "+28 Arc Res",
	[1271] = "+29 Arc Res",
	[1272] = "+30 Arc Res",
	[1273] = "+31 Arc Res",
	[1274] = "+32 Arc Res",
	[1275] = "+33 Arc Res",
	[1276] = "+34 Arc Res",
	[1277] = "+35 Arc Res",
	[1278] = "+36 Arc Res",
	[1279] = "+37 Arc Res",
	[1280] = "+38 Arc Res",
	[1281] = "+39 Arc Res",
	[1282] = "+40 Arc Res",
	[1283] = "+41 Arc Res",
	[1284] = "+42 Arc Res",
	[1285] = "+43 Arc Res",
	[1286] = "+44 Arc Res",
	[1287] = "+45 Arc Res",
	[1288] = "+46 Arc Res",
	[1289] = "+1 Frost Res",
	[1290] = "+2 Frost Res",
	[1291] = "+3 Frost Res",
	[1292] = "+4 Frost Res",
	[1293] = "+5 Frost Res",
	[1294] = "+6 Frost Res",
	[1295] = "+7 Frost Res",
	[1296] = "+8 Frost Res",
	[1297] = "+9 Frost Res",
	[1298] = "+10 Frost Res",
	[1299] = "+11 Frost Res",
	[1300] = "+12 Frost Res",
	[1301] = "+13 Frost Res",
	[1302] = "+14 Frost Res",
	[1303] = "+15 Frost Res",
	[1304] = "+16 Frost Res",
	[1305] = "+17 Frost Res",
	[1306] = "+18 Frost Res",
	[1307] = "+19 Frost Res",
	[1308] = "+20 Frost Res",
	[1309] = "+21 Frost Res",
	[1310] = "+22 Frost Res",
	[1311] = "+23 Frost Res",
	[1312] = "+24 Frost Res",
	[1313] = "+25 Frost Res",
	[1314] = "+26 Frost Res",
	[1315] = "+27 Frost Res",
	[1316] = "+28 Frost Res",
	[1317] = "+29 Frost Res",
	[1318] = "+30 Frost Res",
	[1319] = "+31 Frost Res",
	[1320] = "+32 Frost Res",
	[1321] = "+33 Frost Res",
	[1322] = "+34 Frost Res",
	[1323] = "+35 Frost Res",
	[1324] = "+36 Frost Res",
	[1325] = "+37 Frost Res",
	[1326] = "+38 Frost Res",
	[1327] = "+39 Frost Res",
	[1328] = "+40 Frost Res",
	[1329] = "+41 Frost Res",
	[1330] = "+42 Frost Res",
	[1331] = "+43 Frost Res",
	[1332] = "+44 Frost Res",
	[1333] = "+45 Frost Res",
	[1334] = "+46 Frost Res",
	[1335] = "+1 Fir Res",
	[1336] = "+2 Fir Res",
	[1337] = "+3 Fir Res",
	[1338] = "+4 Fir Res",
	[1339] = "+5 Fir Res",
	[1340] = "+6 Fir Res",
	[1341] = "+7 Fir Res",
	[1342] = "+8 Fir Res",
	[1343] = "+9 Fir Res",
	[1344] = "+10 Fir Res",
	[1345] = "+11 Fir Res",
	[1346] = "+12 Fir Res",
	[1347] = "+13 Fir Res",
	[1348] = "+14 Fir Res",
	[1349] = "+15 Fir Res",
	[1350] = "+16 Fir Res",
	[1351] = "+17 Fir Res",
	[1352] = "+18 Fir Res",
	[1353] = "+19 Fir Res",
	[1354] = "+20 Fir Res",
	[1355] = "+21 Fir Res",
	[1356] = "+22 Fir Res",
	[1357] = "+23 Fir Res",
	[1358] = "+24 Fir Res",
	[1359] = "+25 Fir Res",
	[1360] = "+26 Fir Res",
	[1361] = "+27 Fir Res",
	[1362] = "+28 Fir Res",
	[1363] = "+29 Fir Res",
	[1364] = "+30 Fir Res",
	[1365] = "+31 Fir Res",
	[1366] = "+32 Fir Res",
	[1367] = "+33 Fir Res",
	[1368] = "+34 Fir Res",
	[1369] = "+35 Fir Res",
	[1370] = "+36 Fir Res",
	[1371] = "+37 Fir Res",
	[1372] = "+38 Fir Res",
	[1373] = "+39 Fir Res",
	[1374] = "+40 Fir Res",
	[1375] = "+41 Fir Res",
	[1376] = "+42 Fir Res",
	[1377] = "+43 Fir Res",
	[1378] = "+44 Fir Res",
	[1379] = "+45 Fir Res",
	[1380] = "+46 Fir Res",
	[1381] = "+1 Nat Res",
	[1382] = "+2 Nat Res",
	[1383] = "+3 Nat Res",
	[1384] = "+4 Nat Res",
	[1385] = "+5 Nat Res",
	[1386] = "+6 Nat Res",
	[1387] = "+7 Nat Res",
	[1388] = "+8 Nat Res",
	[1389] = "+9 Nat Res",
	[1390] = "+10 Nat Res",
	[1391] = "+11 Nat Res",
	[1392] = "+12 Nat Res",
	[1393] = "+13 Nat Res",
	[1394] = "+14 Nat Res",
	[1395] = "+15 Nat Res",
	[1396] = "+16 Nat Res",
	[1397] = "+17 Nat Res",
	[1398] = "+18 Nat Res",
	[1399] = "+19 Nat Res",
	[1400] = "+20 Nat Res",
	[1401] = "+21 Nat Res",
	[1402] = "+22 Nat Res",
	[1403] = "+23 Nat Res",
	[1404] = "+24 Nat Res",
	[1405] = "+25 Nat Res",
	[1406] = "+26 Nat Res",
	[1407] = "+27 Nat Res",
	[1408] = "+28 Nat Res",
	[1409] = "+29 Nat Res",
	[1410] = "+30 Nat Res",
	[1411] = "+31 Nat Res",
	[1412] = "+32 Nat Res",
	[1413] = "+33 Nat Res",
	[1414] = "+34 Nat Res",
	[1415] = "+35 Nat Res",
	[1416] = "+36 Nat Res",
	[1417] = "+37 Nat Res",
	[1418] = "+38 Nat Res",
	[1419] = "+39 Nat Res",
	[1420] = "+40 Nat Res",
	[1421] = "+41 Nat Res",
	[1422] = "+42 Nat Res",
	[1423] = "+43 Nat Res",
	[1424] = "+44 Nat Res",
	[1425] = "+45 Nat Res",
	[1426] = "+46 Nat Res",
	[1427] = "+1 Shdw Res",
	[1428] = "+2 Shdw Res",
	[1429] = "+3 Shdw Res",
	[1430] = "+4 Shdw Res",
	[1431] = "+5 Shdw Res",
	[1432] = "+6 Shdw Res",
	[1433] = "+7 Shdw Res",
	[1434] = "+8 Shdw Res",
	[1435] = "+9 Shdw Res",
	[1436] = "+10 Shdw Res",
	[1437] = "+11 Shdw Res",
	[1438] = "+12 Shdw Res",
	[1439] = "+13 Shdw Res",
	[1440] = "+14 Shdw Res",
	[1441] = "+15 Shdw Res",
	[1442] = "+16 Shdw Res",
	[1443] = "+17 Shdw Res",
	[1444] = "+18 Shdw Res",
	[1445] = "+19 Shdw Res",
	[1446] = "+20 Shdw Res",
	[1447] = "+21 Shdw Res",
	[1448] = "+22 Shdw Res",
	[1449] = "+23 Shdw Res",
	[1450] = "+24 Shdw Res",
	[1451] = "+25 Shdw Res",
	[1452] = "+26 Shdw Res",
	[1453] = "+27 Shdw Res",
	[1454] = "+28 Shdw Res",
	[1455] = "+29 Shdw Res",
	[1456] = "+30 Shdw Res",
	[1457] = "+31 Shdw Res",
	[1458] = "+32 Shdw Res",
	[1459] = "+33 Shdw Res",
	[1460] = "+34 Shdw Res",
	[1461] = "+35 Shdw Res",
	[1462] = "+36 Shdw Res",
	[1463] = "+37 Shdw Res",
	[1464] = "+38 Shdw Res",
	[1465] = "+39 Shdw Res",
	[1466] = "+40 Shdw Res",
	[1467] = "+41 Shdw Res",
	[1468] = "+42 Shdw Res",
	[1469] = "+43 Shdw Res",
	[1470] = "+44 Shdw Res",
	[1471] = "+45 Shdw Res",
	[1472] = "+46 Shdw Res",
	[1483] = "Mana +150",
	[1503] = "HP +100",
	[1504] = "AC +125",
	[1505] = "+20 Fir Res",
	[1506] = "Str +8",
	[1507] = "Stam +8",
	[1508] = "Agi +8",
	[1509] = "Int +8",
	[1510] = "Spi +8",
	[1523] = "MANA/\nFR +85/\n14",
	[1524] = "HP/\nFR +75/\n14",
	[1525] = "AC/\nFR +110/\n14",
	[1526] = "Str/\nFR +10/\n14",
	[1527] = "STA/\nFR +10/\n14",
	[1528] = "Agi/\nFR +10/\n14",
	[1529] = "Int/\nFR +10/\n14",
	[1530] = "Spi/\nFR +10/\n14",
	[1531] = "Str/\nSTA +10/\n10",
	[1532] = "Str/\nSTA/\nAC/\nFR +10/\n10/\n110/\n15",
	[1543] = "Int/\nSpi/\nMANA/\nFR +10/\n10/\n100/\n15",
	[1563] = "+2 AP",
	[1583] = "+4 AP",
	[1584] = "+6 AP",
	[1585] = "+8 AP",
	[1586] = "+10 AP",
	[1587] = "+12 AP",
	[1588] = "+14 AP",
	[1589] = "+16 AP",
	[1590] = "+18 AP",
	[1591] = "+20 AP",
	[1592] = "+22 AP",
	[1593] = "+24 AP",
	[1594] = "+26 AP",
	[1595] = "+28 AP",
	[1596] = "+30 AP",
	[1597] = "+32 AP",
	[1598] = "+34 AP",
	[1599] = "+36 AP",
	[1600] = "+38 AP",
	[1601] = "+40 AP",
	[1602] = "+42 AP",
	[1603] = "+44 AP",
	[1604] = "+46 AP",
	[1605] = "+48 AP",
	[1606] = "+50 AP",
	[1607] = "+52 AP",
	[1608] = "+54 AP",
	[1609] = "+56 AP",
	[1610] = "+58 AP",
	[1611] = "+60 AP",
	[1612] = "+62 AP",
	[1613] = "+64 AP",
	[1614] = "+66 AP",
	[1615] = "+68 AP",
	[1616] = "+70 AP",
	[1617] = "+72 AP",
	[1618] = "+74 AP",
	[1619] = "+76 AP",
	[1620] = "+78 AP",
	[1621] = "+80 AP",
	[1622] = "+82 AP",
	[1623] = "+84 AP",
	[1624] = "+86 AP",
	[1625] = "+88 AP",
	[1626] = "+90 AP",
	[1627] = "+92 AP",
	[1643] = "Sharp +8",
	[1663] = "RB 5",
	[1664] = "RB 7",
	[1665] = "FT 5",
	[1666] = "FT 6",
	[1667] = "FB 4",
	[1668] = "FB 5",
	[1669] = "WF 4",
	[1683] = "FT Tot 4",
	[1703] = "Weight +8",
	[1704] = "Spk 20-30",
	[1723] = "OOC",
	[1743] = "MHTest02",
	[1763] = "Cold Blood",
	[1783] = "WF Tot 1",
	[1803] = "Fstn 1",
	[1823] = "Fstn 2",
	[1824] = "Fstn 3",
	[1825] = "Fstn 4",
	[1843] = "AC +40",
	[1863] = "Feedback 2",
	[1864] = "Feedback 3",
	[1865] = "Feedback 4",
	[1866] = "Feedback 5",
	[1883] = "Int +7",
	[1884] = "Spi +9",
	[1885] = "Str +9",
	[1886] = "Stam +9",
	[1887] = "Agi +7",
	[1888] = "+5 All Res",
	[1889] = "AC +70",
	[1890] = "Spi +9",
	[1891] = "Stats +4",
	[1892] = "HP +100",
	[1893] = "Mana +100",
	[1894] = "Icy",
	[1895] = "Dmg +9",
	[1896] = "Wpn Dmg +9",
	[1897] = "Wpn Dmg +5",
	[1898] = "Lifesteal",
	[1899] = "Unholy",
	[1900] = "Crusader",
	[1901] = "Int +9",
	[1903] = "Spi +9",
	[1904] = "Int +9",
	[1923] = "+3 Fir Res",
	[1943] = "+8 Def",
	[1944] = "+5 Def",
	[1945] = "+6 Def",
	[1946] = "+7 Def",
	[1947] = "+7 Def",
	[1948] = "+9 Def",
	[1949] = "+9 Def",
	[1950] = "+10 Def",
	[1951] = "+11 Def",
	[1952] = "+13 Def",
	[1953] = "+15 Def",
	[1954] = "+17 Def",
	[1955] = "+21 Def",
	[1956] = "+11 Def",
	[1957] = "+12 Def",
	[1958] = "+13 Def",
	[1959] = "+14 Def",
	[1960] = "+15 Def",
	[1961] = "+16 Def",
	[1962] = "+17 Def",
	[1963] = "+18 Def",
	[1964] = "+19 Def",
	[1965] = "+19 Def",
	[1966] = "+20 Def",
	[1967] = "+21 Def",
	[1968] = "+22 Def",
	[1969] = "+23 Def",
	[1970] = "+23 Def",
	[1971] = "+24 Def",
	[1972] = "+25 Def",
	[1973] = "+25 Def",
	[1983] = "+1% Blk",
	[1984] = "+2% Blk",
	[1985] = "+3% Blk",
	[1986] = "+4% Blk",
	[1987] = "Blk Lvl 14",
	[1988] = "Blk Lvl 15",
	[1989] = "Blk Lvl 16",
	[1990] = "Blk Lvl 17",
	[1991] = "Blk Lvl 18",
	[1992] = "Blk Lvl 19",
	[1993] = "Blk Lvl 20",
	[1994] = "Blk Lvl 21",
	[1995] = "Blk Lvl 22",
	[1996] = "Blk Lvl 23",
	[1997] = "Blk Lvl 24",
	[1998] = "Blk Lvl 25",
	[1999] = "Blk Lvl 26",
	[2000] = "Blk Lvl 27",
	[2001] = "Blk Lvl 28",
	[2002] = "Blk Lvl 29",
	[2003] = "Blk Lvl 30",
	[2004] = "Blk Lvl 31",
	[2005] = "Blk Lvl 32",
	[2006] = "Blk Lvl 33",
	[2007] = "Blk Lvl 34",
	[2008] = "Blk Lvl 35",
	[2009] = "Blk Lvl 36",
	[2010] = "Blk Lvl 37",
	[2011] = "Blk Lvl 38",
	[2012] = "Blk Lvl 39",
	[2013] = "Blk Lvl 40",
	[2014] = "Blk Lvl 41",
	[2015] = "Blk Lvl 42",
	[2016] = "Blk Lvl 43",
	[2017] = "Blk Lvl 44",
	[2018] = "Blk Lvl 45",
	[2019] = "Blk Lvl 46",
	[2020] = "Blk Lvl 47",
	[2021] = "Blk Lvl 48",
	[2022] = "Blk Lvl 49",
	[2023] = "Blk Lvl 50",
	[2024] = "Blk Lvl 51",
	[2025] = "Blk Lvl 52",
	[2026] = "Blk Lvl 53",
	[2027] = "Blk Lvl 54",
	[2028] = "Blk Lvl 55",
	[2029] = "Blk Lvl 56",
	[2030] = "Blk Lvl 57",
	[2031] = "Blk Lvl 58",
	[2032] = "Blk Lvl 59",
	[2033] = "Blk Lvl 60",
	[2034] = "Blk Lvl 61",
	[2035] = "Blk Lvl 62",
	[2036] = "Blk Lvl 63",
	[2037] = "Blk Lvl 64",
	[2038] = "Blk Lvl 65",
	[2039] = "Blk Lvl 66",
	[2040] = "+2 Rng AP",
	[2041] = "+5 Rng AP",
	[2042] = "+7 Rng AP",
	[2043] = "+10 Rng AP",
	[2044] = "+12 Rng AP",
	[2045] = "+14 Rng AP",
	[2046] = "+17 Rng AP",
	[2047] = "+19 Rng AP",
	[2048] = "+22 Rng AP",
	[2049] = "+24 Rng AP",
	[2050] = "+26 Rng AP",
	[2051] = "+29 Rng AP",
	[2052] = "+31 Rng AP",
	[2053] = "+34 Rng AP",
	[2054] = "+36 Rng AP",
	[2055] = "+38 Rng AP",
	[2056] = "+41 Rng AP",
	[2057] = "+43 Rng AP",
	[2058] = "+46 Rng AP",
	[2059] = "+48 Rng AP",
	[2060] = "+50 Rng AP",
	[2061] = "+53 Rng AP",
	[2062] = "+55 Rng AP",
	[2063] = "+58 Rng AP",
	[2064] = "+60 Rng AP",
	[2065] = "+62 Rng AP",
	[2066] = "+65 Rng AP",
	[2067] = "+67 Rng AP",
	[2068] = "+70 Rng AP",
	[2069] = "+72 Rng AP",
	[2070] = "+74 Rng AP",
	[2071] = "+77 Rng AP",
	[2072] = "+79 Rng AP",
	[2073] = "+82 Rng AP",
	[2074] = "+84 Rng AP",
	[2075] = "+86 Rng AP",
	[2076] = "+89 Rng AP",
	[2077] = "+91 Rng AP",
	[2078] = "+1% Dg",
	[2079] = "+1 Arc Dmg",
	[2080] = "+3 Arc Dmg",
	[2081] = "+4 Arc Dmg",
	[2082] = "+6 Arc Dmg",
	[2083] = "+7 Arc Dmg",
	[2084] = "+9 Arc Dmg",
	[2085] = "+10 Arc Dmg",
	[2086] = "+11 Arc Dmg",
	[2087] = "+13 Arc Dmg",
	[2088] = "+14 Arc Dmg",
	[2089] = "+16 Arc Dmg",
	[2090] = "+17 Arc Dmg",
	[2091] = "+19 Arc Dmg",
	[2092] = "+20 Arc Dmg",
	[2093] = "+21 Arc Dmg",
	[2094] = "+23 Arc Dmg",
	[2095] = "+24 Arc Dmg",
	[2096] = "+26 Arc Dmg",
	[2097] = "+27 Arc Dmg",
	[2098] = "+29 Arc Dmg",
	[2099] = "+30 Arc Dmg",
	[2100] = "+31 Arc Dmg",
	[2101] = "+33 Arc Dmg",
	[2102] = "+34 Arc Dmg",
	[2103] = "+36 Arc Dmg",
	[2104] = "+37 Arc Dmg",
	[2105] = "+39 Arc Dmg",
	[2106] = "+40 Arc Dmg",
	[2107] = "+41 Arc Dmg",
	[2108] = "+43 Arc Dmg",
	[2109] = "+44 Arc Dmg",
	[2110] = "+46 Arc Dmg",
	[2111] = "+47 Arc Dmg",
	[2112] = "+49 Arc Dmg",
	[2113] = "+50 Arc Dmg",
	[2114] = "+51 Arc Dmg",
	[2115] = "+53 Arc Dmg",
	[2116] = "+54 Arc Dmg",
	[2117] = "+1 Shdw Dmg",
	[2118] = "+3 Shdw Dmg",
	[2119] = "+4 Shdw Dmg",
	[2120] = "+6 Shdw Dmg",
	[2121] = "+7 Shdw Dmg",
	[2122] = "+9 Shdw Dmg",
	[2123] = "+10 Shdw Dmg",
	[2124] = "+11 Shdw Dmg",
	[2125] = "+13 Shdw Dmg",
	[2126] = "+14 Shdw Dmg",
	[2127] = "+16 Shdw Dmg",
	[2128] = "+17 Shdw Dmg",
	[2129] = "+19 Shdw Dmg",
	[2130] = "+20 Shdw Dmg",
	[2131] = "+21 Shdw Dmg",
	[2132] = "+23 Shdw Dmg",
	[2133] = "+24 Shdw Dmg",
	[2134] = "+26 Shdw Dmg",
	[2135] = "+27 Shdw Dmg",
	[2136] = "+29 Shdw Dmg",
	[2137] = "+30 Shdw Dmg",
	[2138] = "+31 Shdw Dmg",
	[2139] = "+33 Shdw Dmg",
	[2140] = "+34 Shdw Dmg",
	[2141] = "+36 Shdw Dmg",
	[2142] = "+37 Shdw Dmg",
	[2143] = "+39 Shdw Dmg",
	[2144] = "+40 Shdw Dmg",
	[2145] = "+41 Shdw Dmg",
	[2146] = "+43 Shdw Dmg",
	[2147] = "+44 Shdw Dmg",
	[2148] = "+46 Shdw Dmg",
	[2149] = "+47 Shdw Dmg",
	[2150] = "+49 Shdw Dmg",
	[2151] = "+50 Shdw Dmg",
	[2152] = "+51 Shdw Dmg",
	[2153] = "+53 Shdw Dmg",
	[2154] = "+54 Shdw Dmg",
	[2155] = "+1 Fir Dmg",
	[2156] = "+3 Fir Dmg",
	[2157] = "+4 Fir Dmg",
	[2158] = "+6 Fir Dmg",
	[2159] = "+7 Fir Dmg",
	[2160] = "+9 Fir Dmg",
	[2161] = "+10 Fir Dmg",
	[2162] = "+11 Fir Dmg",
	[2163] = "+13 Fir Dmg",
	[2164] = "+14 Fir Dmg",
	[2165] = "+16 Fir Dmg",
	[2166] = "+17 Fir Dmg",
	[2167] = "+19 Fir Dmg",
	[2168] = "+20 Fir Dmg",
	[2169] = "+21 Fir Dmg",
	[2170] = "+23 Fir Dmg",
	[2171] = "+24 Fir Dmg",
	[2172] = "+26 Fir Dmg",
	[2173] = "+27 Fir Dmg",
	[2174] = "+29 Fir Dmg",
	[2175] = "+30 Fir Dmg",
	[2176] = "+31 Fir Dmg",
	[2177] = "+33 Fir Dmg",
	[2178] = "+34 Fir Dmg",
	[2179] = "+36 Fir Dmg",
	[2180] = "+37 Fir Dmg",
	[2181] = "+39 Fir Dmg",
	[2182] = "+40 Fir Dmg",
	[2183] = "+41 Fir Dmg",
	[2184] = "+43 Fir Dmg",
	[2185] = "+44 Fir Dmg",
	[2186] = "+46 Fir Dmg",
	[2187] = "+47 Fir Dmg",
	[2188] = "+49 Fir Dmg",
	[2189] = "+50 Fir Dmg",
	[2190] = "+51 Fir Dmg",
	[2191] = "+53 Fir Dmg",
	[2192] = "+54 Fir Dmg",
	[2193] = "+1 Holy Dmg",
	[2194] = "+3 Holy Dmg",
	[2195] = "+4 Holy Dmg",
	[2196] = "+6 Holy Dmg",
	[2197] = "+7 Holy Dmg",
	[2198] = "+9 Holy Dmg",
	[2199] = "+10 Holy Dmg",
	[2200] = "+11 Holy Dmg",
	[2201] = "+13 Holy Dmg",
	[2202] = "+14 Holy Dmg",
	[2203] = "+16 Holy Dmg",
	[2204] = "+17 Holy Dmg",
	[2205] = "+19 Holy Dmg",
	[2206] = "+20 Holy Dmg",
	[2207] = "+21 Holy Dmg",
	[2208] = "+23 Holy Dmg",
	[2209] = "+24 Holy Dmg",
	[2210] = "+26 Holy Dmg",
	[2211] = "+27 Holy Dmg",
	[2212] = "+29 Holy Dmg",
	[2213] = "+30 Holy Dmg",
	[2214] = "+31 Holy Dmg",
	[2215] = "+33 Holy Dmg",
	[2216] = "+34 Holy Dmg",
	[2217] = "+36 Holy Dmg",
	[2218] = "+37 Holy Dmg",
	[2219] = "+39 Holy Dmg",
	[2220] = "+40 Holy Dmg",
	[2221] = "+41 Holy Dmg",
	[2222] = "+43 Holy Dmg",
	[2223] = "+44 Holy Dmg",
	[2224] = "+46 Holy Dmg",
	[2225] = "+47 Holy Dmg",
	[2226] = "+49 Holy Dmg",
	[2227] = "+50 Holy Dmg",
	[2228] = "+51 Holy Dmg",
	[2229] = "+53 Holy Dmg",
	[2230] = "+54 Holy Dmg",
	[2231] = "+1 Frost Dmg",
	[2232] = "+3 Frost Dmg",
	[2233] = "+4 Frost Dmg",
	[2234] = "+6 Frost Dmg",
	[2235] = "+7 Frost Dmg",
	[2236] = "+9 Frost Dmg",
	[2237] = "+10 Frost Dmg",
	[2238] = "+11 Frost Dmg",
	[2239] = "+13 Frost Dmg",
	[2240] = "+14 Frost Dmg",
	[2241] = "+16 Frost Dmg",
	[2242] = "+17 Frost Dmg",
	[2243] = "+19 Frost Dmg",
	[2244] = "+20 Frost Dmg",
	[2245] = "+21 Frost Dmg",
	[2246] = "+23 Frost Dmg",
	[2247] = "+24 Frost Dmg",
	[2248] = "+26 Frost Dmg",
	[2249] = "+27 Frost Dmg",
	[2250] = "+29 Frost Dmg",
	[2251] = "+30 Frost Dmg",
	[2252] = "+31 Frost Dmg",
	[2253] = "+33 Frost Dmg",
	[2254] = "+34 Frost Dmg",
	[2255] = "+36 Frost Dmg",
	[2256] = "+37 Frost Dmg",
	[2257] = "+39 Frost Dmg",
	[2258] = "+40 Frost Dmg",
	[2259] = "+41 Frost Dmg",
	[2260] = "+43 Frost Dmg",
	[2261] = "+44 Frost Dmg",
	[2262] = "+46 Frost Dmg",
	[2263] = "+47 Frost Dmg",
	[2264] = "+49 Frost Dmg",
	[2265] = "+50 Frost Dmg",
	[2266] = "+51 Frost Dmg",
	[2267] = "+53 Frost Dmg",
	[2268] = "+54 Frost Dmg",
	[2269] = "+1 Nat Dmg",
	[2270] = "+3 Nat Dmg",
	[2271] = "+4 Nat Dmg",
	[2272] = "+6 Nat Dmg",
	[2273] = "+7 Nat Dmg",
	[2274] = "+9 Nat Dmg",
	[2275] = "+10 Nat Dmg",
	[2276] = "+11 Nat Dmg",
	[2277] = "+13 Nat Dmg",
	[2278] = "+14 Nat Dmg",
	[2279] = "+16 Nat Dmg",
	[2280] = "+17 Nat Dmg",
	[2281] = "+19 Nat Dmg",
	[2282] = "+20 Nat Dmg",
	[2283] = "+21 Nat Dmg",
	[2284] = "+23 Nat Dmg",
	[2285] = "+24 Nat Dmg",
	[2286] = "+26 Nat Dmg",
	[2287] = "+27 Nat Dmg",
	[2288] = "+29 Nat Dmg",
	[2289] = "+30 Nat Dmg",
	[2290] = "+31 Nat Dmg",
	[2291] = "+33 Nat Dmg",
	[2292] = "+34 Nat Dmg",
	[2293] = "+36 Nat Dmg",
	[2294] = "+37 Nat Dmg",
	[2295] = "+39 Nat Dmg",
	[2296] = "+40 Nat Dmg",
	[2297] = "+41 Nat Dmg",
	[2298] = "+43 Nat Dmg",
	[2299] = "+44 Nat Dmg",
	[2300] = "+46 Nat Dmg",
	[2301] = "+47 Nat Dmg",
	[2302] = "+49 Nat Dmg",
	[2303] = "+50 Nat Dmg",
	[2304] = "+51 Nat Dmg",
	[2305] = "+53 Nat Dmg",
	[2306] = "+54 Nat Dmg",
	[2307] = "+2 Heals",
	[2308] = "+4 Heals",
	[2309] = "+7 Heals",
	[2310] = "+9 Heals",
	[2311] = "+11 Heals",
	[2312] = "+13 Heals",
	[2313] = "+15 Heals",
	[2314] = "+18 Heals",
	[2315] = "+20 Heals",
	[2316] = "+22 Heals",
	[2317] = "+24 Heals",
	[2318] = "+26 Heals",
	[2319] = "+29 Heals",
	[2320] = "+31 Heals",
	[2321] = "+33 Heals",
	[2322] = "+35 Heals",
	[2323] = "+37 Heals",
	[2324] = "+40 Heals",
	[2325] = "+42 Heals",
	[2326] = "+44 Heals",
	[2327] = "+46 Heals",
	[2328] = "+48 Heals",
	[2329] = "+51 Heals",
	[2330] = "+53 Heals",
	[2331] = "+55 Heals",
	[2332] = "+57 Heals",
	[2333] = "+59 Heals",
	[2334] = "+62 Heals",
	[2335] = "+64 Heals",
	[2336] = "+66 Heals",
	[2337] = "+68 Heals",
	[2338] = "+70 Heals",
	[2339] = "+73 Heals",
	[2340] = "+75 Heals",
	[2341] = "+77 Heals",
	[2342] = "+79 Heals",
	[2343] = "+81 Heals",
	[2344] = "+84 Heals",
	[2363] = "+1 MP5",
	[2364] = "+1 MP5",
	[2365] = "+1 MP5",
	[2366] = "+2 MP5",
	[2367] = "+2 MP5",
	[2368] = "+2 MP5",
	[2369] = "+3 MP5",
	[2370] = "+3 MP5",
	[2371] = "+4 MP5",
	[2372] = "+4 MP5",
	[2373] = "+4 MP5",
	[2374] = "+5 MP5",
	[2375] = "+5 MP5",
	[2376] = "+6 MP5",
	[2377] = "+6 MP5",
	[2378] = "+6 MP5",
	[2379] = "+7 MP5",
	[2380] = "+7 MP5",
	[2381] = "+8 MP5",
	[2382] = "+8 MP5",
	[2383] = "+8 MP5",
	[2384] = "+9 MP5",
	[2385] = "+9 MP5",
	[2386] = "+10 MP5",
	[2387] = "+10 MP5",
	[2388] = "+10 MP5",
	[2389] = "+11 MP5",
	[2390] = "+11 MP5",
	[2391] = "+12 MP5",
	[2392] = "+12 MP5",
	[2393] = "+12 MP5",
	[2394] = "+13 MP5",
	[2395] = "+13 MP5",
	[2396] = "+14 MP5",
	[2397] = "+14 MP5",
	[2398] = "+14 MP5",
	[2399] = "+15 MP5",
	[2400] = "+15 MP5",
	[2401] = "+1 HP5",
	[2402] = "+1 HP5",
	[2403] = "+1 HP5",
	[2404] = "+1 HP5",
	[2405] = "+1 HP5",
	[2406] = "+2 HP5",
	[2407] = "+2 HP5",
	[2408] = "+2 HP5",
	[2409] = "+2 HP5",
	[2410] = "+3 HP5",
	[2411] = "+3 HP5",
	[2412] = "+3 HP5",
	[2413] = "+3 HP5",
	[2414] = "+4 HP5",
	[2415] = "+4 HP5",
	[2416] = "+4 HP5",
	[2417] = "+4 HP5",
	[2418] = "+5 HP5",
	[2419] = "+5 HP5",
	[2420] = "+5 HP5",
	[2421] = "+5 HP5",
	[2422] = "+6 HP5",
	[2423] = "+6 HP5",
	[2424] = "+6 HP5",
	[2425] = "+6 HP5",
	[2426] = "+7 HP5",
	[2427] = "+7 HP5",
	[2428] = "+7 HP5",
	[2429] = "+7 HP5",
	[2430] = "+8 HP5",
	[2431] = "+8 HP5",
	[2432] = "+8 HP5",
	[2433] = "+8 HP5",
	[2434] = "+9 HP5",
	[2435] = "+9 HP5",
	[2436] = "+9 HP5",
	[2437] = "+9 HP5",
	[2438] = "+10 HP5",
	[2443] = "Frost Dmg +7",
	[2463] = "+7 Fir Res",
	[2483] = "+5 Fir Res",
	[2484] = "+5 Frost Res",
	[2485] = "+5 Arc Res",
	[2486] = "+5 Nat Res",
	[2487] = "+5 Shdw Res",
	[2488] = "+5 All Res",
	[2503] = "Def +3",
	[2504] = "Dmg +30",
	[2505] = "Heals +55",
	[2506] = "Crit +2%",
	[2523] = "+3% Hit",
	[2543] = "A Spd +1%",
	[2544] = "Dmg & Heals +8",
	[2545] = "Dg +1%",
	[2563] = "Str +15",
	[2564] = "Agi +15",
	[2565] = "MP Reg 4 per 5 sec.",
	[2566] = "Heals +24",
	[2567] = "Spi +20",
	[2568] = "Int +22",
	[2583] = "Def +7/\nStam +10/\nBlk Val +15",
	[2584] = "Def +7/\nStam +10/\nHeals +24",
	[2585] = "AP +28/\nDg +1%",
	[2586] = "Rng AP +24/\nStam +10/\nHit +1%",
	[2587] = "Dmg & Heals +13/\nInt +15",
	[2588] = "Dmg & Heals +18/\nSp Hit +1%",
	[2589] = "Dmg & Heals +18/\nStam +10",
	[2590] = "MP Reg +4/\nStam +10/\nHeals +24",
	[2591] = "Int +10/\nStam +10/\nHeals +24",
	[2603] = "Eternium Line",
	[2604] = "+33 Heals",
	[2605] = "+18 Dmg & Heals",
	[2606] = "+30 AP",
	[2607] = "+12 Dmg & Heals",
	[2608] = "+13 Dmg & Heals",
	[2609] = "+15 Dmg & Heals",
	[2610] = "+14 Dmg & Heals",
	[2611] = "REUSE Random - 15 Sps All",
	[2612] = "+18 Dmg & Heals",
	[2613] = "Threat +2%",
	[2614] = "Shdw Dmg +20",
	[2615] = "Frost Dmg +20",
	[2616] = "Fir Dmg +20",
	[2617] = "Heals +30",
	[2618] = "Agi +15",
	[2619] = "+15 Fir Res",
	[2620] = "+15 Nat Res",
	[2621] = "Subtlety",
	[2622] = "Dg +1%",
	[2623] = "Min Wiz Oil",
	[2624] = "Min Mana Oil",
	[2625] = "Less Mana Oil",
	[2626] = "Less Wiz Oil",
	[2627] = "Wiz Oil",
	[2628] = "Brill Wiz Oil",
	[2629] = "Brill Mana Oil",
	[2630] = "D Psn5",
	[2646] = "Agi +25",
	[2681] = "+10 Nat Res",
	[2682] = "+10 Frost Res",
	[2683] = "+10 Shdw Res",
	[2684] = "+100 AP vs UD",
	[2685] = "+60 Dmg vs UD",
	[2715] = "Heals +31/\n5 MP5",
	[2716] = "Stam +16/\nAC +100",
	[2717] = "AP +26/\n+1% Crit",
	[2721] = "Dmg +15/\n+1% Sp Crit",
-- ############## TBC IDs ##########################################
-- ############## TBC IDs ##########################################
-- ############## TBC IDs ##########################################
	[2722] = "Scp +10",
	[2723] = "Scp +12",
	[2724] = "Scp +28 Crit Rt",
	[2725] = "+8 Str",
	[2726] = "+8 Agi",
	[2727] = "+9 SP",
	[2728] = "+9 SP",
	[2729] = "+16 AP",
	[2730] = "+8 Dg Rt",
	[2731] = "+12 Stam",
	[2732] = "+8 Spr",
	[2733] = "+4 MP5",
	[2734] = "+8 Int",
	[2735] = "+8 Crit Rt",
	[2736] = "+8 Crit Rt",
	[2737] = "+8 Def Rt",
	[2738] = "+4 Str/\n+6 Stam",
	[2739] = "+4 Agi/\n+6 Stam",
	[2740] = "+5 SP/\n+6 Stam",
	[2741] = "+5 SP/\n+2 MP5",
	[2742] = "+5 SP/\n+4 Int",
	[2743] = "+4 Def Rt/\n+6 Stam",
	[2744] = "+4 Int/\n+2 MP5",
	[2745] = "+25 SP/\n+15 Stam",
	[2746] = "+35 SP/\n+20 Stam",
	[2747] = "+25 SP/\n+15 Stam",
	[2748] = "+35 SP/\n+20 Stam",
	[2749] = "+12 Int",
	[2750] = "6 MP5.",
	[2751] = "+14 Crit Rt",
	[2752] = "+3 Crit Rt/\n+3 Str",
	[2753] = "+4 Crit Rt/\n+4 Str",
	[2754] = "+8 Par Rt",
	[2755] = "+3 Hit Rt/\n+3 Agi",
	[2756] = "+4 Hit Rt/\n+4 Agi",
	[2757] = "+3 Crit Rt/\n+4 Stam",
	[2758] = "+4 Crit Rt/\n+6 Stam",
	[2759] = "+8 Res Rt",
	[2760] = "+3 Crit Rt/\n+4 SP",
	[2761] = "+4 Crit Rt/\n+5 SP",
	[2762] = "+3 Crit Rt/\n+4 SPen",
	[2763] = "+4 Crit Rt/\n+5 SPen",
	[2764] = "+8 Hit Rt",
	[2765] = "+10 SPen",
	[2766] = "+8 Int",
	[2767] = "+8 Hit Rt",
	[2768] = "+16 SP",
	[2769] = "+11 Hit Rt",
	[2770] = "+7 SP",
	[2771] = "+8 Crit Rt",
	[2772] = "+14 Crit Rt",
	[2773] = "+16 Crit Rt",
	[2774] = "+11 Int",
	[2775] = "+11 Crit Rt",
	[2776] = "+3 MP5",
	[2777] = "+13 Spr",
	[2778] = "+13 SPen",
	[2779] = "+16 Spr",
	[2780] = "+20 SPen",
	[2781] = "+19 Stam",
	[2782] = "+10 Agi",
	[2783] = "+14 Hit Rt",
	[2784] = "+12 Hit Rt",
	[2785] = "+13 Hit Rt",
	[2786] = "+7 Hit Rt",
	[2787] = "+8 Crit Rt",
	[2788] = "+9 Res",
	[2789] = "+15 Res",
	[2790] = "ZZOLDLesser Rn of Ward",
	[2791] = "Grt Rn of Ward",
	[2792] = "+8 Stam",
	[2793] = "+8 Def Rt",
	[2794] = "+4 MP5",
	[2795] = "Comfortable Insoles",
	[2796] = "+15 Dg Rt",
	[2797] = "+9 Dg Rt",
	[2798] = "+$i Int (+$n/\n+$f)",
	[2799] = "+$i Stam (+$n/\n+$f)",
	[2800] = "+$i AC (+$n/\n+$f)",
	[2801] = "+8 Res",
	[2802] = "+$i Agi",
	[2803] = "+$i Stam",
	[2804] = "+$i Int",
	[2805] = "+$i Str",
	[2806] = "+$i Spr",
	[2807] = "+$i Arc Dmg",
	[2808] = "+$i Fir Dmg",
	[2809] = "+$i Nat Dmg",
	[2810] = "+$i Frost Dmg",
	[2811] = "+$i Shd Dmg",
	[2812] = "+$i Heal",
	[2813] = "+$i Def Rt",
	[2814] = "+$i HP5.",
	[2815] = "+$i Dg Rt",
	[2816] = "+$i MP5.",
	[2817] = "+$i Arc Rs",
	[2818] = "+$i Fir Rs",
	[2819] = "+$i Frost Rs",
	[2820] = "+$i Nat Rs",
	[2821] = "+$i Shd Rs",
	[2822] = "+$i Crit Rt",
	[2823] = "+$i Crit Rt",
	[2824] = "+$i SP",
	[2825] = "+$i AP",
	[2826] = "+$i Blk Rt",
	[2827] = "+14 Crit Rt/\n1% SRefl",
	[2828] = "Ch to Inc Sp Cast Spd",
	[2829] = "+24 AP/\nMn Run Spd Inc",
	[2830] = "+12 Crit Rt/\nRed Snare/\nRoot Dura by 10%",
	[2831] = "+18 Stam/\nStun Dura Red by 15%",
	[2832] = "+14 SP/\n2% Red Threat",
	[2833] = "+12 Def Rt/\nCh to resto resto on hit",
	[2834] = "+3 Melee Dmg/\nCh to Stun Target",
	[2835] = "+12 Int/\nCh to resto mana on Spcast",
	[2836] = "3 MP5.",
	[2837] = "+7 Spr",
	[2838] = "+7 Crit Rt",
	[2839] = "+14 Crit Rt",
	[2840] = "+21 Stam",
	[2841] = "+10 Stam",
	[2842] = "+8 Spr",
	[2843] = "+8 Crit Rt",
	[2844] = "+8 Hit Rt",
	[2845] = "+11 Hit Rt",
	[2846] = "4 MP5.",
	[2847] = "4 MP5.",
	[2848] = "5 MP5.",
	[2849] = "+7 Dg Rt",
	[2850] = "+13 Crit Rt",
	[2851] = "+19 Stam",
	[2852] = "7 MP5",
	[2853] = "8 MP5",
	[2854] = "3 MP5",
	[2855] = "5 MP5.",
	[2856] = "+4 Res Rt",
	[2857] = "+2 Crit Rt",
	[2858] = "+2 Crit Rt",
	[2859] = "+3 Res Rt",
	[2860] = "+3 Hit Rt",
	[2861] = "+3 Def Rt",
	[2862] = "+3 Res Rt",
	[2863] = "+3 Int",
	[2864] = "+4 Crit Rt",
	[2865] = "+2 MP5.",
	[2866] = "+3 Spr",
	[2867] = "+2 Res Rt",
	[2868] = "+6 Stam",
	[2869] = "+4 Int",
	[2870] = "+3 Par Rt",
	[2871] = "+4 Dg Rt",
	[2872] = "+5 SP",
	[2873] = "+4 Hit Rt",
	[2874] = "+4 Crit Rt",
	[2875] = "+3 Crit Rt",
	[2876] = "+3 Dg Rt",
	[2877] = "+4 Agi",
	[2878] = "+4 Res Rt",
	[2879] = "+3 Str",
	[2880] = "+3 Hit Rt",
	[2881] = "+1 MP5.",
	[2882] = "+6 Stam",
	[2883] = "+4 Stam",
	[2884] = "+2 Crit Rt",
	[2885] = "+2 Crit Rt",
	[2886] = "+2 Hit Rt",
	[2887] = "+3 Crit Rt",
	[2888] = "+6 Blk Val",
	[2889] = "+5 SP",
	[2890] = "+4 Spr",
	[2891] = "+10 Res Rt",
	[2892] = "+4 Str",
	[2893] = "+3 Agi",
	[2894] = "+7 Str",
	[2895] = "+4 Stam",
	[2896] = "+8 SP",
	[2897] = "+3 Stam, +4 Crit Rt",
	[2898] = "+3 Stam/\n+4 Crit Rt",
	[2899] = "+3 Stam/\n+4 Crit Rt",
	[2900] = "+4 SP",
	[2901] = "+2 SP",
	[2902] = "+2 Crit Rt",
	[2906] = "+$i Stam/\n+$i Int",
	[2907] = "+2 Par Rt",
	[2908] = "+4 Hit Rt",
	[2909] = "+2 Hit Rt",
	[2910] = "+3 SP",
	[2911] = "+10 Str",
	[2912] = "+12 SP",
	[2913] = "+10 Crit Rt",
	[2914] = "+10 Crit Rt",
	[2915] = "+5 Str, +5 Crit Rt",
	[2916] = "+5 Crit Rt/\n+6 SP",
	[2917] = "gem test enchantment",
	[2918] = "+3 Stam, +4 Crit Rt",
	[2919] = "+7 Str",
	[2921] = "+3 Stam/\n+4 Crit Rt",
	[2922] = "+7 Str",
	[2923] = "+3 Stam/\n+4 Crit Rt",
	[2924] = "+8 SP",
	[2925] = "+3 Stam",
	[2926] = "+2 Dg Rt",
	[2927] = "+4 Str",
	[2928] = "+12 SP",
	[2929] = "+2 Wpn Dmg",
	[2930] = "+12 SP",
	[2931] = "+4 All Stats",
	[2932] = "+4 Def Rt",
	[2933] = "+15 Res Rt",
	[2934] = "+10 Crit Rt",
	[2935] = "+15 Hit Rt",
	[2936] = "+8 AP",
	[2937] = "+20 SP",
	[2938] = "+20 SPen",
	[2939] = "Mn Spd/\n+6 Agi",
	[2940] = "Mn Spd/\n+9 Stam",
	[2941] = "+2 Hit Rt",
	[2942] = "+6 Crit Rt",
	[2943] = "+14 AP",
	[2944] = "+14 AP",
	[2945] = "+20 AP",
	[2946] = "+10 AP, +5 Crit Rt",
	[2947] = "+3 Rs All",
	[2948] = "+4 Rs All",
	[2949] = "+20 AP",
	[2950] = "+10 Crit Rt",
	[2951] = "+4 Crit Rt",
	[2952] = "+4 Crit Rt",
	[2953] = "+2 SP",
	[2954] = "Weighted +12 Dmg",
	[2955] = "Weighted +14 Crit Rt/\n+12 Dmg",
	[2956] = "+4 Str",
	[2957] = "+4 Agi",
	[2958] = "+5 SP",
	[2959] = "+5 SP",
	[2960] = "+8 AP",
	[2961] = "+6 Stam",
	[2962] = "+4 Spr",
	[2963] = "+2 MP5",
	[2964] = "+4 Int",
	[2965] = "+4 Crit Rt",
	[2966] = "+4 Hit Rt",
	[2967] = "+4 Crit Rt",
	[2968] = "+4 Def Rt",
	[2969] = "+20 AP/\nMn Run Spd Inc",
	[2970] = "+12 SP/\nMn Run Spd Inc",
	[2971] = "+12 AP",
	[2972] = "+4 Blk Rt",
	[2973] = "+6 AP",
	[2974] = "+4 SP",
	[2975] = "+5 Blk Val",
	[2976] = "+2 Def Rt",
	[2977] = "+13 Dg Rt",
	[2978] = "+15 Dg Rt/\n+10 Def Rt",
	[2979] = "+15 SP",
	[2980] = "+18 SP/\n+5 MP5",
	[2981] = "+15 SP",
	[2982] = "+18 SP/\n+10 Crit Rt",
	[2983] = "+26 AP",
	[2984] = "+8 Shd Rs",
	[2985] = "+8 Fir Rs",
	[2986] = "+30 AP/\n+10 Crit Rt",
	[2987] = "+8 Frost Rs",
	[2988] = "+8 Nat Rs",
	[2989] = "+8 Arc Rs",
	[2990] = "+13 Def Rt",
	[2991] = "+15 Def Rt/\n+10 Dg Rt",
	[2992] = "+6 MP Reg",
	[2993] = "+12 SP/\n8 MP5",
	[2994] = "+13 Crit Rt",
	[2995] = "+15 Crit Rt/\n+12 SP",
	[2996] = "+13 Crit Rt",
	[2997] = "+15 Crit Rt/\n+20 AP",
	[2998] = "+7 All Rss",
	[2999] = "+16 Def Rt/\n+17 Dg Rt",
	[3000] = "+18 Stam, +12 Dg Rt,/\n+12 Res Rt",
	[3001] = "+19 SP/\n+9 MP5",
	[3002] = "+22 SP/\n+14 Hit Rt",
	[3003] = "+34 AP/\n+16 Hit Rt",
	[3004] = "+18 Stam/\n+20 Res Rt",
	[3005] = "+20 Nat Rs",
	[3006] = "+20 Arc Rs",
	[3007] = "+20 Fir Rs",
	[3008] = "+20 Frost Rs",
	[3009] = "+20 Shd Rs",
	[3010] = "+40 AP/\n+10 Crit Rt",
	[3011] = "+30 Stam/\n+10 Agi",
	[3012] = "+50 AP/\n+12 Crit Rt",
	[3013] = "+40 Stam/\n+12 Agi",
	[3014] = "WF Totem 5 (L70 Testing",
	[3015] = "+2 Str",
	[3016] = "+2 Int",
	[3017] = "+3 Blk Rt",
	[3018] = "RB 9",
	[3019] = "RB 9",
	[3020] = "RB 9",
	[3021] = "RB 1",
	[3022] = "RB 1",
	[3023] = "RB 1",
	[3024] = "RB 2",
	[3025] = "RB 2",
	[3026] = "RB 2",
	[3027] = "RB 3",
	[3028] = "RB 3",
	[3029] = "RB 3",
	[3030] = "RB 4",
	[3031] = "RB 4",
	[3032] = "RB 4",
	[3033] = "RB 5",
	[3034] = "RB 5",
	[3035] = "RB 5",
	[3036] = "RB 6",
	[3037] = "RB 6",
	[3038] = "RB 6",
	[3039] = "RB 7",
	[3040] = "RB 7",
	[3041] = "RB 7",
	[3042] = "RB 8",
	[3043] = "RB 8",
	[3044] = "RB 8",
	[3045] = "+5 Str/\n+6 Stam",
	[3046] = "+6 SP/\n+4 Int",
	[3047] = "+6 Stam/\n+5 Crit Rt",
	[3048] = "+5 Agi/\n+6 Stam",
	[3049] = "+5 Crit Rt/\n+2 MP5.",
	[3050] = "+6 SP/\n+4 Int",
	[3051] = "+6 SP/\n+6 Stam",
	[3052] = "+10 AP/\n+4 Hit Rt",
	[3053] = "+5 Def Rt/\n+4 Dg Rt",
	[3054] = "+6 SP/\n+6 Stam",
	[3055] = "+5 Agi/\n+4 Hit Rt",
	[3056] = "+5 Par Rt/\n+4 Def Rt",
	[3057] = "+5 Str/\n+4 Hit Rt",
	[3058] = "+5 Crit Rt/\n+2 MP5",
	[3059] = "+5 Crit Rt/\n2 MP5.",
	[3060] = "+5 Dg Rt/\n+6 Stam",
	[3061] = "+5 Hit Rt/\n+6 SP",
	[3062] = "+6 Crit Rt/\n+5 Dg Rt",
	[3063] = "+5 Par Rt/\n+6 Stam",
	[3064] = "+5 Spr/\n+5 SP",
	[3065] = "+8 Str",
	[3066] = "+6 SP/\n+5 SPen",
	[3067] = "+10 AP/\n+6 Stam",
	[3068] = "+5 Dg Rt/\n+4 Hit Rt",
	[3069] = "+6 SP/\n+4 Res Rt",
	[3070] = "+8 AP/\n+5 Crit Rt",
	[3071] = "+5 Int/\n+6 Stam",
	[3072] = "+5 Str/\n+4 Crit Rt",
	[3073] = "+4 Agi/\n+5 Def Rt",
	[3074] = "+4 Int/\n+5 Spr",
	[3075] = "+5 Str/\n+4 Def Rt",
	[3076] = "+4 Crit Rt/\n+6 SP",
	[3077] = "+5 Int/\n2 MP5.",
	[3078] = "+6 Stam/\n+5 Def Rt",
	[3079] = "+8 AP/\n+5 Res Rt",
	[3080] = "+6 Stam/\n+5 Res Rt",
	[3081] = "+6 SP/\n+4 Crit Rt",
	[3082] = "+5 Def Rt/\n2 MP5.",
	[3083] = "+6 SP/\n+4 Spr",
	[3084] = "+5 Dg Rt/\n+4 Res Rt",
	[3085] = "+6 Stam/\n+5 Crit Rt",
	[3086] = "+6 SP/\n2 MP5.",
	[3087] = "+5 Str/\n+4 Res Rt",
	[3088] = "+5 Hit Rt/\n+6 Stam",
	[3089] = "+5 Hit Rt/\n2 MP5.",
	[3090] = "+5 Par Rt/\n+4 Res Rt",
	[3091] = "+5 Crit Rt/\n+5 SPen",
	[3092] = "+3 Crit Rt",
	[3093] = "+150 AP vs UD/\nDemons",
	[3094] = "+4 Exp Rt",
	[3095] = "+8 Rs All",
	[3096] = "+17 Str/\n+16 Int",
	[3097] = "+2 Spr",
	[3098] = "+2 SP",
	[3099] = "+6 SP/\n+6 Stam",
	[3100] = "+6 SP/\n+6 Stam",
	[3101] = "+10 AP/\n+6 Stam",
	[3102] = "Psn",
	[3103] = "+8 Str",
	[3104] = "+6 Hit Rt",
	[3105] = "+8 Hit Rt",
	[3106] = "+6 AP/\n+4 Stam",
	[3107] = "+8 AP/\n+6 Stam",
	[3108] = "+6 AP & +1 MP5onds",
	[3109] = "+8 AP/\n+2 MP5",
	[3110] = "+3 Hit Rt/\n+4 SP",
	[3111] = "+4 Hit Rt/\n+5 SP",
	[3112] = "+4 Crit Rt/\n+8 AP",
	[3113] = "+3 Crit Rt/\n+6 AP",
	[3114] = "+4 AP",
	[3115] = "+10 Str",
	[3116] = "+10 Agi",
	[3117] = "+12 SP",
	[3118] = "+12 SP",
	[3119] = "+20 AP",
	[3120] = "+10 Dg Rt",
	[3121] = "+10 Par Rt",
	[3122] = "+15 Stam",
	[3123] = "+10 Spr",
	[3124] = "+5 MP5",
	[3125] = "+13 SPen",
	[3126] = "+10 Int",
	[3127] = "+10 Crit Rt",
	[3128] = "+10 Hit Rt",
	[3129] = "+10 Crit Rt",
	[3130] = "+10 Def Rt",
	[3131] = "+10 Res Rt",
	[3132] = "+10 Hit Rt",
	[3133] = "+5 Str/\n+7 Stam",
	[3134] = "+5 Agi/\n+7 Stam",
	[3135] = "+10 AP/\n+7 Stam",
	[3136] = "+10 AP/\n+3 MP5",
	[3137] = "+6 SP/\n+7 Stam",
	[3138] = "+6 SP/\n+3 MP5",
	[3139] = "+5 Crit Rt/\n+5 Str",
	[3140] = "+5 Crit Rt/\n+6 SP",
	[3141] = "+6 SP/\n+5 Int",
	[3142] = "+5 Hit Rt/\n+5 Agi",
	[3143] = "+5 Hit Rt/\n+6 SP",
	[3144] = "+5 Crit Rt/\n+10 AP",
	[3145] = "+5 Def Rt/\n+7 Stam",
	[3146] = "+5 Crit Rt/\n+6 SPen",
	[3147] = "+5 Int/\n+3 MP5",
	[3148] = "+5 Crit Rt/\n+7 Stam",
	[3149] = "+2 Agi",
	[3150] = "+7 MP5.",
	[3151] = "+2 SP",
	[3152] = "+2 Crit Rt",
	[3153] = "+2 SP",
	[3154] = "+12 Agi/\n3% Inc Crit Dmg",
	[3155] = "Ch to Inc Melee/\nRanged Atk Spd",
	[3156] = "+8 AP/\n+6 Stam",
	[3157] = "+4 Int/\n+6 Stam",
	[3158] = "+5 SP/\n+4 Spr",
	[3159] = "+8 AP/\n+4 Crit Rt",
	[3160] = "+5 SP/\n+4 Int",
	[3161] = "+4 Stam/\n+4 Crit Rt",
	[3162] = "+24 AP/\n5% Stun Rs",
	[3163] = "+14 SP/\n5% Stun Rs",
	[3164] = "+3 Stam",
	[3197] = "+20 AP",
	[3198] = "+5 SP",
	[3199] = "+170 AC",
	[3200] = "+4 Spr/\n+5 SP",
	[3201] = "+4 SP/\n+3 Spr",
	[3202] = "+5 SP/\n+4 Spr",
	[3204] = "+3 Crit Rt",
	[3205] = "+3 Crit Rt",
	[3206] = "+8 Agi",
	[3207] = "+12 Str",
	[3208] = "+24 AP",
	[3209] = "+12 Agi",
	[3210] = "+14 SP",
	[3211] = "+14 SP",
	[3212] = "+18 Stam",
	[3213] = "+6 MP5",
	[3214] = "+12 Spr",
	[3215] = "+12 Res Rt",
	[3216] = "+12 Int",
	[3217] = "+12 Crit Rt",
	[3218] = "+12 Hit Rt",
	[3219] = "+12 Hit Rt",
	[3220] = "+12 Crit Rt",
	[3221] = "+12 Def Rt",
	[3222] = "+20 Agi",
	[3223] = "Admt Wpn Chain",
	[3224] = "+6 Agi",
	[3225] = "Executioner",
	[3226] = "+4 Res Rt/\n+6 Stam",
	[3227] = "+10 Crit Rt",
	[3228] = "+34 AP",
	[3229] = "+12 Res Rt",
	[3230] = "+20 Frost Rs",
	[3231] = "+15 Exp Rt",
	[3232] = "+15 Stam/\nMn Spd Inc",
	[3233] = "+250 Mana",
	[3234] = "+20 Hit Rt",
	[3235] = "+12 Rs All",
	[3236] = "+200 resto",
	[3237] = "+10 Wpn Dmg",
	[3238] = "Gatherer",
	[3239] = "Icebreaker Wpn",
	[3240] = "+23 SP",
	[3241] = "Lifeward",
	[3242] = "+5 Rs All",
	[3243] = "+35 SPen",
	[3244] = "+7 resto/\nMP5",
	[3245] = "+20 Res Rt",
	[3246] = "+28 SP",
	[3247] = "+140 AP vs UD",
	[3248] = "+18 Exp Rt",
	[3249] = "+16 Crit Rt",
	[3250] = "Icewalker",
	[3251] = "Giantslaying",
	[3252] = "+8 All Stats",
	[3253] = "+2% Threat/\n10 Par Rt",
	[3254] = "+4 All Stats",
	[3255] = "+55 SP",
	[3256] = "Inc Stealth/\n+10 Agi",
	[3257] = "+54 SP",
	[3258] = "+18 SP",
	[3259] = "+22 Stam",
	[3260] = "+240 AC",
	[3261] = "+12 Crit Rt/\n3% Inc Crit Dmg",
	[3262] = "+15 Stam",
	[3263] = "+4 Crit Rt",
	[3264] = "+150 AC, -10% Spd",
	[3265] = "Blessed Wpn Coating",
	[3266] = "Righteous Wpn Coating",
	[3267] = "+4 Hst Rt",
	[3268] = "+15 Stam",
	[3269] = "+3 Fishing",
	[3270] = "+8 Hst Rt",
	[3271] = "+4 Hst Rt/\n+5 SP",
	[3272] = "+4 Hst Rt/\n+6 Stam",
	[3273] = "Deathfrost",
	[3274] = "+12 Def Rt/\n+5% Shield Blk Val",
	[3275] = "+14 SP/\n+2% Int",
	[3276] = "+20 AP",
	[3277] = "+12 SP",
	[3278] = "+12 SP",
	[3279] = "+3 SP",
	[3280] = "+4 Dg Rt/\n+6 Stam",
	[3281] = "+20 AP",
	[3282] = "+12 SP",
	[3283] = "+12 SP",
	[3284] = "+5 Res Rt/\n+7 Stam",
	[3285] = "+5 Hst Rt/\n+7 Stam",
	[3286] = "+5 Hst Rt/\n+6 SP",
	[3287] = "+10 Hst Rt",
	[3288] = "Test Riding Crop Enchant",
	[3289] = "+10% Mnt Spd",
-- ############## Wrath IDs ##########################################
-- ############## Wrath IDs ##########################################
-- ############## Wrath IDs ##########################################
	[3292] = "+68 AP",
	[3293] = "+51 Stam",
	[3294] = "+225 AC",
	[3295] = "+16 Hst Rt",
	[3296] = "+10 Spr/\n2% Red Threat",
	[3297] = "+275 resto",
	[3298] = "Exc Mana Oil",
	[3299] = "Exc Wizard Oil",
	[3300] = "+19 SP",
	[3301] = "+6 Crit Rt",
	[3302] = "+8 Def Rt",
	[3303] = "+8 Hst Rt",
	[3304] = "+8 Dg Rt",
	[3305] = "+12 Stam",
	[3306] = "2 MP5.",
	[3307] = "+9 Stam",
	[3308] = "+4 Hst Rt",
	[3309] = "+6 Hst Rt",
	[3310] = "+6 Int",
	[3311] = "+6 Spr",
	[3312] = "+8 Str",
	[3313] = "+8 Agi",
	[3314] = "+8 Crit Rt",
	[3315] = "+3% Mnt Spd",
	[3316] = "+6 Crit Rt",
	[3317] = "+21 Stam",
	[3318] = "+6 SP/\n+5 Spr",
	[3319] = "Test Add Sockets Enchant",
	[3320] = "Test Skill Req Enchant",
	[3321] = "+150 AC",
	[3322] = "Frz Rn Wpn",
	[3324] = "+10 Crit Rt",
	[3325] = "+45 Stam/\n+15 Agi",
	[3326] = "+55 AP/\n+15 Crit Rt",
	[3327] = "+55 Stam/\n+22 Agi",
	[3328] = "+75 AP/\n+22 Crit Rt",
	[3329] = "+12 Stam",
	[3330] = "+18 Stam",
	[3331] = "+72 Stam/\n+35 Agi",
	[3332] = "+100 AP/\n+36 Crit Rt",
	[3333] = "QA Test Blank Purple Gem Enchant",
	[3334] = "Northrend Flight",
	[3335] = "+20 AP",
	[3336] = "+10 Crit Rt",
	[3337] = "+10 AP/\n+5 Crit Rt",
	[3338] = "+6 SP/\n+5 Crit Rt",
	[3339] = "+12 SP",
	[3340] = "+10 Crit Rt",
	[3341] = "Frz Rn Wpn 2",
	[3342] = "Frz Rn Wpn 3",
	[3343] = "Frz Rn Wpn 4",
	[3344] = "Frz Rn Wpn 5",
	[3345] = "ELiv 1",
	[3346] = "ELiv 2",
	[3347] = "ELiv 3",
	[3348] = "ELiv 4",
	[3349] = "ELiv 5",
	[3350] = "ELiv 6",
	[3351] = "+6 Hit Rt",
	[3352] = "+8 Spr",
	[3353] = "+8 Int",
	[3354] = "+12 Stam",
	[3355] = "+6 Agi",
	[3356] = "+12 AP",
	[3357] = "+6 Str",
	[3358] = "+6 Dg Rt",
	[3359] = "+4 Par Rt",
	[3360] = "+8 Par Rt",
	[3361] = "+6 Blk Rt",
	[3362] = "+6 Exp Rt",
	[3363] = "+9 Blk Val",
	[3364] = "Empower Rn Wpn",
	[3365] = "Rn of Swordshat",
	[3366] = "Rn of Lichbane",
	[3367] = "Rn of Spshat",
	[3368] = "Rn of the Fallen Crusader",
	[3369] = "Rn of Cinderglacier",
	[3370] = "Rn of Razorice",
	[3371] = "+12 Str",
	[3374] = "+12 Agi",
	[3375] = "+24 AP",
	[3376] = "+12 Dg Rt",
	[3377] = "+12 Par Rt",
	[3378] = "+12 AC Pen Rt",
	[3379] = "+12 Exp Rt",
	[3380] = "+14 SP",
	[3381] = "+12 Int",
	[3382] = "+12 Crit Rt",
	[3383] = "+12 Hit Rt",
	[3384] = "+12 Def Rt",
	[3385] = "+12 Res Rt",
	[3386] = "+12 Hst Rt",
	[3387] = "+18 Stam",
	[3388] = "+12 Spr",
	[3389] = "+6 MP5",
	[3390] = "+15 SPen",
	[3391] = "+6 AC Pen Rt/\n+9 Stam",
	[3392] = "+6 Str/\n+9 Stam",
	[3393] = "+6 Agi/\n+9 Stam",
	[3394] = "+7 SP/\n+9 Stam",
	[3395] = "+12 AP/\n+9 Stam",
	[3396] = "+6 Dg Rt/\n+9 Stam",
	[3397] = "+6 Par Rt/\n+9 Stam",
	[3398] = "+6 Exp Rt/\n+9 Stam",
	[3399] = "+7 SP/\n+6 Spr",
	[3400] = "+6 Agi/\n+3 MP5",
	[3401] = "+7 SP/\n+3 MP5",
	[3402] = "+12 AP/\n+3 MP5",
	[3403] = "+7 SP/\n+8 SPen",
	[3404] = "+7 SP/\n+6 Int",
	[3405] = "+6 Str/\n+6 Crit Rt",
	[3406] = "+6 Agi/\n+6 Hit Rt",
	[3407] = "+6 Str/\n+6 Def Rt",
	[3408] = "+6 Str/\n+6 Res Rt",
	[3409] = "+6 Str/\n+6 Hst Rt",
	[3410] = "+6 Agi/\n+6 Crit Rt",
	[3411] = "+6 Str/\n+6 Hit Rt",
	[3412] = "+6 Agi/\n+6 Res Rt",
	[3413] = "+6 Agi/\n+6 Hst Rt",
	[3414] = "+7 SP/\n+6 Crit Rt",
	[3415] = "+7 SP/\n+6 Hit Rt",
	[3416] = "+7 SP/\n+6 Res Rt",
	[3417] = "+7 SP/\n+6 Hst Rt",
	[3418] = "+6 Dg Rt/\n+6 Def Rt",
	[3419] = "+6 Par Rt/\n+6 Def Rt",
	[3420] = "+6 Exp Rt/\n+6 Hit Rt",
	[3421] = "+6 Exp Rt/\n+6 Def Rt",
	[3422] = "+12 AP/\n+6 Crit Rt",
	[3423] = "+12 AP/\n+6 Hit Rt",
	[3424] = "+12 AP/\n+6 Res Rt",
	[3426] = "+12 AP/\n+6 Hst Rt",
	[3427] = "+6 Int/\n+9 Stam",
	[3428] = "+6 Crit Rt/\n+9 Stam",
	[3429] = "+6 Hit Rt/\n+9 Stam",
	[3430] = "+6 Def Rt/\n+9 Stam",
	[3431] = "+6 Res Rt/\n+9 Stam",
	[3432] = "+6 Hst Rt/\n+9 Stam",
	[3433] = "+6 Int/\n+6 Spr",
	[3434] = "+6 Crit Rt/\n+6 Spr",
	[3435] = "+6 Hit Rt/\n+6 Spr",
	[3436] = "+6 Res Rt/\n+6 Spr",
	[3437] = "+6 Hst Rt/\n+6 Spr",
	[3438] = "+6 Int/\n+3 MP5",
	[3439] = "+6 Crit Rt/\n+3 MP5",
	[3440] = "+6 Hit Rt/\n+3 MP5",
	[3441] = "+6 Res Rt/\n+3 MP5",
	[3442] = "+6 Hst Rt/\n+3 MP5",
	[3443] = "+6 Crit Rt/\n+8 SPen",
	[3444] = "+6 Hit Rt/\n+8 SPen",
	[3445] = "+6 Hst Rt/\n+8 SPen",
	[3446] = "+16 Str",
	[3447] = "+16 Agi",
	[3448] = "+19 SP",
	[3449] = "+32 AP",
	[3450] = "+16 Dg Rt",
	[3451] = "+16 Par Rt",
	[3452] = "+16 AC Pen Rt",
	[3453] = "+16 Exp Rt",
	[3454] = "+24 Stam",
	[3455] = "+16 Spr",
	[3456] = "+8 MP5",
	[3457] = "+20 SPen",
	[3458] = "+16 Int",
	[3459] = "+16 Crit Rt",
	[3460] = "+16 Hit Rt",
	[3461] = "+16 Def Rt",
	[3462] = "+16 Res Rt",
	[3463] = "+16 Hst Rt",
	[3464] = "+8 Str/\n+12 Stam",
	[3465] = "+8 Agi/\n+12 Stam",
	[3466] = "+9 SP/\n+12 Stam",
	[3467] = "+16 AP/\n+12 Stam",
	[3468] = "+8 Dg Rt/\n+12 Stam",
	[3469] = "+8 Par Rt/\n+12 Stam",
	[3470] = "+8 AC Pen Rt/\n+12 Stam",
	[3471] = "+8 Exp Rt/\n+12 Stam",
	[3472] = "+9 SP/\n+8 Spr",
	[3473] = "+9 SP/\n+4 MP5",
	[3474] = "+8 Agi/\n+4 MP5",
	[3475] = "+16 AP/\n+4 MP5",
	[3476] = "+9 SP/\n+10 SPen",
	[3477] = "+8 Str/\n+8 Crit Rt",
	[3478] = "+8 Str/\n+8 Hit Rt",
	[3479] = "+8 Str/\n+8 Def Rt",
	[3480] = "+8 Str/\n+8 Res Rt",
	[3481] = "+8 Str/\n+8 Hst Rt",
	[3482] = "+8 Agi/\n+8 Crit Rt",
	[3483] = "+8 Agi/\n+8 Hit Rt",
	[3484] = "+8 Agi/\n+8 Res Rt",
	[3485] = "+8 Agi/\n+8 Hst Rt",
	[3486] = "+9 SP/\n+8 Int",
	[3487] = "+9 SP/\n+8 Crit Rt",
	[3488] = "+9 SP/\n+8 Hit Rt",
	[3489] = "+9 SP/\n+8 Res Rt",
	[3490] = "+9 SP/\n+8 Hst Rt",
	[3491] = "+16 AP/\n+8 Crit Rt",
	[3492] = "+16 AP/\n+8 Hit Rt",
	[3493] = "+16 AP/\n+8 Res Rt",
	[3494] = "+16 AP/\n+8 Hst Rt",
	[3495] = "+8 Dg Rt/\n+8 Def Rt",
	[3496] = "+8 Par Rt/\n+8 Def Rt",
	[3497] = "+8 Exp Rt/\n+8 Hit Rt",
	[3498] = "+8 Exp Rt/\n+8 Def Rt",
	[3499] = "+8 Int/\n+12 Stam",
	[3500] = "+8 Crit Rt/\n+12 Stam",
	[3501] = "+8 Hit Rt/\n+12 Stam",
	[3502] = "+8 Def Rt/\n+12 Stam",
	[3503] = "+8 Res Rt/\n+12 Stam",
	[3504] = "+8 Hst Rt/\n+12 Stam",
	[3505] = "+8 Int/\n+8 Spr",
	[3506] = "+8 Crit Rt/\n+8 Spr",
	[3507] = "+8 Hit Rt/\n+8 Spr",
	[3508] = "+8 Res Rt/\n+8 Spr",
	[3509] = "+8 Hst Rt/\n+8 Spr",
	[3510] = "+8 Int/\n+4 MP5",
	[3511] = "+8 Crit Rt/\n+4 MP5",
	[3512] = "+8 Hit Rt/\n+4 MP5",
	[3513] = "+8 Res Rt/\n+4 MP5",
	[3514] = "+8 Hst Rt/\n+4 MP5",
	[3515] = "+8 Crit Rt/\n+10 SPen",
	[3516] = "+8 Hit Rt/\n+10 SPen",
	[3517] = "+8 Hst Rt/\n+10 SPen",
	[3518] = "+20 Str",
	[3519] = "+20 Agi",
	[3520] = "+23 SP",
	[3521] = "+40 AP",
	[3522] = "+20 Dg Rt",
	[3523] = "+20 Par Rt",
	[3524] = "+20 Exp Rt",
	[3525] = "+20 AC Pen Rt",
	[3526] = "+20 Int",
	[3527] = "+20 Crit Rt",
	[3528] = "+20 Hit Rt",
	[3529] = "+20 Def Rt",
	[3530] = "+20 Res Rt",
	[3531] = "+20 Hst Rt",
	[3532] = "+30 Stam",
	[3533] = "+20 Spr",
	[3534] = "+10 MP5",
	[3535] = "+25 SPen",
	[3536] = "+10 Str/\n+15 Stam",
	[3537] = "+10 Agi/\n+15 Stam",
	[3538] = "+12 SP/\n+15 Stam",
	[3539] = "+20 AP/\n+15 Stam",
	[3540] = "+10 Dg Rt/\n+15 Stam",
	[3541] = "+10 Par Rt/\n+15 Stam",
	[3542] = "+10 Exp Rt/\n+15 Stam",
	[3543] = "+10 AC Pen Rt/\n+15 Stam",
	[3544] = "+10 Agi/\n+5 MP5",
	[3545] = "+12 SP/\n+10 Spr",
	[3546] = "+12 SP/\n+5 MP5",
	[3547] = "+20 AP/\n+5 MP5",
	[3548] = "+12 SP/\n+13 SPen",
	[3549] = "+10 Str/\n+10 Crit Rt",
	[3550] = "+10 Str/\n+10 Hit Rt",
	[3551] = "+10 Str/\n+10 Def Rt",
	[3552] = "+10 Str/\n+10 Res Rt",
	[3553] = "+10 Str/\n+10 Hst Rt",
	[3554] = "+10 Agi/\n+10 Crit Rt",
	[3555] = "+10 Agi/\n+10 Hit Rt",
	[3556] = "+10 Agi/\n+10 Res Rt",
	[3557] = "+10 Agi/\n+10 Hst Rt",
	[3558] = "+12 SP/\n+10 Int",
	[3559] = "+12 SP/\n+10 Crit Rt",
	[3560] = "+12 SP/\n+10 Hit Rt",
	[3561] = "+12 SP/\n+10 Res Rt",
	[3563] = "+12 SP/\n+10 Hst Rt",
	[3564] = "+20 AP/\n+10 Crit Rt",
	[3565] = "+20 AP/\n+10 Hit Rt",
	[3566] = "+20 AP/\n+10 Res Rt",
	[3567] = "+20 AP/\n+10 Hst Rt",
	[3568] = "+10 Dg Rt/\n+10 Def Rt",
	[3569] = "+10 Par Rt/\n+10 Def Rt",
	[3570] = "+10 Exp Rt/\n+10 Hit Rt",
	[3571] = "+10 Exp Rt/\n+10 Def Rt",
	[3572] = "+10 Int/\n+15 Stam",
	[3573] = "+10 Crit Rt/\n+15 Stam",
	[3574] = "+10 Hit Rt/\n+15 Stam",
	[3575] = "+10 Def Rt/\n+15 Stam",
	[3576] = "+10 Res Rt/\n+15 Stam",
	[3577] = "+10 Hst Rt/\n+15 Stam",
	[3578] = "+10 Int/\n+10 Spr",
	[3579] = "+10 Crit Rt/\n+10 Spr",
	[3580] = "+10 Hit Rt/\n+10 Spr",
	[3581] = "+10 Res Rt/\n+10 Spr",
	[3582] = "+10 Hst Rt/\n+10 Spr",
	[3583] = "+10 Int/\n+5 MP5",
	[3584] = "+10 Crit Rt/\n+5 MP5",
	[3585] = "+10 Hit Rt/\n+5 MP5",
	[3586] = "+10 Res Rt/\n+5 MP5",
	[3587] = "+10 Hst Rt/\n+5 MP5",
	[3588] = "+10 Crit Rt/\n+13 SPen",
	[3589] = "+10 Hit Rt/\n+13 SPen",
	[3590] = "+10 Hst Rt/\n+13 SPen",
	[3591] = "Test +4 Int/\n+2 MP5",
	[3592] = "+100 SP vs UD",
	[3593] = "+170 AP vs UD",
	[3594] = "Rn of Swordbreaking",
	[3595] = "Rn of Spbreaking",
	[3596] = "+5 SP",
	[3597] = "Master Fstn",
	[3600] = "+6 Res Rt",
	[3602] = "+7 SP",
	[3607] = "+40 Ranged Hst Rt",
	[3608] = "+40 Ranged Crit",
	[3609] = "Lesser Fstn",
	[3610] = "Fstn",
	[3611] = "Grt Fstn",
	[3612] = "Major Fstn",
	[3613] = "Fel Fstn",
	[3614] = "Grand Fstn",
	[3615] = "Spstn",
	[3616] = "Grt Spstn",
	[3617] = "Major Spstn",
	[3618] = "Master Spstn",
	[3619] = "Demonic Spstn",
	[3620] = "Grand Spstn",
	[3621] = "+21 Crit Rt/\n3% Inc Crit Dmg",
	[3622] = "+25 Crit Rt/\n1% SRefl",
	[3623] = "+25 SP/\n+2% Int",
	[3624] = "+21 Crit Rt/\nRed Snare/\nRoot Dura by 10%",
	[3625] = "+42 AP/\nMn Run Spd Inc",
	[3626] = "+25 SP/\n2% Red Threat",
	[3627] = "+21 Int/\nCh to resto mana on Spcast",
	[3628] = "+21 Agi/\n3% Inc Crit Dmg",
	[3630] = "+21 Def Rt/\nCh to resto resto on hit",
	[3631] = "+21 Def Rt/\n+5% Shield Blk Val",
	[3632] = "+25 SP/\nMn Run Spd Inc",
	[3633] = "+11 MP5/\n3% Inc Crit Heal Effect",
	[3634] = "+32 Stam/\nReduce Sp Dmg Taken by 2%",
	[3635] = "+25 SP/\nSilence Dura Red by 10%",
	[3636] = "+21 Crit Rt/\nFear Dura Red by 10%",
	[3637] = "+32 Stam/\n2% Inc AC Val from Items",
	[3638] = "+42 AP/\nStun Dura Red by 10%",
	[3639] = "+25 SP/\nStun Dura Red by 10%",
	[3640] = "+42 AP/\nSometimes Heal on Your Crits",
	[3641] = "+21 Crit Rt/\n+2% Mana",
	[3642] = "+32 Stam/\nStun Dura Red by 10%",
	[3643] = "Ch to Inc Melee/\nRanged Atk Spd",
	[3644] = "+14 Agi",
	[3646] = "+14 Dg Rt",
	[3647] = "+14 Exp Rt",
	[3648] = "+14 Par Rt",
	[3649] = "+14 Str",
	[3650] = "+16 SP",
	[3651] = "+28 AP",
	[3652] = "+14 AC Pen Rt",
	[3653] = "+14 Spr",
	[3654] = "+7 MP5",
	[3655] = "+21 Stam",
	[3656] = "+18 SPen",
	[3657] = "+14 Crit Rt",
	[3658] = "+14 Def Rt",
	[3659] = "+14 Hst Rt",
	[3660] = "+14 Hit Rt",
	[3661] = "+14 Int",
	[3662] = "+14 Res Rt",
	[3663] = "+14 AP/\n+4 MP5",
	[3664] = "+14 AP/\n+11 Stam",
	[3665] = "+7 AC Pen Rt/\n+11 Stam",
	[3666] = "+7 Agi/\n+4 MP5",
	[3667] = "+7 Agi/\n+11 Stam",
	[3668] = "+7 Dg Rt/\n+11 Stam",
	[3669] = "+7 Exp Rt/\n+11 Stam",
	[3670] = "+7 Par Rt/\n+11 Stam",
	[3671] = "+7 Str/\n+11 Stam",
	[3672] = "+8 SP/\n+4 MP5",
	[3673] = "+8 SP/\n+7 Spr",
	[3674] = "+8 SP/\n+9 SPen",
	[3675] = "+8 SP/\n+11 Stam",
	[3676] = "+14 AP/\n+7 Crit Rt (OLD",
	[3677] = "+7 Agi/\n+7 Hst Rt",
	[3678] = "+14 AP/\n+7 Hst Rt",
	[3679] = "+14 AP/\n+7 Hit Rt",
	[3680] = "+14 AP/\n+7 Res Rt",
	[3681] = "+7 Str/\n+7 Crit Rt",
	[3682] = "+7 Str/\n+7 Hit Rt",
	[3683] = "+7 Str/\n+7 Def Rt",
	[3684] = "+7 Str/\n+7 Res Rt",
	[3685] = "+7 Str/\n+7 Hst Rt",
	[3686] = "+7 Agi/\n+7 Crit Rt",
	[3687] = "+7 Agi/\n+7 Hit Rt",
	[3688] = "+7 Agi/\n+7 Res Rt",
	[3689] = "+8 SP/\n+7 Int",
	[3690] = "+8 SP/\n+7 Crit Rt",
	[3691] = "+8 SP/\n+7 Hit Rt",
	[3692] = "+8 SP/\n+7 Res Rt",
	[3693] = "+8 SP/\n+7 Hst Rt",
	[3694] = "+7 Dg Rt/\n+7 Def Rt",
	[3695] = "+7 Par Rt/\n+7 Def Rt",
	[3696] = "+7 Exp Rt/\n+7 Hit Rt",
	[3697] = "+7 Exp Rt/\n+7 Def Rt",
	[3698] = "+7 Crit Rt/\n+7 Spr",
	[3699] = "+7 Crit Rt/\n+11 Stam",
	[3700] = "+7 Def Rt/\n+11 Stam",
	[3701] = "+7 Hst Rt/\n+7 Spr",
	[3702] = "+7 Hst Rt/\n+11 Stam",
	[3703] = "+7 Hit Rt/\n+7 Spr",
	[3704] = "+7 Hit Rt/\n+11 Stam",
	[3705] = "+7 Int/\n+7 Spr",
	[3706] = "+7 Int/\n+11 Stam",
	[3707] = "+7 Res Rt/\n+7 Spr",
	[3708] = "+7 Res Rt/\n+11 Stam",
	[3709] = "+7 Crit Rt/\n+9 SPen",
	[3710] = "+7 Crit Rt/\n+4 MP5",
	[3711] = "+7 Int/\n+4 MP5",
	[3712] = "+7 Hit Rt/\n+4 MP5",
	[3713] = "+7 Res Rt/\n+4 MP5",
	[3714] = "+7 Hst Rt/\n+4 MP5",
	[3715] = "+7 Hit Rt/\n+9 SPen",
	[3716] = "+7 Hst Rt/\n+9 SPen",
	[3717] = "Socket Bracer",
	[3718] = "+35 SP/\n+12 Spr",
	[3719] = "+50 SP/\n+20 Spr",
	[3720] = "+35 SP/\n+20 Stam",
	[3721] = "+50 SP/\n+30 Stam",
	[3722] = "Lightweave Embroidery",
	[3723] = "Socket Gloves",
	[3726] = "+$i Hst Rt",
	[3727] = "+$i Hit Rt",
	[3728] = "Darkglow Embroidery",
	[3729] = "Socket Belt",
	[3730] = "Swordguard Embroidery",
	[3731] = "Tit Wpn Chain",
	[3732] = "+34 Str",
	[3733] = "+34 Agi",
	[3734] = "+39 SP",
	[3735] = "+34 Spr",
	[3736] = "+17 MP5",
	[3737] = "+34 Int",
	[3738] = "+34 Crit Rt",
	[3739] = "+34 Hst Rt",
	[3740] = "+34 Dg Rt",
	[3741] = "+34 Par Rt",
	[3742] = "+34 Hit Rt",
	[3743] = "+34 Def Rt",
	[3744] = "+34 Res Rt",
	[3745] = "+34 AC Pen Rt",
	[3746] = "+34 Exp Rt",
	[3747] = "+43 SPen",
	[3748] = "Tit Spk (45-67",
	[3749] = "+4 Stats",
	[3750] = "+6 Stats",
	[3751] = "+6 Def Rt",
	[3752] = "+5 SP",
	[3753] = "+9 SP",
	[3754] = "+24 AP +10 Stam +10 Hit Rt",
	[3755] = "+28 AP +12 Dg Rt",
	[3756] = "+130 AP",
	[3757] = "+102 Stam",
	[3758] = "+76 SP",
	[3759] = "+70 Fir Rs",
	[3760] = "+70 Frost Rs",
	[3761] = "+70 Shd Rs",
	[3762] = "+70 Nat Rs",
	[3763] = "+70 Arc Rs",
	[3764] = "+12 AP",
	[3765] = "+4 AC Pen Rt",
	[3766] = "+12 Stam",
	[3767] = "+14 AP/\n+7 Crit Rt",
	[3768] = "Instant Psn 8",
	[3769] = "Instant Psn 9",
	[3770] = "Deadly Psn 8",
	[3771] = "Deadly Psn 9",
	[3772] = "Wound Psn 6",
	[3773] = "Wound Psn 7",
	[3774] = "Anes Psn 2",
	[3775] = "+30 SP/\n+15 Crit Rt",
	[3776] = "+45 AP/\n+15 Crit Rt",
	[3777] = "+20 Def/\n+15 Dg Rt",
	[3778] = "+8 Exp Rt",
	[3779] = "FT 8",
	[3780] = "FT 9",
	[3781] = "FT 10",
	[3782] = "FB 7",
	[3783] = "FB 8",
	[3784] = "FB 9",
	[3785] = "WF 6",
	[3786] = "WF 7",
	[3787] = "WF 8",
	[3788] = "+25 Hit Rt/\n+25 Crit Rt",
	[3789] = "Zerk",
	[3790] = "Black Magic",
	[3791] = "+30 Stam",
	[3792] = "+20 Res Rt",
	[3793] = "+40 AP/\n+15 Res Rt",
	[3794] = "+23 SP/\n+15 Res Rt",
	[3795] = "+50 AP/\n+20 Res Rt",
	[3796] = "+29 SP/\n+20 Res Rt",
	[3797] = "+29 SP/\n+20 Res Rt",
	[3798] = "+34 AP/\nMn Run Spd Inc",
	[3799] = "+20 SP/\nMn Run Spd Inc",
	[3800] = "+17 Crit Rt/\nFear Dura Red by 10%",
	[3801] = "+17 Crit Rt/\nRed Snare/\nRoot Dura by 10%",
	[3802] = "+20 SP/\nSilence Dura Red by 10%",
	[3803] = "+34 AP/\nStun Dura Red by 10%",
	[3804] = "+26 Stam/\nStun Dura Red by 10%",
	[3805] = "+20 SP/\nStun Dura Red by 10%",
	[3806] = "+18 SP/\n+10 Crit Rt",
	[3807] = "+18 SP/\n+5 MP5",
	[3808] = "+40 AP/\n+15 Crit Rt",
	[3809] = "+24 SP/\n+8 MP5",
	[3810] = "+24 SP/\n+15 Crit Rt",
	[3811] = "+20 Dg Rt/\n+15 Def Rt",
	[3812] = "+25 Frost Rs/\n+30 Stam",
	[3813] = "+25 Nat Rs/\n+30 Stam",
	[3814] = "+25 Shd Rs/\n+30 Stam",
	[3815] = "+25 Arc Rs/\n+30 Stam",
	[3816] = "+25 Fir Rs/\n+30 Stam",
	[3817] = "+50 AP/\n+20 Crit Rt",
	[3818] = "+37 Stam/\n+20 Def Rt",
	[3819] = "+30 SP/\n10 MP5onds.",
	[3820] = "+30 SP/\n20 Crit Rt.",
	[3821] = "+8 Res Rt",
	[3822] = "+55 Stam/\n+22 Agi",
	[3823] = "+75 AP/\n+22 Crit Rt",
	[3824] = "+24 AP",
	[3825] = "+15 Hst Rt",
	[3826] = "+12 Hit Rt/\n+12 Crit Rt",
	[3827] = "+110 AP",
	[3828] = "+85 AP",
	[3829] = "+35 AP",
	[3830] = "+50 SP",
	[3831] = "+23 Hst Rt",
	[3832] = "+10 All Stats",
	[3833] = "+65 AP",
	[3834] = "+63 SP",
	[3835] = "+120 AP/\n+15 Crit Rt",
	[3836] = "+70 SP/\n+6 Mana/\n5 seconds",
	[3837] = "+60 Dg Rt/\n+15 Def Rt",
	[3838] = "+70 SP/\n+15 Crit Rt",
	[3839] = "+40 AP",
	[3840] = "+23 SP",
	[3841] = "+23 SP",
	[3842] = "+30 Stam/\n+25 Res Rt",
	[3843] = "Scp +15",
	[3844] = "+45 Spr",
	[3845] = "+50 AP",
	[3846] = "+40 SP",
	[3847] = "Stoneskin Gargoyle",
	[3848] = "Socket Staff",
	[3849] = "Tit Plate",
	[3850] = "+40 Stam",
	[3851] = "+50 Stam",
	[3852] = "+30 Stam/\n+15 Res Rt",
	[3853] = "+40 Res Rt/\n+28 Stam",
	[3854] = "+81 SP",
	[3855] = "+69 SP",
	[3856] = "+100 Agi",
	[3857] = "+6 Def Rt",
	[3858] = "+5 Hit Rt",
	[3860] = "+885 AC",
	[3861] = "+20 Str",
	[3862] = "+20 Agi",
	[3863] = "+30 Stam",
	[3864] = "+20 Spr",
	[3865] = "+20 Int",
	[3866] = "+23 SP",
	[3867] = "+20 Hit Rt",
	[3868] = "Fishing Lure +100 Fishing Skill",
	[3869] = "Blade Ward",
	[3870] = "Blood Draining",
	[3871] = "+6 Par Rt",
	[3872] = "+50 SP/\n+20 Spr",
	[3873] = "+50 SP/\n+30 Stam",
	[3874] = "+130 AP",
	[3875] = "+30 AP/\n+10 Crit Rt",
	[3876] = "+15 Dg Rt/\n+10 Def Rt",
	[3877] = "+16 AP",
	[3879] = "+10 All Stats",
	[3880] = "+6 AC Pen Rt",
	[3881] = "+17 MP5",
	[3882] = "+8 AC Pen Rt",
}

--------------------------
-- Item Enchant Display --
--------------------------
addon.hasBiznicks = false

local function DCS_Item_Enchant_GetText()
	local MATCH_ENCHANT = ENCHANTED_TOOLTIP_LINE:gsub('%%s', '(.+)')
	local ENCHANT_PATTERN = ENCHANTED_TOOLTIP_LINE:gsub('%%s', '(.+)') --moving outside of the function might not be warranted but moving outside of for loop is
	local tooltip = CreateFrame("GameTooltip", "DCSScanTooltip", nil, "GameTooltipTemplate") --TODO: use the same frame for both repairs and itemlevel
	tooltip:SetOwner(UIParent, "ANCHOR_NONE")
	for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
		v.enchant:SetText("")
		-- local slotId, textureName = GetInventorySlotInfo(v) --Call for string parsing instead of table lookup, bleh.
		local item = Item:CreateFromEquipmentSlot(v:GetID())
		local itemLink = GetInventoryItemLink("player", v:GetID())
		if itemLink then
			local itemName, itemStringLink = GetItemInfo(itemLink)
			if itemStringLink then
				local _, _, Color, Ltype, Id, Enchant, Gem1, Gem2, Gem3, Gem4, Suffix, Unique, LinkLvl, Name = string.find(itemStringLink,
				"|?c?f?f?(%x*)|?H?([^:]*):?(%d+):?(%d*):?(%d*):?(%d*):?(%d*):?(%d*):?(%-?%d*):?(%-?%d*):?(%d*):?(%d*):?(%-?%d*)|?h?%[?([^%[%]]*)%]?|?h?|?r?")
				-- print(Enchant) --Enchant ID...because, ya know, let's not be logical, Blizzard...
				-- if (slot == CharacterHandsSlot) then
				-- 	if 
				if (Enchant == "2523") then
					addon.hasBiznicks = true
				end
				if showenchant then
					v.enchant:SetTextColor(getItemQualityColor(item:GetItemQuality())) --upvalue call
					if abbrevEnchants then
						v.enchant:SetText(DCS_ABBREV_ENCHANT_IDS[tonumber(""..Enchant.."")])
					else
						v.enchant:SetText(DCS_ENCHANT_IDS[tonumber(""..Enchant.."")])
					end
				else
					v.enchant:SetText("")
				end
			end
			tooltip:ClearLines()
			tooltip:SetHyperlink(itemLink)
		end
	end
end

gdbprivate.gdbdefaults.gdbdefaults.DejaClassicStatsShowEnchantChecked = {
	ShowEnchantSetChecked = true,
}

local DCS_ShowEnchantCheck = CreateFrame("CheckButton", "DCS_ShowEnchantCheck", DejaClassicStatsPanel, "InterfaceOptionsCheckButtonTemplate")
DCS_ShowEnchantCheck:RegisterEvent("PLAYER_LOGIN")
DCS_ShowEnchantCheck:RegisterEvent("PLAYER_EQUIPMENT_CHANGED")
DCS_ShowEnchantCheck:RegisterEvent("UNIT_STATS")

DCS_ShowEnchantCheck:ClearAllPoints()
	DCS_ShowEnchantCheck:SetPoint("TOPLEFT", "dcsItemsPanelCategoryFS", 7, -175)
	DCS_ShowEnchantCheck:SetScale(1)
	DCS_ShowEnchantCheck.tooltipText = L["Displays each equipped item's enchantment."].."\n\n\"Enchantment? Enchantment!\" -Sandal Feddic" --Creates a tooltip on mouseover.
	_G[DCS_ShowEnchantCheck:GetName() .. "Text"]:SetText(L["Enchants"])
	
DCS_ShowEnchantCheck:SetScript("OnEvent", function(self, event, ...)
	if event == "PLAYER_LOGIN" then
		showenchant = gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowEnchantChecked.ShowEnchantSetChecked
		self:SetChecked(showenchant)
	end
	if PaperDollFrame:IsVisible() then
		DCS_Set_Dura_Item_Positions()
		DCS_Item_Enchant_GetText() --Shouldn't be needed as there is never a time when the paperdoll wont have to be opened to display this.
		DCS_Set_Item_Quality_Color_Outlines() --Here to update on the events when PaperDoll is open.
	end
end)

DCS_ShowEnchantCheck:SetScript("OnClick", function(self)
	showenchant = not showenchant
	gdbprivate.gdb.gdbdefaults.DejaClassicStatsShowEnchantChecked.ShowEnchantSetChecked = showenchant
	DCS_Set_Dura_Item_Positions() --is this call needed? (Yes, it is -Deja)
	DCS_Item_Enchant_GetText()
end)

gdbprivate.gdbdefaults.gdbdefaults.DejaClassicStatsAbbrevEnchantsChecked = {
	AbbrevEnchantsSetChecked = true,
}

local DCS_AbbrevEnchantsCheck = CreateFrame("CheckButton", "DCS_AbbrevEnchantsCheck", DejaClassicStatsPanel, "InterfaceOptionsCheckButtonTemplate")
DCS_AbbrevEnchantsCheck:RegisterEvent("PLAYER_LOGIN")
DCS_AbbrevEnchantsCheck:RegisterEvent("PLAYER_EQUIPMENT_CHANGED")
DCS_AbbrevEnchantsCheck:RegisterEvent("UNIT_STATS")

DCS_AbbrevEnchantsCheck:ClearAllPoints()
	DCS_AbbrevEnchantsCheck:SetPoint("TOPLEFT", "dcsItemsPanelCategoryFS", 7, -195)
	DCS_AbbrevEnchantsCheck:SetScale(1)
	DCS_AbbrevEnchantsCheck.tooltipText = L["Displays an abbreviated label of each equipped item's enchantment."] --Creates a tooltip on mouseover.
	_G[DCS_AbbrevEnchantsCheck:GetName() .. "Text"]:SetText(L["Abbreviated Enchant Labels"])
	
DCS_AbbrevEnchantsCheck:SetScript("OnEvent", function(self, event, ...)
	if event == "PLAYER_LOGIN" then
		abbrevEnchants = gdbprivate.gdb.gdbdefaults.DejaClassicStatsAbbrevEnchantsChecked.AbbrevEnchantsSetChecked
		self:SetChecked(abbrevEnchants)
	end
	if PaperDollFrame:IsVisible() then
		DCS_Set_Dura_Item_Positions()
		DCS_Item_Enchant_GetText() --Shouldn't be needed as there is never a time when the paperdoll wont have to be opened to display this.
		DCS_Set_Item_Quality_Color_Outlines() --Here to update on the events when PaperDoll is open.
	end
end)

DCS_AbbrevEnchantsCheck:SetScript("OnClick", function(self)
	abbrevEnchants = not abbrevEnchants
	gdbprivate.gdb.gdbdefaults.DejaClassicStatsAbbrevEnchantsChecked.AbbrevEnchantsSetChecked = abbrevEnchants
	DCS_Set_Dura_Item_Positions() --is this call needed? (Yes, it is -Deja)
	DCS_Item_Enchant_GetText()
end)

gdbprivate.gdbdefaults.gdbdefaults.DejaClassicStatsAlternateInfoPlacement = {
	AlternateInfoPlacementChecked = false,
}

PaperDollFrame:HookScript("OnShow", function(self)
	if showitemlevel then
		DCS_Item_Level_Center()
	else
		for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
			v.ilevel:SetFormattedText("")
		end
	end
	if showrepair then
		DCS_Item_RepairCostBottom()
		DCS_Set_Dura_Item_Positions()
	else
		for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
			v.itemrepair:SetFormattedText("")
		end
	end
	if showavgdur then
		DCS_Mean_Durability()
		if addon.duraMean == 100 then --check after calculation
			duraMeanFS:SetFormattedText("")
		else
			duraMeanFS:SetFormattedText("%.0f%%", addon.duraMean)
		end
	else
		duraMeanFS:SetFormattedText("")
		duraDurabilityFrameFS:Hide()
	end
	if showdura then
		DCS_Item_DurabilityTop()
	else
		for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
			v.durability:SetFormattedText("")
		end
	end
	if showtextures then
		DCS_Durability_Bar_Textures()
		duraMeanTexture:Show()
	else
		for _, v in ipairs(DCSITEM_SLOT_FRAMES) do
			v.duratexture:Hide()
		end
		duraMeanTexture:Hide()
	end
	if showenchant then
		DCS_Item_Enchant_GetText()
	end
	DCS_Set_Item_Quality_Color_Outlines()
end)


-- local tempEnchantID = {
-- 	[256] = 600, -- (+75)
-- 	[263] = 600, -- (+25)
-- 	[264] = 600, -- (+50)
-- 	[265] = 600, -- (+75)
-- 	[266] = 600, -- (+100)
-- 	[3868] = 3600, -- (+100)
-- 	[4225] = 900, -- (+150)
-- 	[4264] = 600, -- (+15)
-- 	[4919] = 600, -- (+150)
-- 	[5386] = 600, -- (+200)
-- }

-- itemName, itemLink, itemRarity, itemLevel, itemMinLevel, itemType,
-- itemSubType, itemStackCount, itemEquipLoc, itemTexture, itemSellPrice =
-- 	GetItemInfo(itemID or "itemString" or "itemName" or "itemLink")
	
-- local hasMainHandEnchant, mainHandExpiration, mainHandCharges, mainHandEnchantID, hasOffHandEnchant, offHandExpiration, offHandCharges, offHandEnchantId = GetWeaponEnchantInfo()
-- print()
-- local duration = tempEnchantID[mainHandEnchantID] or 3600

local DCS_AlternateInfoPlacementCheck = CreateFrame("CheckButton", "DCS_AlternateInfoPlacementCheck", DejaClassicStatsPanel, "InterfaceOptionsCheckButtonTemplate")
	DCS_AlternateInfoPlacementCheck:RegisterEvent("PLAYER_LOGIN")
	DCS_AlternateInfoPlacementCheck:ClearAllPoints()
	--DCS_AlternateInfoPlacementCheck:SetPoint("TOPLEFT", 30, -255)
	DCS_AlternateInfoPlacementCheck:SetPoint("TOPLEFT", "dcsItemsPanelCategoryFS", 7, -155)
	DCS_AlternateInfoPlacementCheck:SetScale(1)
	DCS_AlternateInfoPlacementCheck.tooltipText = L["Displays the item's info beside each item's slot."] --Creates a tooltip on mouseover.
	_G[DCS_AlternateInfoPlacementCheck:GetName() .. "Text"]:SetText(L["Display Info Beside Items"])

DCS_AlternateInfoPlacementCheck:SetScript("OnEvent", function(self, event, ...)
	otherinfoplacement = gdbprivate.gdb.gdbdefaults.DejaClassicStatsAlternateInfoPlacement.AlternateInfoPlacementChecked
	self:SetChecked(otherinfoplacement)
	DCS_Set_Dura_Item_Positions()
	DCS_Item_Level_Center()
	DCS_Item_Enchant_GetText()
end)

DCS_AlternateInfoPlacementCheck:SetScript("OnClick", function(self)
	otherinfoplacement = not otherinfoplacement
	gdbprivate.gdb.gdbdefaults.DejaClassicStatsAlternateInfoPlacement.AlternateInfoPlacementChecked = otherinfoplacement
	DCS_Set_Dura_Item_Positions()
end)

gdbprivate.gdbdefaults.gdbdefaults.DejaClassicStatsItemQualityBorders = {
	ItemQualityBordersChecked = true,
}

local DCS_ItemQualityBordersCheck = CreateFrame("CheckButton", "DCS_ItemQualityBordersCheck", DejaClassicStatsPanel, "InterfaceOptionsCheckButtonTemplate")
	DCS_ItemQualityBordersCheck:RegisterEvent("PLAYER_LOGIN")
	DCS_ItemQualityBordersCheck:ClearAllPoints()
	--DCS_ItemQualityBordersCheck:SetPoint("TOPLEFT", 30, -255)
	DCS_ItemQualityBordersCheck:SetPoint("TOPLEFT", "dcsItemsPanelCategoryFS", 7, -215)
	DCS_ItemQualityBordersCheck:SetScale(1)
	DCS_ItemQualityBordersCheck.tooltipText = L["Displays a colored border around each item's slot indicating its quality."] --Creates a tooltip on mouseover.
	_G[DCS_ItemQualityBordersCheck:GetName() .. "Text"]:SetText(L["Item Quality Borders"])

DCS_ItemQualityBordersCheck:SetScript("OnEvent", function(self, event, ...)
	qualityBordersChecked = gdbprivate.gdb.gdbdefaults.DejaClassicStatsItemQualityBorders.ItemQualityBordersChecked
	self:SetChecked(qualityBordersChecked)
	-- DCS_Set_Item_Quality_Color_Outlines() -- Don't use at login (only set check) as items are not cached until paperdoll has been opened thus error occurs as all item info is nil
end)

DCS_ItemQualityBordersCheck:SetScript("OnClick", function(self)
	qualityBordersChecked = not qualityBordersChecked
	gdbprivate.gdb.gdbdefaults.DejaClassicStatsItemQualityBorders.ItemQualityBordersChecked = qualityBordersChecked
	DCS_Set_Item_Quality_Color_Outlines()
end)